package com.jln.ufc.web.action.aop;

import com.fasterxml.jackson.databind.ObjectMapper;
import com.jln.common.RedisUtil.RedisUtil;
import com.jln.common.annotation.jurisdictionAnnotation.ParametersLoading;
import com.jln.common.constant.TokenCacheConst;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.JwtUtils;
import com.jln.common.utils.PageParameter;
import com.jln.system.web.action.commonweb.sysrelevance.pojo.Dto.TableDataDto;
import com.jln.system.web.action.commonweb.sysrelevance.pojo.Vo.TableDataVo;
import com.jln.system.web.action.commonweb.sysrelevance.service.SysRelevanceTableRoleService;
import com.jln.ufc.web.action.entity.LaboratoryPermissions;
import io.jsonwebtoken.Claims;
import lombok.extern.slf4j.Slf4j;
import org.aspectj.lang.ProceedingJoinPoint;
import org.aspectj.lang.annotation.Around;
import org.aspectj.lang.annotation.Aspect;
import org.aspectj.lang.annotation.Pointcut;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;
import org.springframework.web.context.request.RequestContextHolder;
import org.springframework.web.context.request.ServletRequestAttributes;

import javax.servlet.http.HttpServletRequest;
import java.beans.IntrospectionException;
import java.beans.PropertyDescriptor;
import java.lang.reflect.Field;
import java.lang.reflect.InvocationTargetException;
import java.lang.reflect.Method;
import java.util.HashSet;
import java.util.List;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @ClassName:  MES-业务，生产调度、生产计划、基础数据-物料管理数据权限控制
 * @Description:
 * @Author:三刀 Date:2021/9/15 16:35
 * Version:1.0
 **/
@Slf4j
@Aspect
@Component
public class AuthorityUfcAop {

    @Autowired
    private RedisUtil redisUtil;

    @Autowired
    private JwtUtils jwtUtils;


    @Autowired
    private SysRelevanceTableRoleService sysRelevanceTableRoleService;

    @Autowired
    private  ObjectMapper objectMapper;

    /**
     * 切入点-----注解切入
     */
    @Pointcut("@annotation(com.jln.common.annotation.ApplyForPermission)")
    public void entryPoint () {
    }

    /**
     * 前置验证---验证参数是否符合要求
     * @param joinPoint
     * @return
     * @throws Throwable
     */
    @Around("entryPoint()")
    public Object  processingData(ProceedingJoinPoint joinPoint) throws Throwable {
        Object[] params = joinPoint.getArgs();

        //获取用户信息----通过用户信息查询出，当前用户角色
        ServletRequestAttributes requestAttributes = (ServletRequestAttributes) RequestContextHolder.getRequestAttributes();
        HttpServletRequest request = requestAttributes.getRequest();
        Object sysUseroid = request.getHeader("api_key");
        if(EmptyUtil.isEmpty(sysUseroid)){
            throw new CustomException(ResultCodeEnum.Expire_TOKEN);
        }
        Claims claimByToken = jwtUtils.getClaimByToken(sysUseroid.toString());
        Object o = redisUtil.get(TokenCacheConst.TOKEN_USER_INFO + "::" + claimByToken.getSubject());
        if(EmptyUtil.isEmpty(o)){
            throw new CustomException(ResultCodeEnum.Expire_TOKEN);
        }
        User userInfo = objectMapper.convertValue(o, User.class);
        //TO-DO--通过参数编码查询出对应参数设置的 default_value值 返回的是数组
        for (int i = 0; i < params.length; i++) {
            Object param = params[i];
            if(param instanceof PageParameter){
                Object data = ((PageParameter) param).getData();

                // 业务分类
                if (data instanceof LaboratoryPermissions) {
                    data = parameterInjection(userInfo, data);
                    ((PageParameter) param).setData(data);
                    params[i] = param;
                }
                
            }
            // 业务分类
            if (param instanceof LaboratoryPermissions) {
                params[i] = parameterInjection(userInfo, param);
            }

        }
        return joinPoint.proceed(params);
    }
    private List<Long> getRoleValue(String code, User userInfo){
        //根据角色查询配置的id集合
        Set<TableDataVo> list = new HashSet<>();
        userInfo.getSysRoles().forEach(sysRole -> {
            TableDataDto tableDataDto = new TableDataDto();
            tableDataDto.setBusinessCode(code);
            tableDataDto.setRoleFk(sysRole.getSysRoleId());

            //取出配置的参数值
            Result<List<TableDataVo>> tableRoleData = sysRelevanceTableRoleService.getTableRoleData(tableDataDto);
            if (tableRoleData.confirmSuccess()){
                list.addAll(tableRoleData.getData());
            }
        });
        //取出id集合
        List<Long> collect = list.stream().map(TableDataVo::getId).collect(Collectors.toList());
        return collect;
    }

    /**
     * 通过参数配置的 值，查询出需要加载哪些对应参数(实验室)
     * @return
     */
    private Object parameterInjection(User userInfo, Object object){
        LaboratoryPermissions laboratoryPermissions = new LaboratoryPermissions();
        Class<?> aClass = laboratoryPermissions.getClass();
        Field[] declaredFields = aClass.getDeclaredFields();
        
        ParametersLoading annotation = declaredFields[0].getAnnotation(ParametersLoading.class);
        //参数对应编码
        String value = annotation.value();
        List<Long> roleValue = getRoleValue(value, userInfo);

        PropertyDescriptor pd = null;
        try {
            if(!EmptyUtil.isEmpty(roleValue)){
                pd = new PropertyDescriptor(declaredFields[0].getName(), aClass);
                //获得写方法
                Method wM = pd.getWriteMethod();
                wM.invoke(laboratoryPermissions, roleValue);
            }
        } catch (IntrospectionException e) {
            e.printStackTrace();
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        } catch (InvocationTargetException e) {
            e.printStackTrace();
        }
        
        BeanUtils.copyProperties(laboratoryPermissions, object);
        return object;
    }
}
