package com.jln.ufc.web.action.ufc.bm.entity.vo;

import com.baomidou.mybatisplus.annotation.FieldStrategy;
import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableField;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jln.common.constant.LocalDateTimeConst;
import com.jln.common.entity.PswlsxInfo;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Max;
import javax.validation.constraints.Min;
import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

@Data
@ApiModel("物料基础信息数据层")
public class UfcBMaterialInfo extends PswlsxInfo {

    /**
     * 维护人姓名
     */
    @ApiModelProperty(example = "维护人:张三", required = true, dataType = "string")
    private String userName;

    /**
     * 物料分类外键
     */
    @ApiModelProperty(example = "0000", value = "物料分类外键", required = true)
    private Long bMaterialclassFk;

    /**
     * 物料分类名称
     */
    @ApiModelProperty(example = "0000", value = "物料分类名称", required = true)
    private String bMaterialclassName;

    @ApiModelProperty(example = "物料基础信息主键", required = true, dataType = "string")
    @TableId(value = "B_MaterialOID", type = IdType.INPUT)
    private Long bMaterialoid;

    /**
     * 物料编码
     */
    @NotBlank(message = "物料编码不能为空")
    @ApiModelProperty(example = "物料编码 1001", required = true, dataType = "string")
    @Size(max = 20, message = "物料编码最大长度为20个字节")
    private String wlid;

    /**
     * 物料名称
     */
    @NotBlank(message = "物料名称不能为空")
    @ApiModelProperty(example = "物料名称 老干妈", required = true, dataType = "string")
    @Size(max = 80, message = "物料名称最大长度为80个字节")
    private String mc;

    /**
     * 规格型号
     */
    @ApiModelProperty(example = "规格型号 XT-1001", required = true, dataType = "string")
    @Size(max = 80, message = "规格型号最大长度为80个字节")
    private String gg;

    /**
     * 计量单位
     */
    @ApiModelProperty(example = "计量单位 吨", required = true, dataType = "string")
    @Size(max = 8, message = "计量单位最大长度为8个字节")
    private String jldw;

    /**
     * 对应物料类别
     */
    @ApiModelProperty(example = "物料分类id FL01", required = true, dataType = "string")
    @Size(max = 10, message = "对应物料类别最大长度为10个字节")
    private String piid;

    /**
     * 图号
     */
    @ApiModelProperty(example = "图号 TH01", required = true, dataType = "string")
    @Size(max = 50, message = "图号最大长度为50个字节")
    private String tz;

    /**
     * 材质
     */
    @ApiModelProperty(example = "材料 CL01", required = true, dataType = "string")
    @Size(max = 30, message = "材质最大长度为30个字节")
    private String cl;

    /**
     * 辅助计量单位
     */
    @ApiModelProperty(example = "辅助计量单位 cm", required = true, dataType = "string")
    @Size(max = 8, message = "辅助计量单位最大长度为8个字节")
    private String fjldw;

    /**
     * 单件管理
     */
    @ApiModelProperty(example = "单件管理 1", required = true)
    private Boolean djgl;

    /**
     * 批号控制
     */
    @ApiModelProperty(example = "批号控制 2", required = true)
    private Boolean phkz;

    /**
     * 净重
     */
    @ApiModelProperty(example = "净重 2", required = true)
    private BigDecimal jz;

    /**
     * 毛重
     */
    @ApiModelProperty(example = "毛重 2", required = true)
    private BigDecimal mz;

    /**
     * 备注
     */
    @Size(max = 250, message = "备注最大长度为250个字节")
    private String bz;

    /**
     * 停用标志
     */
    @ApiModelProperty(example = "false", required = true)
    private Boolean tybz;

    /**
     * 启用日期
     */
    @ApiModelProperty(example = "启用日期", required = true, dataType = "date")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    @TableField(updateStrategy = FieldStrategy.IGNORED)
    private LocalDate qyrq;


    /**
     * 停用日期
     */
    @ApiModelProperty(example = "停用日期", required = true, dataType = "date")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING, pattern = "yyyy-MM-dd")
    @TableField(updateStrategy = FieldStrategy.IGNORED)
    private LocalDate tyrq;

    /**
     * 创建日期
     */
    @ApiModelProperty(example = "创建日期", hidden = true, dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysCreated;

    /**
     * 最后修改日期
     */
    @ApiModelProperty(example = "最后修改日期", hidden = true, dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysLastUpd;


    /**
     * 创建用户
     */
    @ApiModelProperty(hidden = true)
    @Size(max = 36, message = "创建用户主键最大长度为36个字节")
    private Long sysCreatedBy;


    /**
     * 最后修改用户
     */
    @ApiModelProperty(hidden = true)
    @Size(max = 36, message = "最后修改用户主键最大长度为36个字节")
    private String sysLastUpdBy;





    /**
     * 版本号
     */
    @ApiModelProperty(value = "版本号", example = "")
    @Length(max = 20)
    private String bbh;

    /**
     * 物料质量等级外键
     */
    @ApiModelProperty(value = "物料质量等级外键", example = "")
    private Long qualityFk;

    /**
     * 物料质量等级外键
     */
    @ApiModelProperty(value = "物料质量等级名称", example = "")
    private String qualityName;
    @ApiModelProperty(value = "物料质量等级编码", example = "")
    private String qualityCode;

    /**
     * 产品系列外键
     */
    @ApiModelProperty(value = "产品系列外键", example = "")
    private Long cpxlFk;

    @ApiModelProperty(value = "产品系列名称", example = "")
    private String cpxlName;
    @ApiModelProperty(value = "产品系列编码", example = "")
    private String cpxlCode;

    /**
     * 是否ERP物料
     */
    @ApiModelProperty(value = "是否ERP物料", example = "")
    private Boolean erpMaterial;

    /**
     * ERP物料编码
     */
    @Length(max = 32)
    @ApiModelProperty(value = "ERP物料编码", example = "")
    private String erpMaterialCode;

    /**
     * 存货形态(CP|产成品、CL|原材料、BC|半成品、ZZ|在制品)
     */
    @Length(max = 2)
    @ApiModelProperty(value = "存货形态", example = "")
    private String inventoryForms;

    /**
     * 标准包装数量
     */
    @ApiModelProperty(value = "标准包装数量", example = "")
    @Max(999)
    @Min(0)
    private Integer standardPackageQuantity;

    /**
     * 安全库存
     */
    @ApiModelProperty(value = "安全库存", example = "")
    @Max(999)
    @Min(0)
    private Integer safetyStock;

    /**
     * 有效期
     */
    @ApiModelProperty(value = "有效期", example = "")
    private Integer validityPeriod;

    /**
     * 包装方式(PC|批次采集包装、DJ|单件采集包装、ZJ|不采集直接包装、NO|不需要包装)
     */
    @ApiModelProperty(value = "包装方式", example = "")
    @Length(max = 2)
    private String packingMethod;

    /**
     * 缺省工厂
     */
    @ApiModelProperty(value = "缺省工厂", example = "")
    @Length(max = 50)
    private String defaultFactory;
    /**
     * 缺省工厂
     */
    @ApiModelProperty(value = "缺省工厂编码", example = "")
    private String defaultFactoryCode;

    /**
     * 缺省工厂外键
     */
    @ApiModelProperty(value = "缺省工厂外键", example = "")
    private Long defaultFactoryFk;

    /**
     * 缺省仓库
     */
    @Length(max = 50)
    @ApiModelProperty(value = "缺省仓库", example = "0021|测试仓库")
    private String defaultWarehouse;

    /**
     * 产品结构号
     */
    @ApiModelProperty(value = "产品结构号", example = "")
    @Length(max = 50)
    private String productStructure;
    private String productStructureCode;

    /**
     * 工艺路线号
     */
    @ApiModelProperty(value = "工艺路线号", example = "")
    @Length(max = 50)
    private String processRoute;
    @ApiModelProperty(value = "工艺路线号编码", example = "")
    private String processRouteCode;

    /**
     * 是否属性管理
     */
    @ApiModelProperty(value = "是否属性管理", example = "")
    private Boolean whetherProperty;

    /**
     * 物料属性组外键
     */
    @ApiModelProperty(value = "物料属性组外键", example = "")
    private Long propertyGroupFk;
    /**
     * 物料属性组名称
     */
    @ApiModelProperty(value = "物料属性组名称", example = "")
    private String propertyGroupName;

    /**
     * 物料属性值
     */
    @ApiModelProperty(value = "物料属性值", example = "")
    private String materialPropertyValue;

    /**
     * 批号属性组外键
     */
    @ApiModelProperty(value = "批号属性组外键", example = "")
    private Long batchGroupFk;

    /**
     * 批号属性组名称
     */
    @ApiModelProperty(value = "批号属性组名称", example = "")
    private String batchGroupName;
    /**
     * 批号属性值
     */
    @ApiModelProperty(value = "批号属性值", example = "")
    private String batchPropertyValue;

    /**
     * 订货类型(M|制造  P|外购  W|外协  V|虚拟)
     */
    @ApiModelProperty(value = "订货类型", example = "M")
    @Size
    @Length(max = 1)
    private String orderType;

    /**
     * 文档附件名称
     */
    @ApiModelProperty(example = "文档附件名称",dataType = "string")
    private String cessoryName;

    /**
     * 文档地址
     */
    @ApiModelProperty(example = "文档地址",dataType = "string")
    private String accessoryUrl;

}
