package com.jln.ufc.web.action.ufc.bm.entity.vo;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jln.common.constant.LocalDateTimeConst;
import com.jln.common.entity.AuthorityEntity;
import com.jln.ufc.web.action.ufc.bm.entity.dto.UfcBMaterialPropertyDto;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.NotBlank;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.List;

/**
 * @author: Luca.Liu
 * @date: 2022/1/5
 */
@Data
@ApiModel(value = "物料查询接口")
public class UfcBMaterialSelectCopyVo extends AuthorityEntity {

    @ApiModelProperty(example = "物料基础信息主键", hidden = true,dataType = "string")
    @TableId(value = "B_MaterialOID", type = IdType.INPUT)
    private Long bMaterialoid;


    @NotBlank(message = "物料编码不能为空")
    @ApiModelProperty(example = "物料编码", required = true,dataType = "string")
    private String wlid;


    @NotBlank(message = "物料名称不能为空")
    @ApiModelProperty(example = "物料名称", required = true,dataType = "string")
    private String mc;


    @ApiModelProperty(example = "规格型号", required = true,dataType = "string")
    private String gg;


    @ApiModelProperty(example = "计量单位", required = true,dataType = "string")
    private String jldw;


    @ApiModelProperty(example = "图号", required = true,dataType = "string")
    private String tz;

    @ApiModelProperty(example = "材质", required = true,dataType = "string")
    private String cl;

    @ApiModelProperty(example = "物料分类编码", required = true,dataType = "string")
    private String piid;

    @ApiModelProperty(example = "物料分类名称", required = true,dataType = "string")
    private String typeName;

    @ApiModelProperty(example = "物料分类外键", required = true,dataType = "string")
    private String bMaterialclassFk;

    /**
     * 物料属性组外键
     */
    @ApiModelProperty(value = "物料属性组外键", example = "")
    private Long propertyGroupFk;
    /**
     * 物料属性组名称
     */
    @ApiModelProperty(value = "物料属性组名称", example = "")
    private String propertyGroupName;

    /**
     * 物料属性值
     */
    @ApiModelProperty(value = "物料属性值", example = "")
    private String materialPropertyValue;

    /**
     * 批号属性组外键
     */
    @ApiModelProperty(value = "批号属性组外键", example = "")
    private Long batchGroupFk;

    /**
     * 批号属性组名称
     */
    @ApiModelProperty(value = "批号属性组名称", example = "")
    private String batchGroupName;
    /**
     * 批号属性值
     */
    @ApiModelProperty(value = "批号属性值", example = "")
    private String batchPropertyValue;

    @ApiModelProperty(example = "当前时间", hidden = true,dataType = "string")
    private LocalDateTime thisTime;

    /**
     * 产品结构号
     */
    @ApiModelProperty(value = "产品结构号", example = "")
    @Length(max = 50)
    private String productStructure;
    @ApiModelProperty(value = "产品结构号", example = "")
    private String productStructureCode;

    @ApiModelProperty(value = "工艺路线号编码", example = "")
    private String processRoute;
    private String processRouteCode;

    @ApiModelProperty(example = "版本号", hidden = true,dataType = "string")
    private String bbh;

    /**
     * 停用标志
     */
    @ApiModelProperty(example = "false", required = true)
    private Boolean tybz;

    /**
     * 启用日期
     */
    @ApiModelProperty(example = "启用日期", required = true,dataType = "date")
    @JsonFormat(shape = JsonFormat.Shape.STRING,pattern =LocalDateTimeConst.DATE_PATTERN)
    private LocalDate qyrq;

    /**
     * 停用日期
     */
    @ApiModelProperty(example = "停用日期", required = true,dataType = "date")
    @JsonFormat(shape = JsonFormat.Shape.STRING,pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate tyrq;

    /**
     * 物料属性查询条件：2021-11-24新增
     */
    private List<UfcBMaterialPropertyDto> wlsxList;

    @ApiModelProperty(value = "查询属性组明细外键-处理数据", hidden = true)
    private List<Long> gorupItemList;

    /**
     * 属性值
     */
    @ApiModelProperty(value = "物料属性值查询",hidden = true)
    private List<String> sxzList;


    //2021/6/26新增物料属性相关字段
    @ApiModelProperty(example = "物料属性字段", required = true, dataType = "string")
    private String wlsxJson;

    @ApiModelProperty(example = "物料批次字段", required = true, dataType = "string")
    private String wlpcJson;

    @ApiModelProperty(example = "物料属性组编码", required = true, dataType = "string")
    private String wlsxzbm;

    @ApiModelProperty(example = "物料属性组名称", required = true, dataType = "string")
    private String wlsxzmc;

    @ApiModelProperty(example = "物料批次组编码", required = true, dataType = "string")
    private String wlpczbm;

    @ApiModelProperty(example = "物料批次组名称", required = true, dataType = "string")
    private String wlpczmc;

    @ApiModelProperty(example = "物料批次属性组外键", required = true, dataType = "string")
    private Long batchGroupId;

    @ApiModelProperty(example = "物料属性组外键", required = true, dataType = "string")
    private Long groupId;

}
