package com.jln.ufc.web.action.ufc.bm.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.system.web.action.commonweb.parameterize.validation.ValidationRules;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBMaterial;
import com.jln.ufc.web.action.ufc.bm.entity.dto.UfcBMaterialPropertyDto;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialSelectCopyVo;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialSelectVo;
import com.jln.ufc.web.action.ufc.bm.mapper.UfcBMaterialMapper;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialPropertyGroupService;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author
 * @since 2020-02-12
 */
@Slf4j
@Service("UfcBMaterial")
public class UfcBMaterialServiceImpl extends ServiceImpl<UfcBMaterialMapper, UfcBMaterial> implements UfcBMaterialService, ValidationRules<UfcBMaterial> {
    @Autowired
    private UfcBMaterialMapper bMaterialMapper;

    /**
     * 物料属性-属性组的业务逻辑层
     */
    @Autowired
    private UfcBMaterialPropertyGroupService bMaterialPropertyGroupService;

    @Override
    public Result<Page<UfcBMaterialSelectVo>> selectList(PageParameter<UfcBMaterialSelectCopyVo> query) {
        UfcBMaterialSelectCopyVo vo = null;
//        BMaterialSelectVo vo = null;
        if (EmptyUtil.isEmpty(query.getData())) {
            vo = new UfcBMaterialSelectCopyVo();
        } else {
            vo = query.getData();
        }
        disposeMaterialProperty(vo);
        vo.setThisTime(LocalDateTime.now());
        Page<UfcBMaterialSelectVo> page = new Page<>(query.getPageNum(), query.getPageSize());
        Integer count = this.baseMapper.selectListCount(vo);
        //手动计算总数
        page.setSearchCount(false);
        page.setTotal(count);
        Page<UfcBMaterialSelectVo> selectVos = bMaterialMapper.selectLists(page, vo);

        if (selectVos.getRecords().size() > 0) {
            bMaterialPropertyGroupService.packedAbsorber(selectVos);
        }

        return new Result<Page<UfcBMaterialSelectVo>>().toSuccess(selectVos);
    }
    /**
     * 处理物料属性查询的时候，如果传递了物料属性组 的时候数据处理
     * @param vo
     */
    private void  disposeMaterialProperty(UfcBMaterialSelectCopyVo vo){
        if(EmptyUtil.isEmpty(vo)){
            log.info("处理物料列表查询是否包含属性值方法：查询条件为空!");
            return;
        }
        if(EmptyUtil.isEmpty(vo.getWlsxList())){
            log.info("处理物料列表查询是否包含属性值方法：物料属性为空，不需要处理!");
            return;
        }
        //属性组明细外键-存储数据
        List<Long> gorupItemList=new ArrayList<>();
        //属性组值-存储数据
        List<String> sxzList=new ArrayList<>();
        for (UfcBMaterialPropertyDto dto : vo.getWlsxList()) {
            if(!EmptyUtil.isEmpty(dto.getSxz())){
                //当属性值不为空的时候才需要加入查询条件
                gorupItemList.add(dto.getBmaterialGorupItemfk());
                sxzList.add(dto.getSxz());
            }
        }
        if(EmptyUtil.isEmpty(sxzList)){
            //属性值为空的时候，需要将 前端传递的查询条件删除掉
            vo.setWlsxList(null);
        }
        vo.setSxzList(sxzList);
        vo.setGorupItemList(gorupItemList);

    }

    @Override
    public void verify(String code, User user, UfcBMaterial paramers) throws CustomException {

    }

    @Override
    public void verify(String code, UfcBMaterial paramers) throws CustomException {

    }
}
