package com.jln.ufc.web.action.ufc.bm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBSupplier;
import com.jln.ufc.web.action.ufc.bm.entity.dto.UfcBSupplierFl;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBSupplierInfo;
import com.jln.ufc.web.action.ufc.bm.mapper.UfcBSupplierMapper;
import com.jln.ufc.web.action.ufc.bm.service.UfcBSupplierService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;

/**
 * @author: Luca.Liu
 * @date: 2022/2/28
 */
@Service
public class UfcBSupplierServiceImpl extends ServiceImpl<UfcBSupplierMapper, UfcBSupplier> implements UfcBSupplierService {

    @Autowired
    private UfcBSupplierMapper ufcBSupplierMapper;

    @Override
    public Result save(UfcBSupplierInfo bSupplierInfo, User user) {
        UfcBSupplier bSupplier = new UfcBSupplier();
        if (bSupplierInfo != null) {
            BeanUtils.copyProperties(bSupplierInfo, bSupplier);
            bSupplier.setUfcJesygys(bSupplierInfo.getJesygys());
            if (EmptyUtil.isEmpty(bSupplier.getBSupplieroid())) {
                int count = this.count(new LambdaQueryWrapper<UfcBSupplier>().eq(UfcBSupplier::getGysid, bSupplier.getGysid()).eq(UfcBSupplier::getDel,0));
                if (count > 0) {
                    return new Result().toFailure(ResultCodeEnum.BMERROR1000);
                }
                bSupplier.setBSupplieroid(SnowflakeIdUtils.generate());
                bSupplier.setDel(0);
            }
            //维护人oid和维护时间
            bSupplier.setSysLastUpdBy(user.getEmployeeOid());
            bSupplier.setSysLastUpd(LocalDateTime.now());
            boolean saveStatus = this.saveOrUpdate(bSupplier);
            if (saveStatus) {
                return new Result().toSuccess(bSupplier.getBSupplieroid());
            }
            return new Result().toFailure(ResultCodeEnum.FAILUTE);
        }
        return new Result().toFailure(ResultCodeEnum.VMERROR14003);
    }

    @Override
    public Result getbyoid(Long oid) {
        UfcBSupplierInfo select = baseMapper.getbyoid(oid);
        if(EmptyUtil.isEmpty(select)){
            return new Result().toFailure(ResultCodeEnum.BMERROR1004);
        }
        return new Result().toSuccess(select);
    }

    @Override
    public Result selectPage(PageParameter<UfcBSupplierFl> page) {
        Result result=new Result<>();
        Page<UfcBSupplierInfo> bSupplierInfoPage = ufcBSupplierMapper.getlist(new Page<>(page.getPageNum(),page.getPageSize()),page.getData());
        if (bSupplierInfoPage.getRecords().size() == 0) {
            result.setCode(-1);
            result.toSuccess(false);
            result.setMsg("没有数据");
            result.setData(new ArrayList<>());
        } else {
            result.setCode(200);
            result.toSuccess(true);
            result.setData(bSupplierInfoPage);
            //存储数据给报表用
            Page<UfcBSupplierInfo> bSupplierInfoPages = ufcBSupplierMapper.getlist(new Page<>(1,9999999),page.getData());
        }
        return result;
    }
}
