package com.jln.ufc.web.action.ufc.bm.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.BMaterialGorupItemVo;
import com.jln.common.entity.Result;
import com.jln.common.entity.WlsxInfo;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.ufc.web.action.ufc.bm.entity.UfcJcBMaterial;
import com.jln.ufc.web.action.ufc.bm.entity.dto.UfcBMaterialPropertyDto;
import com.jln.ufc.web.action.ufc.bm.entity.dto.UfcMaterialPageDto;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialInfo;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialSelectCopyVo;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialSelectInfoVo;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialSelectVo;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialView;
import com.jln.ufc.web.action.ufc.bm.mapper.UfcJcBMaterialMapper;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialPropertyGroupService;
import com.jln.ufc.web.action.ufc.bm.service.UfcJcBMaterialService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

@Slf4j
@Service
public class UfcJcBMaterialServiceImpl extends ServiceImpl<UfcJcBMaterialMapper, UfcJcBMaterial> implements UfcJcBMaterialService {

    @Autowired
    private UfcJcBMaterialMapper ufcBMaterialMapper;

    @Autowired
    private UfcBMaterialPropertyGroupService bMaterialPropertyGroupService;

    @Override
    public Result<Page<UfcBMaterialSelectVo>> queryList(PageParameter<UfcBMaterialSelectCopyVo> query) {
        UfcBMaterialSelectCopyVo vo = null;
        if (EmptyUtil.isEmpty(query.getData())) {
            vo = new UfcBMaterialSelectCopyVo();
        } else {
            vo = query.getData();
        }
        disposeMaterialProperty(vo);
        vo.setThisTime(LocalDateTime.now());
        Page<UfcBMaterialSelectVo> page = new Page<>(query.getPageNum(), query.getPageSize());
//        Integer count = this.baseMapper.selectListCount(vo);
        //手动计算总数
//        page.setSearchCount(false);
//        page.setTotal(count);
        Page<UfcBMaterialSelectVo> selectVos = ufcBMaterialMapper.queryList(page, vo);

        if (selectVos.getRecords().size() > 0) {
            bMaterialPropertyGroupService.packedAbsorber(selectVos);
        }

        return new Result<Page<UfcBMaterialSelectVo>>().toSuccess(selectVos);
    }

    @Override
    public Result<Page<UfcBMaterialInfo>> queryByGcidList(PageParameter<UfcMaterialPageDto> query) {
        Page<UfcBMaterialInfo> page = ufcBMaterialMapper.queryByGcidList(new Page<>(query.getPageNum(), query.getPageSize()), query.getData());
        return new Result<Page<UfcBMaterialInfo>>().setData(page);
    }

    /**
     * 处理物料属性查询的时候，如果传递了物料属性组 的时候数据处理
     * @param vo
     */
    private void  disposeMaterialProperty(UfcBMaterialSelectCopyVo vo){
        if(EmptyUtil.isEmpty(vo)){
            log.info("处理物料列表查询是否包含属性值方法：查询条件为空!");
            return;
        }
        if(EmptyUtil.isEmpty(vo.getWlsxList())){
            log.info("处理物料列表查询是否包含属性值方法：物料属性为空，不需要处理!");
            return;
        }
        //属性组明细外键-存储数据
        List<Long> gorupItemList=new ArrayList<>();
        //属性组值-存储数据
        List<String> sxzList=new ArrayList<>();
        for (UfcBMaterialPropertyDto dto : vo.getWlsxList()) {
            if(!EmptyUtil.isEmpty(dto.getSxz())){
                //当属性值不为空的时候才需要加入查询条件
                gorupItemList.add(dto.getBmaterialGorupItemfk());
                sxzList.add(dto.getSxz());
            }
        }
        if(EmptyUtil.isEmpty(sxzList)){
            //属性值为空的时候，需要将 前端传递的查询条件删除掉
            vo.setWlsxList(null);
        }
        vo.setSxzList(sxzList);
        vo.setGorupItemList(gorupItemList);

    }


    /**
     * 物料属性查询-通过物料主键查询物料属性信息
     *
     * @param wlfk
     * @return
     */
    @Override
    public Result<WlsxInfo> getWlsx(Long wlfk) {
        if (EmptyUtil.isEmpty(wlfk)) {
            return new Result().toFailure("没有物料信息");
        }
        WlsxInfo wlsxInfo = this.baseMapper.getWlsx(wlfk);
        if (!EmptyUtil.isEmpty(wlsxInfo)) {
            //通过物料主键和类型0查询物料绑定属性值
            List<BMaterialGorupItemVo> wlsxzList = this.baseMapper.getWlsxzList(wlfk, "0");
            //通过物料主键和类型1查询物料批次绑定属性值
            List<BMaterialGorupItemVo> wlpcsxzList = this.baseMapper.getWlsxzList(wlfk, "1");
            wlsxInfo.setWlpcsxzList(wlpcsxzList);
            wlsxInfo.setWlsxzList(wlsxzList);
        }
        return new Result<WlsxInfo>().toSuccess(wlsxInfo);
    }
    
    @Override
    public Result<Page<UfcBMaterialView>> getBMaterialList(Page<UfcBMaterialView> page, UfcBMaterialSelectInfoVo bMaterialSelectInfo) {
        Page<UfcBMaterialView> bMaterialView = page.setRecords(this.baseMapper.getBMaterialList(page, bMaterialSelectInfo));
        bMaterialPropertyGroupService.packedAbsorber(bMaterialView);
        return new Result<Page<UfcBMaterialView>>().toSuccess(bMaterialView);    
    }

}
