package com.jln.ufc.web.action.ufc.em.service.impl;

import com.alibaba.fastjson.JSONArray;
import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jln.common.entity.PswlsxInfo;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBMaterialGroupItem;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBMaterialPropertyGroup;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBMaterialPropertyItem;
import com.jln.ufc.web.action.ufc.bm.entity.UfcJcBMaterial;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialGroupItemService;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialPropertyGroupService;
import com.jln.ufc.web.action.ufc.bm.service.UfcJcBMaterialService;
import com.jln.ufc.web.action.ufc.em.entity.vo.EmEquinfVo;
import com.jln.ufc.web.action.ufc.em.entity.vo.QueryParamVo;
import com.jln.ufc.web.action.ufc.em.mapper.UfcEmEquinfMapper;
import com.jln.ufc.web.action.ufc.em.service.UfcEmEquinfService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.HashMap;
import java.util.List;
import java.util.Map;
import java.util.Set;
import java.util.stream.Collectors;

/**
 * @author: Luca.Liu
 * @date: 2022/3/11
 */
@Service
public class UfcEmEquinfServiceImpl implements UfcEmEquinfService {
    
    @Autowired
    private UfcEmEquinfMapper ufcEmEquinfMapper;

    @Autowired
    private UfcJcBMaterialService ufcJcBMaterialService;

    @Autowired
    private UfcBMaterialPropertyGroupService ufcBMaterialPropertyGroupService;
    
    @Autowired
    private UfcBMaterialGroupItemService ufcBMaterialGroupItemService;
    
    
    @Override
    public Result<Page<EmEquinfVo>> getList(PageParameter<QueryParamVo> pageParameter, List<Long> list, User user) {
        //根据用户查询车间主键
        List<Long> cjOid = ufcEmEquinfMapper.selectCj(user.getUserId());
        if(EmptyUtil.isEmpty(cjOid)){
            return new Result().toSuccess(new Page<EmEquinfVo>());
        }
        Page<EmEquinfVo> page = ufcEmEquinfMapper.getList(new Page<>(pageParameter.getPageNum(), pageParameter.getPageSize()), pageParameter.getData(),list,cjOid);

        List<EmEquinfVo> records = page.getRecords();
        if (records.size() > 0) {
            List<Long> materialFks = records.stream().map(EmEquinfVo::getBMaterialFk).collect(Collectors.toList());
            Map<Long, PswlsxInfo> wlsxzInfo = getWlsxzInfo(materialFks);
            for (EmEquinfVo r : records) {
                PswlsxInfo info = wlsxzInfo.get(r.getBMaterialFk());
                if (!EmptyUtil.isEmpty(info)) {
                    BeanUtils.copyProperties(info, r);
                }
            }
        }
        return new Result().toSuccess(page);
    }


    /**
     * 通过物料外键获取物料的属性值
     *
     * @param materialFks
     * @return key：物料外键 ，value：物料属性值信息
     */
    public Map<Long, PswlsxInfo> getWlsxzInfo(List<Long> materialFks) {
        Map<Long, PswlsxInfo> map = new HashMap<>();
        if (EmptyUtil.isEmpty(materialFks)) {
            return map;
        }
        //查询出物料信息
        LambdaQueryWrapper<UfcJcBMaterial> queryWrapper = new LambdaQueryWrapper();
        queryWrapper.in(UfcJcBMaterial::getBMaterialoid, materialFks);
        List<UfcJcBMaterial> materials = ufcJcBMaterialService.list(queryWrapper);
        if (EmptyUtil.isEmpty(materials)) {
            return map;
        }
        //物料批次属性组和物料属性组的主键
        Set<Long> propertyFks = materials.stream().map(m -> m.getPropertyGroupFk()).collect(Collectors.toSet());
        Set<Long> batchFks = materials.stream().map(m -> m.getBatchGroupFk()).collect(Collectors.toSet());
        List<Long> groupFks = new ArrayList<>();
        groupFks.addAll(propertyFks);
        groupFks.addAll(batchFks);
        List<UfcBMaterialGroupItem> groupItems = ufcBMaterialGroupItemService.list(new LambdaQueryWrapper<UfcBMaterialGroupItem>().in(UfcBMaterialGroupItem::getGroupId, groupFks));
        List<UfcBMaterialPropertyGroup> groups = ufcBMaterialPropertyGroupService.list(new LambdaQueryWrapper<UfcBMaterialPropertyGroup>().in(UfcBMaterialPropertyGroup::getMaterialPropertyGroupOid, groupFks));
        if (EmptyUtil.isEmpty(groupItems) || EmptyUtil.isEmpty(groups)) {
            return map;
        }

        for (UfcJcBMaterial m : materials) {
            PswlsxInfo info = new PswlsxInfo();
            //物料属性组
            if (!EmptyUtil.isEmpty(m.getPropertyGroupFk())) {
                UfcBMaterialPropertyGroup groupOne = groups.stream().filter(g -> m.getPropertyGroupFk().equals(g.getMaterialPropertyGroupOid())).findFirst().orElse(null);
                if (!EmptyUtil.isEmpty(groupOne)) {
                    info.setWlsxzmc(groupOne.getName());
                    info.setWlsxzbm(groupOne.getMaterialPropertyGroupCode());
                    List<UfcBMaterialGroupItem> groupItemList = groupItems.stream().filter(o -> m.getPropertyGroupFk().equals(o.getGroupId())).collect(Collectors.toList());
                    String wlsxJson = getWlsxJson(groupItemList, m.getMaterialPropertyValue());
                    info.setWlsxJson(wlsxJson);
                }
            }
            //批次属性组
            if (!EmptyUtil.isEmpty(m.getBatchGroupFk())) {
                UfcBMaterialPropertyGroup groupTwo = groups.stream().filter(g -> m.getBatchGroupFk().equals(g.getMaterialPropertyGroupOid())).findFirst().orElse(null);
                if (!EmptyUtil.isEmpty(groupTwo)) {
                    info.setWlpczmc(groupTwo.getName());
                    info.setWlpczbm(groupTwo.getMaterialPropertyGroupCode());
                    List<UfcBMaterialGroupItem> batchGroupItems = groupItems.stream().filter(o -> m.getBatchGroupFk().equals(o.getGroupId())).collect(Collectors.toList());
                    String wlpcJson = getWlsxJson(batchGroupItems, m.getBatchPropertyValue());
                    info.setWlpcJson(wlpcJson);
                }
            }
            map.put(m.getBMaterialoid(), info);
        }
        return map;

    }


    /**
     * 获取一个属性组的属性值
     *
     * @param groupItems 该属性组和属性项目的绑定关系
     * @param json       json格式的物料属性值
     * @return
     */
    private String getWlsxJson(List<UfcBMaterialGroupItem> groupItems, String json) {
        StringBuffer buffer = new StringBuffer();

        Map<Long, UfcBMaterialGroupItem> groupItemMap = groupItems.stream().collect(Collectors.toMap(UfcBMaterialGroupItem::getItemId, o -> o));

        //将json属性值转为对象
        List<UfcBMaterialPropertyItem> propertyItems = new ArrayList<>();
        try {
            propertyItems = JSONArray.parseArray(json, UfcBMaterialPropertyItem.class);
        } catch (Exception e) {
            return "";
        }
        if (EmptyUtil.isEmpty(propertyItems)) {
            return "";
        }
        for (UfcBMaterialPropertyItem item : propertyItems) {
            UfcBMaterialGroupItem groupItem = groupItemMap.get(item.getMaterialPropertyItemOid());
            if (EmptyUtil.isEmpty(groupItem)){
                return "";
            }
            //该属性项目的属性值是否显示
            if (groupItem.getWhetherDisplay()) {
                //显示格式（1：显示属性名称、2：不显示属性名称）
                if (groupItem.getDisplayFormat() == 1) {
                    String fg = "";
                    switch (groupItem.getSeparator()) {
                        case 1:
                            fg = " ";
                            break;
                        case 2:
                            fg = "|";
                            break;
                        case 3:
                            fg = ";";
                            break;
                        case 4:
                            fg = "；";
                            break;
                        default:
                            fg = "";
                    }
                    String finalFg = fg;
                    buffer.append(item.getName()).append(finalFg).append(item.getDefaultValue()).append("：");
                } else {
                    buffer.append(item.getDefaultValue()).append("：");
                }
            }
        }
        return buffer.toString();
    }
    
    
}
