package com.jln.ufc.web.action.ufc.lm.controller;


import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.jln.common.annotation.LoginUser;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.PageParameter;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmOrders;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcOrdersQueryDTO;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcOrdersVO;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmOrdersService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.GetMapping;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.RequestParam;
import org.springframework.web.bind.annotation.RestController;
import org.springframework.web.multipart.MultipartFile;

import javax.validation.Valid;
import java.util.List;

/**
 * <p>
 * 委托单 前端控制器
 * </p>
 *
 * @author
 * @since 2022-01-06
 */
@Api(tags = "委托单")
@RestController
@RequestMapping("/ufc/erp/orders")
public class UfcLmOrdersController {

    @Autowired
    private UfcLmOrdersService ufcLmOrdersService;

    @ApiOperation(value = "委托单分页查询", notes = "委托单分页查询")
    @PostMapping("/getUfcLmOrdersPage")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result<Page<UfcOrdersVO>> getUfcLmOrdersPage(@RequestBody @Valid PageParameter<UfcOrdersQueryDTO> queryDTO) {
        return ufcLmOrdersService.getUfcLmOrdersPage(queryDTO);
    }

    @ApiOperation(value = "委托单详情", notes = "委托单详情")
    @GetMapping("/getUfcLmOrders")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result<UfcOrdersVO> getUfcLmOrders(@RequestParam Long oid) {
        return ufcLmOrdersService.getUfcLmOrders(oid);
    }

    @ApiOperation(value = "委托单保存", notes = "委托单保存")
    @PostMapping("/saveUfcLmOrders")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result<Long> saveUfcLmOrders(@RequestBody UfcLmOrders detail) {
        return ufcLmOrdersService.saveUfcLmOrders(detail);
    }

    @ApiOperation(value = "委托单删除", notes = "委托单删除")
    @PostMapping("/delUfcLmOrders")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result<String> delUfcLmOrders(@RequestBody List<Long> oids) {
        return ufcLmOrdersService.delUfcLmOrders(oids);
    }

    @ApiOperation(value = "委托单提交", notes = "委托单提交")
    @PostMapping("/submitUfcLmOrders")
    public Result<String> submitUfcLmOrders(@RequestBody List<Long> oids, @LoginUser User user) {
        return ufcLmOrdersService.submitUfcLmOrders(oids, user);
    }

    @ApiOperation(value = "委托单撤回", notes = "委托单撤回")
    @PostMapping("/withdraw")
    public Result<String> withdraw(@RequestBody List<Long> oids, @LoginUser User user) {
        return ufcLmOrdersService.withdraw(oids, user);
    }

    @ApiOperation(value = "委托单导入", notes = "委托单导入")
    @PostMapping("/importInfo")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result<String> importInfo(@RequestParam(value = "file", required = false) MultipartFile file, @LoginUser User user) {
        return ufcLmOrdersService.importInfo(file, user);
    }
}
