package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.entity.LaboratoryPermissions;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmBusinessType;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmBusinessTypeMiddel;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmBusinessTypeMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmBusinessTypeVO;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeMiddelService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author 
 * @since 2022-01-10
 */
@Service
public class UfcLmBusinessTypeServiceImpl extends ServiceImpl<UfcLmBusinessTypeMapper, UfcLmBusinessType> implements UfcLmBusinessTypeService {

    @Autowired
    private UfcLmBusinessTypeMiddelService ufcLmBusinessTypeMiddelService;
    
    @Override
    public Result getPage(PageParameter<UfcLmBusinessTypeVO> pageParameter) {
        Page<UfcLmBusinessTypeVO> page = new Page<>(pageParameter.getPageNum(), pageParameter.getPageSize());
        IPage<UfcLmBusinessTypeVO> list = this.getBaseMapper().getPage(page, pageParameter.getData());
        return new Result().toSuccess(list);
    }

    @Override
    public Result getList(LaboratoryPermissions laboratoryPermissions) {
        LambdaQueryWrapper<UfcLmBusinessType> wrapper = new LambdaQueryWrapper<UfcLmBusinessType>()
                                                                .eq(UfcLmBusinessType::getDel, false);
        if (!EmptyUtil.isEmpty(laboratoryPermissions) && !EmptyUtil.isEmpty(laboratoryPermissions.getUfcLmBusinessTypeIds())) {
            wrapper.in(UfcLmBusinessType::getUfcLmBusinessTypeOid, laboratoryPermissions.getUfcLmBusinessTypeIds());
        }
        
        List<UfcLmBusinessType> list = this.list(wrapper);
        return new Result().toSuccess(list);
    }

    @Override
    public Result get(Long id) {
        if (EmptyUtil.isEmpty(id)) {
            throw new CustomException(-1,"不能为空!");
        }
        UfcLmBusinessType byId = this.getById(id);
        return new Result().toSuccess(byId);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result savePojo(UfcLmBusinessTypeVO ufcLmBusinessTypeVO, User user) {
        if (EmptyUtil.isEmpty(ufcLmBusinessTypeVO)) {
            throw new CustomException(-1,"不能为空!");
        }

        UfcLmBusinessType ufcLmBusinessType = new UfcLmBusinessType();
        BeanUtils.copyProperties(ufcLmBusinessTypeVO, ufcLmBusinessType);

        // 新增
        if (EmptyUtil.isEmpty(ufcLmBusinessType.getUfcLmBusinessTypeOid())) {
            // 判断编码是否重复
            List<UfcLmBusinessType> list = this.list(new LambdaQueryWrapper<UfcLmBusinessType>()
                    .eq(UfcLmBusinessType::getUfcLmBusinessCode, ufcLmBusinessType.getUfcLmBusinessCode())
                    .eq(UfcLmBusinessType::getDel, false));
            if (!EmptyUtil.isEmpty(list)) {
                return new Result().toFailure(ResultCodeEnum.BMERROR1000);
            }
            ufcLmBusinessType.setUfcLmBusinessTypeOid(SnowflakeIdUtils.generate());
            ufcLmBusinessType.setSysCreated(LocalDateTime.now());
            ufcLmBusinessType.setSysCreatedBy(user.getEmployeeOid());
        } else {

            // 已经被引用的不能修改
            List<UfcLmBusinessTypeMiddel> list = ufcLmBusinessTypeMiddelService.list(new LambdaQueryWrapper<UfcLmBusinessTypeMiddel>()
                    .eq(UfcLmBusinessTypeMiddel::getUfcLmBusinessTypeFk, ufcLmBusinessType.getUfcLmBusinessTypeOid()));
            if (!EmptyUtil.isEmpty(list)) {
                throw new CustomException(-1,"资源已经被引用,不能修改!");
            }
        }
        
        ufcLmBusinessType.setSysLastUpd(LocalDateTime.now());
        ufcLmBusinessType.setSysLastUpdBy(user.getEmployeeOid());
        boolean b = this.saveOrUpdate(ufcLmBusinessType);
        if (b) {
            return new Result().toSuccess(ufcLmBusinessType.getUfcLmBusinessTypeOid());
        }
        return new Result().toFailure("保存失败!");
    }


    @Override
    public Result del(List<Long> ids, User user) {
        if (EmptyUtil.isEmpty(ids)) {
            throw new CustomException(-1,"不能为空!");
        }
        
        // 判断是否被引用 被引用的不能删除
        List<UfcLmBusinessTypeMiddel> list = ufcLmBusinessTypeMiddelService.list(new LambdaQueryWrapper<UfcLmBusinessTypeMiddel>()
                .in(UfcLmBusinessTypeMiddel::getUfcLmBusinessTypeFk, ids));
        if (!EmptyUtil.isEmpty(list)) {
            throw new CustomException(-1,"资源已经被引用,不能删除!");
        }
        
        boolean update = this.update(new LambdaUpdateWrapper<UfcLmBusinessType>()
                .set(UfcLmBusinessType::getDel, true)
                .set(UfcLmBusinessType::getSysLastUpd, LocalDateTime.now())
                .set(UfcLmBusinessType::getSysLastUpdBy, user.getEmployeeOid())
                .in(UfcLmBusinessType::getUfcLmBusinessTypeOid, ids));
        
        if (update) {
            return new Result().toSuccess();
        }
        return new Result().toFailure("删除失败!");
    }
    
    
}
