package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.BaseUtil;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.ExcelUtils;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.bm.entity.UfcJcBMaterial;
import com.jln.ufc.web.action.ufc.bm.service.UfcJcBMaterialService;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmOrders;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmOrdersDetail;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestCategory;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestStandard;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmOrdersDetailMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcOrdersDetailQueryDTO;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmOrdersDetailRowModel;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmOrdersDetailService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmOrdersService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestCategoryService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestStandardService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.web.multipart.MultipartFile;

import java.util.ArrayList;
import java.util.List;
import java.util.StringJoiner;

/**
 * <p>
 * 委托单明细 服务实现类
 * </p>
 *
 * @author
 * @since 2022-01-05
 */
@Service
public class UfcLmOrdersDetailServiceImpl extends ServiceImpl<UfcLmOrdersDetailMapper, UfcLmOrdersDetail> implements UfcLmOrdersDetailService {
    @Autowired
    private UfcJcBMaterialService materialService;
    @Autowired
    private UfcLmTestStandardService testStandardService;
    @Autowired
    private UfcLmOrdersService ordersService;
    @Autowired
    private UfcLmTestCategoryService categoryService;

    @Override
    public Result<Page<UfcLmOrdersDetail>> getDetailPage(PageParameter<UfcOrdersDetailQueryDTO> queryDTO) {
        Page<UfcLmOrdersDetail> page = baseMapper.getDetailPage(new Page<>(queryDTO.getPageNum(), queryDTO.getPageSize()), queryDTO.getData());
        return new Result<Page<UfcLmOrdersDetail>>().toSuccess(page);
    }

    @Override
    public Result<List<UfcLmOrdersDetail>> getDetail(UfcOrdersDetailQueryDTO queryDTO) {
        List<UfcLmOrdersDetail> page = baseMapper.getDetailPage(queryDTO);
        return new Result<List<UfcLmOrdersDetail>>().toSuccess(page);
    }

    @Override
    public Result<Long> saveDetail(UfcLmOrdersDetail detail) {
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetaiOid())) {
            detail.setUfcLmOrdersDetaiOid(SnowflakeIdUtils.generate());
        }
        boolean b = this.saveOrUpdate(detail);
        if (!b) {
            return new Result<>().toFailure("保存失败");
        }
        return new Result<Long>().toSuccess(detail.getUfcLmOrdersDetaiOid());
    }

    @Override
    public Result<String> delDetail(List<Long> oids) {
        boolean b = this.removeByIds(oids);
        if (!b) {
            return new Result<>().toFailure("删除失败");
        }
        return new Result<String>().toSuccess();
    }

    @Override
    public Result<String> importDetail(MultipartFile file, Long ufcLmOrdersFk, User user) {
        List<UfcLmOrdersDetailRowModel> modelList = ExcelUtils.readExcel("", UfcLmOrdersDetailRowModel.class, file, 0);
        List<UfcLmOrdersDetail> list = new ArrayList<>();
        UfcLmOrders orders = ordersService.getById(ufcLmOrdersFk);
        StringJoiner sj = new StringJoiner("\n");
        String code = getCode().getData();
        String prefix = "W" + BaseUtil.getYTD();
        Integer start = Integer.valueOf(code.substring(code.length() - 5));
        for (int i = 0; i < modelList.size(); i++) {
            UfcLmOrdersDetailRowModel model = modelList.get(i);
            UfcLmOrdersDetail detail = new UfcLmOrdersDetail();
            detail.setUfcLmOrdersDetaiOid(SnowflakeIdUtils.generate());
            detail.setUfcLmOrdersFk(ufcLmOrdersFk);
            BeanUtils.copyProperties(model, detail);
            detail.setUfcLmOrdersDetailSsdh(prefix + String.format("%05d", start + i));
            String check = check(detail, i);
            if (!EmptyUtil.isEmpty(check)) {
                sj.add(check);
            }
            list.add(detail);
        }
        if (sj.length() > 0) {
            return new Result<>().toFailure(sj.toString());
        }
        boolean b = this.saveBatch(list);
        if (!b) {
            return new Result<>().toFailure("导入失败");
        }
        return new Result<String>().toSuccess();
    }

    private String check(UfcLmOrdersDetail detail, int index) {
        StringJoiner sj = new StringJoiner("，");
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailWlbm())) {
            sj.add("物料编码");
        } else {
            UfcJcBMaterial material = queryMaterial(detail.getUfcLmOrdersDetailWlbm());
            if (EmptyUtil.isEmpty(material)) {
                sj.add("物料信息");
            } else {
                detail.setUfcLmOrdersDetailWlFk(material.getBMaterialoid());
            }
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailWlmc())) {
            sj.add("物料名称");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailGgxh())) {
            sj.add("规格型号");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailTh())) {
            sj.add("图号");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailWlcz())) {
            sj.add("物料材质");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailJldw())) {
            sj.add("计量单位");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailYqwcsj())) {
            sj.add("要求完成时间");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailSssl())) {
            sj.add("送试数量");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailSssj())) {
            sj.add("送试时间");
        }
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailKhhth())) {
            sj.add("客户合同号");
        }
        if (EmptyUtil.isEmpty(detail.getLmTestCategory())) {
            sj.add("实验分类");
        } else {
            UfcLmTestCategory category = queryCategory(detail.getLmTestCategory());
            if (EmptyUtil.isEmpty(category)) {
                sj.add("实验分类");
            } else {
                detail.setLmTestCategoryFk(category.getLmTestCategoryoid());
            }
        }
        if (!EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailJczxsybz())) {
            UfcLmTestStandard standard = queryTestStandard(detail.getUfcLmOrdersDetailJczxsybz());
            if (EmptyUtil.isEmpty(standard)) {
                sj.add("检测中心试验标准");
            } else {
                detail.setUfcLmOrdersDetailJczxsybzFk(standard.getLmTestStandardoid());
            }
        }
        if (!EmptyUtil.isEmpty(detail.getUfcLmOrdersDetailZxsybz())) {
            UfcLmTestStandard standard = queryTestStandard(detail.getUfcLmOrdersDetailZxsybz());
            if (EmptyUtil.isEmpty(standard)) {
                sj.add("执行试验标准");
            } else {
                detail.setUfcLmOrdersDetailZxsybzFk(standard.getLmTestStandardoid());
            }
        }
        if (sj.length() > 0) {
            return "第" + (index + 1) + "行的" + sj.toString() + "没有填写或者不存在";
        }
        return "";
    }

    private UfcLmTestStandard queryTestStandard(String code) {
        LambdaQueryWrapper<UfcLmTestStandard> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(UfcLmTestStandard::getSybzbm, code);
        UfcLmTestStandard one = testStandardService.getOne(queryWrapper);
        return one;
    }

    private UfcJcBMaterial queryMaterial(String code) {
        LambdaQueryWrapper<UfcJcBMaterial> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(UfcJcBMaterial::getWlid, code);
        UfcJcBMaterial one = materialService.getOne(queryWrapper);
        return one;
    }

    private UfcLmTestCategory queryCategory(String code) {
        LambdaQueryWrapper<UfcLmTestCategory> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(UfcLmTestCategory::getSyflbm, code);
        UfcLmTestCategory one = categoryService.getOne(queryWrapper);
        return one;
    }

    @Override
    public Result<String> getCode() {
        String prefix = "W" + BaseUtil.getYTD();
        UfcLmOrdersDetail ufcLmOrdersDetail = this.baseMapper.selectOne(new LambdaQueryWrapper<UfcLmOrdersDetail>()
                .likeRight(UfcLmOrdersDetail::getUfcLmOrdersDetailSsdh, prefix)
                .orderByDesc(UfcLmOrdersDetail::getUfcLmOrdersDetailSsdh)
                .last("LIMIT 1")
        );
        if (EmptyUtil.isEmpty(ufcLmOrdersDetail)) {
            return new Result<String>().toSuccess(prefix + "00001");
        }
        //生成流水号
        String s = ufcLmOrdersDetail.getUfcLmOrdersDetailSsdh().replaceAll(prefix, ""); //流水号
        Integer integer = Integer.valueOf(s) + 1;
        String replace = String.format("%5d", integer).replace(" ", "0");
        return new Result<String>().toSuccess(prefix + replace);
    }
}
