package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.BaseUtil;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.ExcelUtils;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.bm.entity.UfcJcBMaterial;
import com.jln.ufc.web.action.ufc.bm.service.UfcJcBMaterialService;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmOrders;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmOrdersDetail;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTds;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestCategory;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmOrdersDetailMapper;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmOrdersMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTdsSaveDto;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcOrdersDetailQueryDTO;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcOrdersQueryDTO;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTdsslSaveDto;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcSybzSaveDto;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcOrdersVO;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmOrdersRowModel;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmOrdersDetailService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmOrdersService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTdsService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestCategoryService;
import org.mybatis.spring.MyBatisSystemException;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.web.multipart.MultipartFile;

import java.text.ParseException;
import java.text.SimpleDateFormat;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.*;
import java.util.stream.Collectors;

/**
 * <p>
 * 委托单 服务实现类
 * </p>
 *
 * @author
 * @since 2022-01-06
 */
@Service
public class UfcLmOrdersServiceImpl extends ServiceImpl<UfcLmOrdersMapper, UfcLmOrders> implements UfcLmOrdersService {

    @Autowired
    private UfcLmOrdersDetailService ufcLmOrdersDetailService;

    @Autowired
    private UfcLmTdsService lmTdsService;
    @Autowired
    private UfcJcBMaterialService materialService;
    @Autowired
    private UfcLmTestCategoryService categoryService;
    @Autowired
    private UfcLmOrdersDetailMapper detailMapper;

    @Override
    public Result<Page<UfcOrdersVO>> getUfcLmOrdersPage(PageParameter<UfcOrdersQueryDTO> queryDTO) {
        Page<UfcOrdersVO> ordersVOPage = this.baseMapper.selectUfcLmOrdersPage(new Page<>(queryDTO.getPageNum(), queryDTO.getPageSize()), queryDTO.getData());
        return new Result().toSuccess(ordersVOPage);
    }

    @Override
    public Result<UfcOrdersVO> getUfcLmOrders(Long oid) {
        UfcOrdersVO ordersVO = this.baseMapper.selectUfcLmOrders(oid);
        return new Result().toSuccess(ordersVO);
    }

    @Override
    public Result<Long> saveUfcLmOrders(UfcLmOrders detail) {
        if (EmptyUtil.isEmpty(detail.getUfcLmOrdersOid())) {
            detail.setUfcLmOrdersOid(SnowflakeIdUtils.generate());
            detail.setUfcLmOrdersState("I");
        }
        if (detail.getUfcLmOrdersState().equals("F")) {
            return new Result<>().toFailure("只能编辑初始状态数据!");
        }
        boolean b = this.saveOrUpdate(detail);
        if (!b) {
            return new Result<>().toFailure("保存失败");
        }
        return new Result<Long>().toSuccess(detail.getUfcLmOrdersOid());
    }

    @Override
    public Result<String> delUfcLmOrders(List<Long> oids) {
        //查询状态是否存在非初始的
        Integer i = this.baseMapper.selectCount(new LambdaQueryWrapper<UfcLmOrders>()
                .in(UfcLmOrders::getUfcLmOrdersOid, oids)
                .eq(UfcLmOrders::getUfcLmOrdersState, "I")
        );
        if (oids.size() != i) {
            return new Result<>().toFailure("只能删除初始状态数据!");
        }
        boolean b = this.removeByIds(oids);
        if (!b) {
            return new Result<>().toFailure("删除失败");
        }
        return new Result<String>().toSuccess();
    }

    @Transactional
    @Override
    public Result<String> submitUfcLmOrders(List<Long> oids, User user) {
        for (Long oid : oids) {
            //查询委托单
            UfcOrdersVO ufcLmOrders = getUfcLmOrders(oid).getData();
            //查询委托单明细
            UfcOrdersDetailQueryDTO ordersDetailQueryDTO = new UfcOrdersDetailQueryDTO();
            ordersDetailQueryDTO.setUfcLmOrdersFk(oid);
            List<UfcLmOrdersDetail> ufcLmOrdersDetails = ufcLmOrdersDetailService.getDetail(ordersDetailQueryDTO).getData();
            if (!EmptyUtil.isEmpty(ufcLmOrdersDetails)) {
                for (UfcLmOrdersDetail ufcLmOrdersDetail : ufcLmOrdersDetails) {
                    //拼接送试单
                    UfcLmTdsSaveDto lmTdsSaveDto = new UfcLmTdsSaveDto();
                    lmTdsSaveDto.setSsdh(ufcLmOrdersDetail.getUfcLmOrdersDetailSsdh()); //送试单号
                    lmTdsSaveDto.setSyflFk(ufcLmOrdersDetail.getLmTestCategoryFk()); //试验分类外键（试验分类选择）
                    lmTdsSaveDto.setSyflbm(ufcLmOrdersDetail.getLmTestCategory()); //试验分类编码（试验分类选择）
                    lmTdsSaveDto.setSyflmc(ufcLmOrdersDetail.getLmTestCategoryName()); //试验分类名称（试验分类选择）
                    lmTdsSaveDto.setWlFk(ufcLmOrdersDetail.getUfcLmOrdersDetailWlFk()); //物料外键
                    lmTdsSaveDto.setWlbm(ufcLmOrdersDetail.getUfcLmOrdersDetailWlbm()); //物料编码（物料表选择）
                    lmTdsSaveDto.setWlmc(ufcLmOrdersDetail.getUfcLmOrdersDetailWlmc()); //物料名称
                    lmTdsSaveDto.setWlgg(ufcLmOrdersDetail.getUfcLmOrdersDetailGgxh()); //物料规格
                    lmTdsSaveDto.setWlth(ufcLmOrdersDetail.getUfcLmOrdersDetailTh()); //物料图号
                    lmTdsSaveDto.setWlcz(ufcLmOrdersDetail.getUfcLmOrdersDetailWlcz()); //物料材质
                    lmTdsSaveDto.setJldw(ufcLmOrdersDetail.getUfcLmOrdersDetailJldw()); //物料计量单位
                    lmTdsSaveDto.setSybzFk(ufcLmOrdersDetail.getUfcLmOrdersDetailZxsybzFk()); //试验标准主键（根据物料+试验分类自动匹配）
                    lmTdsSaveDto.setSybzbm(ufcLmOrdersDetail.getUfcLmOrdersDetailZxsybz()); //试验标准编码
                    lmTdsSaveDto.setSybzmc(ufcLmOrdersDetail.getUfcLmOrdersDetailZxsybzName()); //试验标准名称
                    //lmTdsSaveDto.setSsrFk(ufcLmOrders.getUfcLmOrdersSendPeopleFk()); //送试人外键
                    lmTdsSaveDto.setSsrmc(ufcLmOrders.getUfcLmOrdersSendPeople()); //送试人名称
                    lmTdsSaveDto.setSssj(ufcLmOrders.getUfcLmOrdersDate().atStartOfDay()); //送试时间
                    lmTdsSaveDto.setSssl(ufcLmOrdersDetail.getUfcLmOrdersDetailSssl()); //送试数量
                    lmTdsSaveDto.setScfs("Z"); //"生成方式（Z|直接维护 P|工艺流程卡）
                    lmTdsSaveDto.setZt("I"); //状态（I|初始 F|已提交）
                    lmTdsSaveDto.setBz(ufcLmOrdersDetail.getUfcLmOrdersDetailBz()); //备注
                    lmTdsSaveDto.setHth(ufcLmOrders.getUfcLmOrdersContract()); //合同号
                    lmTdsSaveDto.setYqwcsj(ufcLmOrdersDetail.getUfcLmOrdersDetailYqwcsj()); //要求完成时间
                    lmTdsSaveDto.setPcsl(ufcLmOrdersDetail.getUfcLmOrdersDetailsl()); //批次数量/送试数量
                    lmTdsSaveDto.setZtyq(ufcLmOrders.getUfcLmOrdersRemarks()); //总体要求

                    //送试单来源对象集合
                    List<UfcLmTdsslSaveDto> lmTdsslSaveDtos = new ArrayList<>();
                    UfcLmTdsslSaveDto lmTdsslSaveDto = new UfcLmTdsslSaveDto();
                    lmTdsslSaveDto.setSsdh(ufcLmOrdersDetail.getUfcLmOrdersDetailSsdh()); //送试单号
                    lmTdsslSaveDto.setKhhth(ufcLmOrdersDetail.getUfcLmOrdersDetailKhhth()); //客户合同号
                    lmTdsslSaveDto.setWlFk(ufcLmOrdersDetail.getUfcLmOrdersDetailWlFk()); //物料外键
                    lmTdsslSaveDto.setWlbm(ufcLmOrdersDetail.getUfcLmOrdersDetailWlbm()); //物料编码（从物料表选择）
                    lmTdsslSaveDto.setWlmc(ufcLmOrdersDetail.getUfcLmOrdersDetailWlmc()); //物料名称
                    lmTdsslSaveDto.setWlgg(ufcLmOrdersDetail.getUfcLmOrdersDetailGgxh()); //物料规格
                    lmTdsslSaveDto.setWlth(ufcLmOrdersDetail.getUfcLmOrdersDetailTh()); //物料图号
                    lmTdsslSaveDto.setWlcz(ufcLmOrdersDetail.getUfcLmOrdersDetailWlcz()); //物料材质
                    lmTdsslSaveDto.setJldw(ufcLmOrdersDetail.getUfcLmOrdersDetailJldw()); //物料计量单位
                    lmTdsslSaveDto.setPh(ufcLmOrdersDetail.getUfcLmOrdersDetailScph()); //批号
                    lmTdsslSaveDto.setSssl(ufcLmOrdersDetail.getUfcLmOrdersDetailSssl()); //送试数量
                    lmTdsslSaveDto.setZt("I"); //状态（I|初始 F|已提交）
                    lmTdsslSaveDto.setBz(ufcLmOrdersDetail.getUfcLmOrdersDetailBz()); //备注
                    lmTdsslSaveDtos.add(lmTdsslSaveDto);
                    lmTdsSaveDto.setLmTdsslSaveDtoList(lmTdsslSaveDtos);

                    //新增送试单
                    Result saveDtoResult = lmTdsService.save(lmTdsSaveDto, user);
                    if (!saveDtoResult.confirmSuccess()) {
                        return new Result<String>().toFailure("送试单异常");
                    }

                    //新增送试单-实验任务
                    Long aLong = Long.valueOf(saveDtoResult.getData().toString());
                    UfcSybzSaveDto sybzSaveDto = new UfcSybzSaveDto();
                    sybzSaveDto.setSsdh(ufcLmOrdersDetail.getUfcLmOrdersDetailSsdh());
                    sybzSaveDto.setSybzFk(aLong);
                    Result<UfcSybzSaveDto> sybzSaveDtoResult = lmTdsService.saveSyrwAndJccs(sybzSaveDto, user);
                    if (!sybzSaveDtoResult.confirmSuccess()) {
                        return new Result<String>().toFailure("送试单-实验任务异常");
                    }
                }
            }
        }
        //修改委托单状态为完成
        this.update(new LambdaUpdateWrapper<UfcLmOrders>()
                .in(UfcLmOrders::getUfcLmOrdersOid, oids)
                .set(UfcLmOrders::getUfcLmOrdersState, "F")
        );
        return new Result<String>().toSuccess();
    }

    @Override
    public Result<String> withdraw(List<Long> oids, User user) {

        //查询送试单号
        List<UfcLmOrdersDetail> ufcLmOrdersDetails = ufcLmOrdersDetailService.getBaseMapper().selectList(new LambdaQueryWrapper<UfcLmOrdersDetail>()
                .in(UfcLmOrdersDetail::getUfcLmOrdersFk, oids)
        );
        if (EmptyUtil.isEmpty(ufcLmOrdersDetails)){
            return new Result<>().toFailure("撤回失败！");
        }

        //查询送试单
        List<UfcLmTds> lmTdsList = lmTdsService.getBaseMapper().selectList(new LambdaUpdateWrapper<UfcLmTds>()
                .in(UfcLmTds::getSsdh, ufcLmOrdersDetails.stream().map(UfcLmOrdersDetail::getUfcLmOrdersDetailSsdh).collect(Collectors.toList()))
                .set(UfcLmTds::getDel, false)
        );
        for (UfcLmTds lmTds : lmTdsList) {
            if(!lmTds.getZt().equals("I")){
                return new Result<>().toFailure("["+lmTds.getSsdh()+"]委托单明细已执行，请撤回送试单为初始状态！");
            }
        }

        //删除送试单
        lmTdsService.update(new LambdaUpdateWrapper<UfcLmTds>()
                .in(UfcLmTds::getLmTdsoid, lmTdsList.stream().map(UfcLmTds::getLmTdsoid).collect(Collectors.toList()))
                .set(UfcLmTds::getDel, true)
        );
        //修改委托单状态
        boolean i = this.update(new LambdaUpdateWrapper<UfcLmOrders>()
                .in(UfcLmOrders::getUfcLmOrdersOid, oids)
                .set(UfcLmOrders::getUfcLmOrdersState, "I")
        );
        if (!i){
            return new Result<>().toFailure("撤回失败！");
        }
        return new Result<String>().toSuccess();
    }

    @Override
    @Transactional
    public Result<String> importInfo(MultipartFile file, User user) {
        List<UfcLmOrdersRowModel> modelList = ExcelUtils.readExcel("", UfcLmOrdersRowModel.class, file, 0);
        if (EmptyUtil.isEmpty(modelList)) {
            throw new CustomException(ResultCodeEnum.QCERROR14014);
        }
        //校验数据
        StringJoiner check = new StringJoiner("\n");
        int index = 1;
        Map<String, UfcLmOrders> ordersMap = new HashMap<>();
        Map<String, List<UfcLmOrdersDetail>> detailMap = new HashMap<>();
        String code = ufcLmOrdersDetailService.getCode().getData();
        Integer start = Integer.valueOf(code.substring(code.length() - 5));
        String prefix = "W" + BaseUtil.getYTD();
        for (UfcLmOrdersRowModel model : modelList) {
            checkModel(check, ordersMap, detailMap, model, index++,start++,prefix);
        }
        if (check.length() > 0) {
            return new Result<>().toFailure(check.toString());
        }

        //编码重复不允许导入
        List<String> ufcLmOrdersNumberList = new ArrayList<>();
        for (String key : ordersMap.keySet()) {
            ufcLmOrdersNumberList.add(key);
        }
        Integer integer = this.baseMapper.selectCount(new LambdaQueryWrapper<UfcLmOrders>().in(UfcLmOrders::getUfcLmOrdersNumber, ufcLmOrdersNumberList));
        if(integer > 0){
            return new Result<>().toFailure("单据编号存在重复,请核对正确后导入!");
        }

        this.saveOrUpdateBatch(ordersMap.values());
        List<UfcLmOrdersDetail> details = new ArrayList<>();
        for (List<UfcLmOrdersDetail> value : detailMap.values()) {
            int Indexes = 1;
            for (UfcLmOrdersDetail ufcLmOrdersDetail : value) {
                if(Indexes<10){
                    ufcLmOrdersDetail.setUfcLmOrdersBgbh(ufcLmOrdersDetail.getUfcLmOrdersBgbh()+"00"+Indexes);
                }else if(index<100){
                    ufcLmOrdersDetail.setUfcLmOrdersBgbh(ufcLmOrdersDetail.getUfcLmOrdersBgbh()+"0"+Indexes);
                }else{
                    ufcLmOrdersDetail.setUfcLmOrdersBgbh(ufcLmOrdersDetail.getUfcLmOrdersBgbh()+Indexes);
                }
                Indexes++;
            }
            details.addAll(value);
        }
        ufcLmOrdersDetailService.saveOrUpdateBatch(details);
        return new Result().toSuccess();
    }

    private void checkModel(StringJoiner check, Map<String, UfcLmOrders> ordersMap, Map<String, List<UfcLmOrdersDetail>> detailMap, UfcLmOrdersRowModel model, int index,Integer start,String prefix) {
        DateTimeFormatter df = DateTimeFormatter.ofPattern("yyyy/M/d");
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersNumber())) {
            check.add("第" + index + "行 '单据编号' 不能为空");
            //sj.add("单据编号");
        }
        UfcLmOrders orders = ordersMap.get(model.getUfcLmOrdersNumber());
        if (EmptyUtil.isEmpty(orders)) {
            orders = new UfcLmOrders();
            BeanUtils.copyProperties(model, orders);
            orders.setUfcLmOrdersOid(SnowflakeIdUtils.generate());
            orders.setUfcLmOrdersState("I");
            if(!EmptyUtil.isEmpty(model.getUfcLmOrdersDate())){
                try{
                    orders.setUfcLmOrdersDate(LocalDate.parse(model.getUfcLmOrdersDate(), df));
                }catch (Exception e){
                    try{
                        String str = getDateFmtStrFromCST(model.getUfcLmOrdersDate(), "yyyy/M/d");
                        orders.setUfcLmOrdersDate(LocalDate.parse(str, df));
                    }catch (Exception ex){
                        throw new CustomException(-1,"第" + index + "行 日期 列传入的值不对！");
                    }
                }
            }
            ordersMap.put(model.getUfcLmOrdersNumber(), orders);
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersType())) {
            check.add("第" + index + "行 '单据类型' 不能为空");
            //sj.add("单据类型");
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersContract())) {
            check.add("第" + index + "行 '合同号' 不能为空");
            //sj.add("合同号");
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersDate())) {
            check.add("第" + index + "行 '日期' 不能为空");
            //sj.add("日期");
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersSalesman())) {
            check.add("第" + index + "行 '销售员' 不能为空");
            //sj.add("销售员");
        }

        UfcLmOrdersDetail detail = new UfcLmOrdersDetail();
        detail.setUfcLmOrdersBgbh(model.getUfcLmOrdersContract());
        BeanUtils.copyProperties(model, detail);
        if(!EmptyUtil.isEmpty(model.getUfcLmOrdersDetailYqwcsj())){
            try{
                detail.setUfcLmOrdersDetailYqwcsj(LocalDate.parse(model.getUfcLmOrdersDetailYqwcsj(), df).atStartOfDay());
            }catch (Exception e){
                try{
                    String str = getDateFmtStrFromCST(model.getUfcLmOrdersDetailYqwcsj(), "yyyy/M/d");
                    detail.setUfcLmOrdersDetailYqwcsj(LocalDate.parse(str, df).atStartOfDay());
                }catch (Exception ex){
                    throw new CustomException(-1,"第" + index + "行 进度要求 列传入的值不对！");
                }
            }
        }
        if(!EmptyUtil.isEmpty(model.getUfcLmOrdersDetailScrq())){
            try{
                detail.setUfcLmOrdersDetailScrq(LocalDate.parse(model.getUfcLmOrdersDetailScrq(), df));
            }catch (Exception e){
                try{
                    String str = getDateFmtStrFromCST(model.getUfcLmOrdersDetailScrq(), "yyyy/M/d");
                    detail.setUfcLmOrdersDetailScrq(LocalDate.parse(str, df));
                }catch (Exception ex){
                    throw new CustomException(-1,"第" + index + "行 检测中心-生产日期 列传入的值不对！");
                }
            }
        }
        detail.setUfcLmOrdersFk(orders.getUfcLmOrdersOid());
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersDetailWlbm())) {
            check.add("第" + index + "行 '物料编码' 不能为空");
            //sj.add("物料编码");
        } else {
            LambdaQueryWrapper<UfcJcBMaterial> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(UfcJcBMaterial::getWlid, model.getUfcLmOrdersDetailWlbm());
            UfcJcBMaterial one = null;
            try{
                one = materialService.getOne(queryWrapper);
            }catch (MyBatisSystemException exception){
                queryWrapper.eq(UfcJcBMaterial::getDefaultFactory,"电子总厂");
                one = materialService.getOne(queryWrapper);
            }
            if (!EmptyUtil.isEmpty(one)) {
                detail.setUfcLmOrdersDetailWlFk(one.getBMaterialoid());
            }
        }
        if (EmptyUtil.isEmpty(model.getLmTestCategory())) {
            check.add("第" + index + "行 '检验类别编码' 不能为空");
            //sj.add("检验类别编码");
        } else {
            LambdaQueryWrapper<UfcLmTestCategory> queryWrapper = new LambdaQueryWrapper<>();
            queryWrapper.eq(UfcLmTestCategory::getSyflbm, model.getLmTestCategory());
            UfcLmTestCategory one = categoryService.getOne(queryWrapper);
            if (!EmptyUtil.isEmpty(one)) {
                detail.setLmTestCategoryFk(one.getLmTestCategoryoid());
            }
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersSalesman())) {
            check.add("第" + index + "行 '进度要求' 不能为空");
            //sj.add("进度要求");
        }
        if (EmptyUtil.isEmpty(model.getUfcLmOrdersSalesman())) {
            check.add("第" + index + "行 '客户数量' 不能为空");
            //sj.add("客户数量");
        }
//        if (EmptyUtil.isEmpty(model.getUfcLmOrdersSalesman())) {
//            sj.add("客户合同号");
//        }
        List<UfcLmOrdersDetail> details = detailMap.get(model.getUfcLmOrdersNumber());
        if (EmptyUtil.isEmpty(details)) {
            details = new ArrayList<>();
            detailMap.put(model.getUfcLmOrdersNumber(), details);
        }
        detail.setUfcLmOrdersDetailSsdh(prefix + String.format("%05d", start));
        details.add(detail);
        /*if (sj.length() > 0) {
            check.add("第" + index + "行不能为空");
        }*/
    }


    /**
     * 将CST的时间字符串转换成需要的日期格式字符串<br>
     *
     * @param cststr
     *            The source to be dealed with. <br>
     *            (exp:Fri Jan 02 00:00:00 CST 2009)
     * @param fmt
     *            The format string
     * @return string or <code>null</code> if the cststr is unpasrseable or is
     *         null return null,else return the string.
     * @author HitSnail
     */
    private String getDateFmtStrFromCST(String cststr, String fmt) {
        if ((null == cststr) || (null == fmt)) {
            return null;
        }
        String str = null;
        SimpleDateFormat sdfy = new SimpleDateFormat(fmt.trim());
        SimpleDateFormat sdf = new SimpleDateFormat(
                "EEE MMM dd HH:mm:ss 'CST' yyyy", Locale.US);
        try {
            str = sdfy.format(sdf.parse(cststr.trim()));
        } catch (ParseException e) {
            e.printStackTrace();
            return null;
        }
        return str;
    }
}
