package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.entity.LaboratoryPermissions;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestCategory;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTestCategoryDto;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTestCategoryMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmTestCategoryVo;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcValueLableVo;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestCategoryService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeMiddelService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 实验室-试验分类 服务实现类
 * </p>
 *
 * @author 
 * @since 2021-08-08
 */
@Service
@Transactional
public class UfcLmTestCategoryServiceImpl extends ServiceImpl<UfcLmTestCategoryMapper, UfcLmTestCategory> implements UfcLmTestCategoryService {


    @Autowired
    private UfcLmTestCategoryService lmTestCategoryService;

    @Autowired
    private UfcLmTestCategoryMapper lmTestCategoryMapper;

    @Autowired
    private UfcLmBusinessTypeMiddelService ufcLmBusinessTypeMiddelService;

    /**
     * 保存或修改实验分类
     * @param lmTestCategoryDto
     * @param user
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveOrUpdateLmTestCategry(UfcLmTestCategoryDto lmTestCategoryDto, User user) {
        try {
            if(ObjectUtils.isEmpty(lmTestCategoryDto)){
               return new Result().toFailure(ResultCodeEnum.Fail_PARAM);
            }
            UfcLmTestCategory lm = new UfcLmTestCategory();
            BeanUtils.copyProperties(lmTestCategoryDto,lm);
            //如果主键为空，实验编码不允许重复
            if(ObjectUtils.isEmpty(lm.getLmTestCategoryoid())){
                int resCount = this.lmTestCategoryService.count(new LambdaQueryWrapper<UfcLmTestCategory>()
                        .eq(UfcLmTestCategory::getSyflbm, lm.getSyflbm())
                        .eq(UfcLmTestCategory::getDel, false));
                if(resCount > 0){
                    return new Result().toFailure(ResultCodeEnum.BMERROR1000);
                }
                lm.setLmTestCategoryoid(SnowflakeIdUtils.generate());
                lm.setSysCreated(LocalDateTime.now());
                lm.setSysCreatedBy(user.getEmployeeOid());
            }
            lm.setSysLastUpd(LocalDateTime.now());
            lm.setSysLastUpdBy(user.getEmployeeOid());
            
            // 保存业务分类中间表
            Result result = ufcLmBusinessTypeMiddelService.savePojo(lm.getLmTestCategoryoid(), lmTestCategoryDto.getUfcLmBusinessTypeFk());
            if (!result.confirmSuccess()) {
                return new Result().toFailure(result.getMsg());
            }
            
            if(this.lmTestCategoryService.saveOrUpdate(lm)){
                return new Result().toSuccess(ResultCodeEnum.SUCCESS);
            }
        } catch (BeansException e) {
            e.printStackTrace();
        }
        return new Result().toFailure(ResultCodeEnum.FAILUTE);
    }



    /**
     *分页查询实验分类
     * @param parameter
     * @return
     */
    @Override
    public Result pageLmTestCategry(PageParameter parameter, LaboratoryPermissions laboratoryPermissions) {
        Page page = new Page<>(parameter.getPageNum(),parameter.getPageSize());
        IPage<UfcLmTestCategoryVo> ipage = lmTestCategoryMapper.selectCategryPage(page, laboratoryPermissions);
        return new Result().toSuccess(ipage);
    }



    @Override
    public Result selLmTCategoryList(UfcLmTestCategoryVo ufcLmTestCategoryVo, LaboratoryPermissions laboratoryPermissions) {
        List<UfcValueLableVo> resList = lmTestCategoryMapper.selectLmTCategoryList(ufcLmTestCategoryVo, laboratoryPermissions);
        return new Result().toSuccess(resList);
    }
}
