package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.lm.entity.UfcErpLmTestItems;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestItems;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmTestItemsVo;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTestItemsMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTestItemsDto;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTestItemsQueryDto;
import com.jln.ufc.web.action.ufc.lm.service.UfcErpLmTestItemsService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestItemsService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeMiddelService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.BeansException;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.time.LocalDateTime;

/**
 * <p>
 * 实验室-试验项目维护 服务实现类
 * </p>
 *
 * @author
 * @since 2021-08-08
 */
@Service
@Transactional
public class UfcLmTestItemsServiceImpl extends ServiceImpl<UfcLmTestItemsMapper, UfcLmTestItems> implements UfcLmTestItemsService {



    @Autowired
    private UfcLmTestItemsMapper ufcLmTestItemsMapper;

    @Autowired
    private UfcErpLmTestItemsService ufcErpLmTestItemsService;

    @Autowired
    private UfcLmTestItemsService lmTestItemsService;

    @Autowired
    private UfcLmBusinessTypeMiddelService ufcLmBusinessTypeMiddelService;
    
    /**
     * 保存或修改
     *
     * @param lmTestItemsDto
     * @param user
     * @return
     */
    @Override
    @Transactional
    public Result saveOrUpdateLmTestItems(UfcLmTestItemsDto lmTestItemsDto, User user) {
        try {
            if (ObjectUtils.isEmpty(lmTestItemsDto)) {
                return new Result().toFailure(ResultCodeEnum.Fail_PARAM);
            }
            UfcLmTestItems lti = new UfcLmTestItems();
            BeanUtils.copyProperties(lmTestItemsDto, lti);
            //如果主键不为空，编码不得重复
            if (ObjectUtils.isEmpty(lti.getLmTestItemsoid())) {
                int resCount = this.lmTestItemsService.count(new LambdaQueryWrapper<UfcLmTestItems>()
                        .eq(UfcLmTestItems::getSyxmbm, lti.getSyxmbm())
                        .eq(UfcLmTestItems::getDel, false));
                if (resCount > 0) {
                    return new Result().toFailure(ResultCodeEnum.BMERROR1000);
                }
                lti.setLmTestItemsoid(SnowflakeIdUtils.generate());
                lti.setSysCreatedBy(user.getEmployeeOid());
                lti.setSysCreated(LocalDateTime.now());
            }
            LambdaQueryWrapper<UfcErpLmTestItems> queryWrapper = new LambdaQueryWrapper();
            queryWrapper.eq(UfcErpLmTestItems::getLmTestItemsOid,lmTestItemsDto.getLmTestItemsoid());
            Integer count = ufcErpLmTestItemsService.count(queryWrapper);
            if(count>0){
                //修改
                LambdaUpdateWrapper<UfcErpLmTestItems> updateWrapper = new LambdaUpdateWrapper();
                updateWrapper.eq(UfcErpLmTestItems::getLmTestItemsOid,lmTestItemsDto.getLmTestItemsoid());
                updateWrapper.set(UfcErpLmTestItems::getBusinessClass,lmTestItemsDto.getBusinessClass());
                ufcErpLmTestItemsService.update(updateWrapper);
            }else{
                if (!EmptyUtil.isEmpty(lmTestItemsDto.getLmTestItemsoid())) {
                    UfcErpLmTestItems ufcErpLmTestItems = new UfcErpLmTestItems();
                    ufcErpLmTestItems.setBusinessClass(lmTestItemsDto.getBusinessClass());
                    ufcErpLmTestItems.setLmTestItemsOid(lmTestItemsDto.getLmTestItemsoid());
                    ufcErpLmTestItemsService.save(ufcErpLmTestItems);
                }
            }
            lti.setSysLastUpdBy(user.getEmployeeOid());
            lti.setSysLastUpd(LocalDateTime.now());

            // 保存业务类型中间表
            Result result = ufcLmBusinessTypeMiddelService.savePojo(lti.getLmTestItemsoid(), lmTestItemsDto.getUfcLmBusinessTypeFk());
            if (!result.confirmSuccess()) {
                return new Result().toFailure(result.getMsg());
            }
            
            if (this.lmTestItemsService.saveOrUpdate(lti)) {
                return new Result().toSuccess(ResultCodeEnum.SUCCESS);
            }
        } catch (BeansException e) {
            e.printStackTrace();
        }

        return new Result().toFailure(ResultCodeEnum.FAILUTE);
    }


    /**
     * 分页查询
     *
     * @param parameter
     * @return
     */
    @Override
    public Result pageLmTestItems(PageParameter<UfcLmTestItemsQueryDto> parameter) {
        Page<UfcLmTestItemsQueryDto> page = new Page<>(parameter.getPageNum(), parameter.getPageSize());
        IPage<UfcLmTestItemsVo> resPage = ufcLmTestItemsMapper.selectLmTestItemsPage(page, parameter.getData());
        return new Result().toSuccess(resPage);
    }

    /**
     * 根据主键查询
     *
     * @param lmTestItemsoid
     * @return
     */
    @Override
    public Result selLmTestItemsByoid(String lmTestItemsoid) {
        UfcLmTestItemsVo resLmTest = ufcLmTestItemsMapper.selLmTestItemsByoid(lmTestItemsoid);
        return new Result().toSuccess(resLmTest);
    }

}
