package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestParameter;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTestParameterCategoryMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcJccsDto;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcJccsVo;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeMiddelService;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTestParameterMapper;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestParameterService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;

/**
 * <p>
 * 实验室-检测参数维护 服务实现类
 * </p>
 *
 * @author gushang
 * @since 2021-08-08
 */
@Service
public class UfcLmTestParameterServiceImpl extends ServiceImpl<UfcLmTestParameterMapper, UfcLmTestParameter> implements UfcLmTestParameterService {

    private List<Long> list ;

    @Autowired
    private UfcLmTestParameterCategoryMapper ufcLmTestParameterCategoryMapper;
    /**
     * 获取检测参数列表
     *
     * @param pageParameter 分页
     * @return
     */
    @Override
    public Result<Page<UfcJccsVo>> getjccsList(PageParameter<UfcJccsDto> pageParameter) {

        Page<UfcJccsVo> page = new Page<>(pageParameter.getPageNum(), pageParameter.getPageSize());
        UfcJccsDto jccsDto = pageParameter.getData();
        if (!ObjectUtils.isEmpty(jccsDto.getJccsflfks())) {
            list  = new ArrayList<>();
            list.add(jccsDto.getJccsflfk());
            List<Long> parentList = getParentList(jccsDto.getJccsflfk());
            jccsDto.setJccsflfks(parentList);
        }
        IPage<UfcJccsVo> getlist = baseMapper.getjccsList(page, pageParameter.getData());
        return new Result().toSuccess(getlist);
    }


    public List<Long> getParentList(Long oid){
        List<Long> parentList = ufcLmTestParameterCategoryMapper.getListByPid(oid);
        list.addAll(parentList);
        for (Long aLong : parentList) {
            List<Long> childList = this.ufcLmTestParameterCategoryMapper.getListByPid(aLong);
            list.addAll(childList);
            for (Long aLong1 : childList) {
                getParentList(aLong1);
            }
        }
        return list;
    }

    /**
     * 检测测试--保存
     *
     * @param jccsDto 实体类
     * @return
     */
    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveorupdatejccs(UfcJccsDto jccsDto, User user) {

        UfcLmTestParameter lmTestParameter = new UfcLmTestParameter();
        BeanUtils.copyProperties(jccsDto, lmTestParameter);
        if (EmptyUtil.isEmpty(jccsDto.getLmTestParameteroid())) {
            List<UfcLmTestParameter> getlist = baseMapper.selectList(new LambdaQueryWrapper<UfcLmTestParameter>()
                    .eq(UfcLmTestParameter::getJccsbm, jccsDto.getJccsbm())
                    .ne(UfcLmTestParameter::getDel, true)
                    .eq(UfcLmTestParameter::getJccsflfk, jccsDto.getJccsflfk())
            );
            int size = getlist.size();
            if (size > 0) {
                return new Result().toFailure(ResultCodeEnum.BMERROR1000);
            }
            lmTestParameter.setLmTestParameteroid(SnowflakeIdUtils.generate());
            lmTestParameter.setSysCreated(LocalDateTime.now());
            lmTestParameter.setSysCreatedBy(user.getEmployeeOid());
        }
        lmTestParameter.setSysLastUpdBy(user.getEmployeeOid());
        lmTestParameter.setSysLastUpd(LocalDateTime.now());
        lmTestParameter.setDel(false);
        boolean saveOrUpdate = this.saveOrUpdate(lmTestParameter);
        if (saveOrUpdate) {
            return new Result().toSuccess("保存成功");
        } else {
            return new Result().toFailure(ResultCodeEnum.BMERROR1012);
        }
    }
   
}
