package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.LambdaUpdateWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTestStandardDto;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTestStandard;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcLmTestStandardVo;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmBusinessTypeMiddelService;
import com.jln.ufc.web.action.ufc.lm.entity.UfcErpLmTestStandard;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTestStandardMapper;
import com.jln.ufc.web.action.ufc.lm.service.UfcErpLmTestStandardService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTestStandardService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;
import org.springframework.util.ObjectUtils;

import java.time.LocalDateTime;

/**
 * <p>
 * 实验室-试验标准 服务实现类
 * </p>
 *
 * @author
 * @since 2021-08-09
 */
@Service
public class UfcLmTestStandardServiceImpl extends ServiceImpl<UfcLmTestStandardMapper, UfcLmTestStandard> implements UfcLmTestStandardService {

    @Autowired
    private UfcLmTestStandardService lmTestStandardService;

    @Autowired
    private UfcLmTestStandardMapper ufcLmTestStandardMapper;

    @Autowired
    private UfcErpLmTestStandardService ufcErpLmTestStandardService;
    @Autowired
    private UfcLmBusinessTypeMiddelService ufcLmBusinessTypeMiddelService;
    /**
     * 保存或修改试验标准数据
     *
     * @param lmTestStandardDto
     * @param user
     * @return
     */
    @Override
    @Transactional
    public Result<Long> saveOrUpdate(UfcLmTestStandardDto lmTestStandardDto, User user) {
        UfcLmTestStandard lmTestStandard = new UfcLmTestStandard();
        if (lmTestStandardDto != null) {
            BeanUtils.copyProperties(lmTestStandardDto, lmTestStandard);
            if (EmptyUtil.isEmpty(lmTestStandard.getLmTestStandardoid())) {
                int bmCount = this.lmTestStandardService.count(new LambdaQueryWrapper<UfcLmTestStandard>().eq(UfcLmTestStandard::getSybzbm, lmTestStandard.getSybzbm()).eq(UfcLmTestStandard::getDel, 0));
                if (bmCount > 0) {
                    return new Result().toFailure(ResultCodeEnum.LMERROR20000);
                }
                lmTestStandard.setLmTestStandardoid(SnowflakeIdUtils.generate());
                lmTestStandard.setSysCreated(LocalDateTime.now());
                lmTestStandard.setSysCreatedBy(user.getEmployeeOid());
                lmTestStandard.setZt("I");
            }else {
                /** 编辑保存时判断编码重复性 */
                int bmCount2 = this.lmTestStandardService.count(new LambdaQueryWrapper<UfcLmTestStandard>().ne(UfcLmTestStandard::getLmTestStandardoid,lmTestStandardDto.getLmTestStandardoid()).eq(UfcLmTestStandard::getSybzbm, lmTestStandard.getSybzbm()).eq(UfcLmTestStandard::getDel, 0));
                if (bmCount2 > 0) {
                    return new Result().toFailure(ResultCodeEnum.LMERROR20000);
                }

                UfcLmTestStandard testStandard = this.lmTestStandardService.getById(lmTestStandard.getLmTestStandardoid());
                if (ObjectUtils.isEmpty(testStandard.getSybzbm())){
                    int bmCount = this.lmTestStandardService.count(new LambdaQueryWrapper<UfcLmTestStandard>().eq(UfcLmTestStandard::getSybzbm, lmTestStandard.getSybzbm()).eq(UfcLmTestStandard::getDel, 0));
                    if (bmCount > 0) {
                        return new Result().toFailure(ResultCodeEnum.LMERROR20000);
                    }
                }
            }

            LambdaQueryWrapper<UfcErpLmTestStandard> queryWrapper = new LambdaQueryWrapper();
            queryWrapper.eq(UfcErpLmTestStandard::getLmTestStandardOid,lmTestStandard.getLmTestStandardoid());
            Integer count = ufcErpLmTestStandardService.count(queryWrapper);
            if(count>0){
                //修改
                LambdaUpdateWrapper<UfcErpLmTestStandard> updateWrapper = new LambdaUpdateWrapper();
                updateWrapper.eq(UfcErpLmTestStandard::getLmTestStandardOid,lmTestStandard.getLmTestStandardoid());
                updateWrapper.set(UfcErpLmTestStandard::getBusinessClass,lmTestStandardDto.getBusinessClass());
                ufcErpLmTestStandardService.update(updateWrapper);
            }else{
                UfcErpLmTestStandard ufcErpLmTestStandard = new UfcErpLmTestStandard();
                ufcErpLmTestStandard.setBusinessClass(lmTestStandardDto.getBusinessClass());
                ufcErpLmTestStandard.setLmTestStandardOid(lmTestStandard.getLmTestStandardoid());
                ufcErpLmTestStandardService.save(ufcErpLmTestStandard);
            }

            //维护人oid和维护时间
            lmTestStandard.setType(false);
            lmTestStandard.setSysLastUpdBy(user.getEmployeeOid());
            lmTestStandard.setSysLastUpd(LocalDateTime.now());

            // 保存业务类型中间表
            Result result = ufcLmBusinessTypeMiddelService.savePojo(lmTestStandard.getLmTestStandardoid(), lmTestStandardDto.getUfcLmBusinessTypeFk());
            if (!result.confirmSuccess()) {
                return new Result().toFailure(result.getMsg());
            }

            boolean saveStatus = this.lmTestStandardService.saveOrUpdate(lmTestStandard);
            if (saveStatus) {
                return new Result().toSuccess(lmTestStandard.getLmTestStandardoid());
            }
            return new Result().toFailure(ResultCodeEnum.LMERROR20001);
        }
        return new Result().toFailure(ResultCodeEnum.FAILUTE);
    }

    /**
     * 获取试验标准列表数据
     *
     * @param parameter
     * @return
     */
    @Override
    public Result<PageParameter<UfcLmTestStandardVo>> getList(PageParameter<UfcLmTestStandardDto> parameter) {
        Page<UfcLmTestStandardDto> page = new Page<>(parameter.getPageNum(), parameter.getPageSize());
        IPage<UfcLmTestStandardVo> lmTestStandardVoIPage = this.ufcLmTestStandardMapper.getList(page, parameter.getData());
        return new Result().toSuccess(lmTestStandardVoIPage);
    }

    

    @Override
    public Result<UfcLmTestStandardVo> getByOid(Long oid) {
        UfcLmTestStandardVo lmTestStandard = ufcLmTestStandardMapper.getByOid(oid);
        if (lmTestStandard != null) {
            return new Result().toSuccess(lmTestStandard);
        }
        return new Result<>().toFailure(ResultCodeEnum.LOOK_UP_TO);
    }




}
