package com.jln.ufc.web.action.ufc.lm.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.metadata.IPage;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jln.common.entity.Result;

import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.entity.LaboratoryPermissions;

import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTds;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcLmTdsMapper;
import com.jln.ufc.web.action.ufc.lm.entity.UfcLmTdsSo;
import com.jln.ufc.web.action.ufc.lm.mapper.UfcTestRecheckMapper;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcChangeOrderDto;
import com.jln.ufc.web.action.ufc.lm.pojo.dto.UfcLmTdsDto;
import com.jln.ufc.web.action.ufc.lm.pojo.vo.UfcTestRecheckVo;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTdsSoService;
import com.jln.ufc.web.action.ufc.lm.service.UfcLmTdsService;
import com.jln.ufc.web.action.ufc.lm.service.UfcTestRecheckService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import java.util.List;

/**
 * <p>
 * 实验室(LM02)-试验任务分配服务实现类
 * </p>
 *
 * @author
 * @since 2021-08-31
 */
@Service
public class UfcTestRecheckServiceImpl implements UfcTestRecheckService {
    @Autowired
    private UfcLmTdsService lmTdsService;

    @Autowired
    private UfcTestRecheckMapper testRecheckMapper;
    @Autowired
    private UfcLmTdsSoService lmTdsSoService;

    @Autowired
    private UfcLmTdsMapper lmTdsMapper;



    /**
     * 试验复核列表分页查询
     * @param lmtdsDto
     * @return
     */
    @Override
    public Result pageFhList(PageParameter<UfcLmTdsDto> lmtdsDto, LaboratoryPermissions laboratoryPermissions) {
        List<Long> itcIds = null;
        if (!EmptyUtil.isEmpty(laboratoryPermissions) && !EmptyUtil.isEmpty(laboratoryPermissions.getUfcLmBusinessTypeIds())) {
            // 根据权限可以查看的试验分类
            itcIds = lmTdsMapper.selectItcIds(laboratoryPermissions.getUfcLmBusinessTypeIds());
        }
        
        Page<UfcTestRecheckVo> page = new Page<>(lmtdsDto.getPageNum(), lmtdsDto.getPageSize());
        IPage<UfcTestRecheckVo> testRecheckVoIPage = testRecheckMapper.pageFhList(page, lmtdsDto.getData(), itcIds);
        //报表存储数据
//        IPage<TestRecheckVo> testRecheckVoIPages = testRecheckMapper.pageFhList(new Page<>(1,9999999), lmtdsDto.getData(), itcIds);
//        TestRecheckServiceImpl.testList = testRecheckVoIPages.getRecords();
        return new Result().toSuccess(testRecheckVoIPage);
    }



    /**
     * 试验复核-转销售
     * @param changeOrderDto
     * @return
     */
    @Override
    public Result changeOrder(UfcChangeOrderDto changeOrderDto) {
        if (EmptyUtil.isEmpty(changeOrderDto.getLmTdsFk())){
            return new Result().toFailure(ResultCodeEnum.Valid_PARAM);
        }
        UfcLmTds lmTds = this.lmTdsService.getOne(new LambdaQueryWrapper<UfcLmTds>().eq(UfcLmTds::getLmTdsoid,changeOrderDto.getLmTdsFk()).eq(UfcLmTds::getZt,"C"));
        if (EmptyUtil.isEmpty(lmTds)){
            return new Result().toFailure(ResultCodeEnum.LMERROR20011);
        }
        UfcLmTdsSo lmTdsSo = new UfcLmTdsSo();
        BeanUtils.copyProperties(changeOrderDto,lmTdsSo);
        if (EmptyUtil.isEmpty(lmTdsSo.getLmTdsSoOid())){
            lmTdsSo.setLmTdsSoOid(SnowflakeIdUtils.generate());
        }
        boolean save = this.lmTdsSoService.save(lmTdsSo);
        if (save){
            return new Result().toSuccess();
        }
        return new Result().toFailure(ResultCodeEnum.LMERROR20001);
    }
}
