package com.jln.ufc.web.action.ufc.ps.pojo;

import com.baomidou.mybatisplus.annotation.*;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jln.common.constant.LocalDateTimeConst;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;

import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 *
 * </p>
 *
 * @author
 * @since 2020-02-23
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel("工单汇报实体")
@TableName("ps_wbrpt")
public class UfcPsWbrpt extends Model<UfcPsWbrpt> {

    private static final long serialVersionUID = 1L;


    @ApiModelProperty(example = "生产工单汇报主键", hidden = true, dataType = "Long")
    @TableId(value = "ps_wbrptoid", type = IdType.INPUT)
    private Long psWbrptoid;

    @Length(max = 100, message = "工票号不能超过12位")
    @ApiModelProperty(example = "GP-GW001", value = "工票号", required = true, dataType = "string")
    private String gpid;

    @Length(max = 500, message = "二维码不能超过500位")
    @ApiModelProperty(example = "二维码", required = true, dataType = "string")
    private String ewm;


    @NotEmpty(message = "车间汇报号不能为空")
    @Length(max = 50, message = "车间汇报号不能超过50位")
    @ApiModelProperty(example = "CSCJ-GW0001", value = "车间汇报号", required = true, dataType = "string")
    private String rptid;

    @NotEmpty(message = "工票类别不能为空")
    @ApiModelProperty(example = "F", value = "工票类别:c|产品工票g|返工工票f|补废工票l|零星工票", required = true, dataType = "string")
    private String gplb;

    @NotNull(message = "反馈日期不能为空")
    @ApiModelProperty(example = "2020-02-23 15:32:00", value = "反馈日期", required = true, dataType = "string")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    @TableField( updateStrategy = FieldStrategy.IGNORED)
    private LocalDateTime fkrq;


    @ApiModelProperty(example = "2020-02-23 15:32:00", value = "实际开工日期", required = true, dataType = "string")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDate sjkgrq;


    @ApiModelProperty(example = "2020-02-23 15:32:00", value = "实际完工日期", required = true, dataType = "string")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate sjwgrq;

    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "合格数量", required = true, dataType = "BigDecimal")
    private BigDecimal hgsl;

    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "回用数量", required = true, dataType = "BigDecimal")
    private BigDecimal hysl;

    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "返工数量", required = true, dataType = "BigDecimal")
    private BigDecimal fgsl;

    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "废品数量", required = true, dataType = "BigDecimal")
    private BigDecimal fpsl;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "料废数量", required = true, dataType = "BigDecimal")
    private BigDecimal lfsl;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "入库单数量", required = true, dataType = "BigDecimal")
    private BigDecimal rkdsl;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "入库数量", required = true, dataType = "BigDecimal")
    private BigDecimal rksl;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "实际加工时间s", required = true, dataType = "BigDecimal")
    private BigDecimal jgsj;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "实际准备时间", required = true, dataType = "BigDecimal")
    private BigDecimal zbsj;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0", value = "人数:反馈加工人数", required = true, dataType = "int")
    private Integer rs;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0", value = "设备数：反馈生产设备数", required = true, dataType = "int")
    private Integer sbs;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.0000", value = "人工工资:保留四位小数s", required = true, dataType = "BigDecimal")
    private BigDecimal gz;


    @DecimalMin(value = "0", message = "数量不能小于零")
    @ApiModelProperty(example = "0.000", value = "人工工时：保留三位小数", required = true, dataType = "BigDecimal")
    @TableField( updateStrategy = FieldStrategy.IGNORED)
    private BigDecimal rggs;


    @Length(max = 250, message = "备注不能超过250字")
    @ApiModelProperty(example = "备注：250字", value = "备注：250字", required = true, dataType = "string")
    private String bz;


    @Length(max = 1, message = "状态为一位")
    @ApiModelProperty(example = "I", value = "状态:i|初始、f|确认、r|下达、s|暂停、c|完成", required = true, dataType = "string")
    private String zt;


    @ApiModelProperty(example = "0", value = "最后修改人oid", hidden = true, dataType = "Long")
    private Long sysLastUpdBy;
    @TableField(exist = false)
    @ApiModelProperty(example = "0", value = "最后修改人名称", hidden = true, dataType = "Long")
    private String sysLastUpdByName;


    @ApiModelProperty(example = "2020-02-24 12:00:00", value = "维护时间", hidden = true, dataType = "string")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysLastUpd;


    @ApiModelProperty(example = "0", value = "生产工单外键", required = true, dataType = "Long")
    private Long psWbFk;


    @ApiModelProperty(example = "0", value = "是否删除：0否，1是", hidden = true, dataType = "int")
    private Integer del;

    @ApiModelProperty(value = "工单产出物料外键")
    private Long psWbOutFk;

    @ApiModelProperty(value = "反馈人外键")
    private Long fkrFk;

    @ApiModelProperty(value = "反馈人编码")
    private String fkrCode;

    @ApiModelProperty(value = "反馈人名称")
    private String fkrName;

    @ApiModelProperty(value = "订单外键")
    private Long woFk;

    @TableField( updateStrategy = FieldStrategy.IGNORED)
    @ApiModelProperty(value = "设备外键")
    private Long ufcEmEqucodoidFk;


    @Override
    protected Serializable pkVal() {
        return this.psWbrptoid;
    }

}
