package com.jln.ufc.web.action.ufc.ps.pojo;

import com.baomidou.mybatisplus.annotation.IdType;
import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jln.common.constant.LocalDateTimeConst;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.hibernate.validator.constraints.Length;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.DecimalMin;
import javax.validation.constraints.NotEmpty;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 
 * </p>
 *
 * @author 
 * @since 2020-02-21
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@ApiModel(value = "工单不合格明细实体")
@TableName("ps_wbuq")
public class UfcPsWbuq extends Model<UfcPsWbuq> {

    private static final long serialVersionUID = 1L;


    @ApiModelProperty(example = "生产工单不合格明细主键", hidden = true,dataType = "Long")
    @TableId(value = "ps_wbuqoid", type = IdType.INPUT)
    private Long psWbuqoid;

    /**
     * 数据库里面这个字段不为空
     */
//    @NotEmpty(message = "车间汇报号")
    @ApiModelProperty(example = "车间汇报号", required = true,dataType = "string")
    private String rptid;


    @ApiModelProperty(example = "不合格序号，自动递增后端生成", hidden = true,dataType = "int")
    private Integer upxh;


    @ApiModelProperty(example = "反馈日期", required = true,dataType = "date")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING,pattern = "yyyy-MM-dd")
    private LocalDate fkrq;


    @NotEmpty(message = "分类不能空")
    @ApiModelProperty(example = "分类:gf|工废lf|料废fg|返工", required = true,dataType = "string")
    private String fl;

    @DecimalMin(value = "0",message = "数量不能小于零")
    @ApiModelProperty(example = "产品工废、料废或返工的数量。", required = true,dataType = "bigDecimal")
    private BigDecimal sl;


    @ApiModelProperty(example = "发现工序号", required = true,dataType = "int")
    private String fxgxid;


    @ApiModelProperty(example = "发生工序号", required = true,dataType = "int")
    private String fsgxid;

    @Length(max =18,message = "不合格现象编码不能超过12位")
    @ApiModelProperty(example = "不合格现象编码，12位", required = true,dataType = "string")
    private String bhgxxid;

    @Length(max =100,message = "不合格现象说明不能超过100字")
    @ApiModelProperty(example = "不合格现象说明，字数限制100", required = true,dataType = "string")
    private String bhgxxmc;

    @Length(max =18,message = "不合格原因编码不能超过12位")
    @ApiModelProperty(example = "不合格原因编码，12位", required = true,dataType = "string")
    private String bhgyyid;

    @Length(max =100,message = "不合格原因说明不能超过100位")
    @ApiModelProperty(example = "不合格原因说明：100字", required = true,dataType = "string")
    private String bhgyymc;


    @ApiModelProperty(example = "报废物料外键，工废或料废的产品物料主键，缺省为生产订单的物料主键。", required = true,dataType = "string")
    private Long bfwlFk;

    @Length(max =18,message = "报废物料批号不能超过18位")
    @ApiModelProperty(example = "报废物料批号,18位s", required = true,dataType = "string")
    private String bfwlph;


    @ApiModelProperty(example = "报废材料外键", required = true,dataType = "string")
    private Long clwlFk;

    @DecimalMin(value = "0",message = "材料数量不能小于零")
    @ApiModelProperty(example = "材料数量", required = true,dataType = "string")
    private BigDecimal clsl;

    @Length(max =18,message = "报废材料料批号不能超过18")
    @ApiModelProperty(example = "报废材料批号,18位", required = true,dataType = "string")
    private String bfclph;


    @ApiModelProperty(example = "供应商外键", required = true,dataType = "Long")
    private Long bSupplierFk;

    @Length(max =250,message = "备注不能超过250字")
    @ApiModelProperty(example = "备注250字", required = true,dataType = "string")
    private String bz;

    @NotEmpty(message = "状态不能为空")
    @ApiModelProperty(example = " 状态：i|初始、f|确认、r|下达、s|暂停、c|完成", required = true,dataType = "string")
    private String zt;


    @ApiModelProperty(example = "维护人", hidden = true,dataType = "Long")
    private Long sysLastUpdBy;


    @ApiModelProperty(example = "维护时间", hidden = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysLastUpd;


    @ApiModelProperty(example = "生产工单外键", required = true,dataType = "Long")
    private Long psWbFk;

    @ApiModelProperty(example = "生产工单汇报外键", required = true,dataType = "Long")
    private Long psWbrptFk;


    @TableLogic
    @ApiModelProperty(example = "是否删除：0否，1是", hidden = true,dataType = "string")
    private Integer del;


    @Override
    protected Serializable pkVal() {
        return this.psWbuqoid;
    }

}
