package com.jln.ufc.web.action.ufc.ps.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.PsWboutEnums;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.DateUtils;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.ufc.web.action.ufc.ps.mapper.UfcPsWbMapper;
import com.jln.ufc.web.action.ufc.ps.mapper.UfcPsWboutMapper;
import com.jln.ufc.web.action.ufc.ps.pojo.UfcPsWbout;
import com.jln.ufc.web.action.ufc.ps.pojo.vo.UfcPsMfeedShow;
import com.jln.ufc.web.action.ufc.ps.pojo.vo.UfcPsWb;
import com.jln.ufc.web.action.ufc.ps.pojo.vo.UfcWbOutVo;
import com.jln.ufc.web.action.ufc.ps.service.UfcPsWboutService;
import lombok.extern.slf4j.Slf4j;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.math.BigDecimal;
import java.time.LocalDateTime;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author
 * @since 2020-02-10
 */
@Slf4j
@Service
public class UfcPsWboutServiceImpl extends ServiceImpl<UfcPsWboutMapper, UfcPsWbout> implements UfcPsWboutService {
    @Autowired
    private UfcPsWbMapper ufcPsWbMapper;

    @Override
    public Result<Page<UfcPsMfeedShow>> getAnalysisSn(PageParameter<Long> psWbFk) {
        if(EmptyUtil.isEmpty(psWbFk.getData())){
            return new Result<>().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        //查询上一道工单合格数量
        Result<Integer> result = this.getThePreviousPsWbNumber(psWbFk.getData());
        Page<UfcPsMfeedShow> snPage = this.baseMapper.getAnalysisSnPage(new Page(psWbFk.getPageNum(), psWbFk.getPageSize()), psWbFk.getData(),null);
        if(0!=snPage.getRecords().size()){
            snPage.getRecords().forEach(
                    psMfeedShow -> {
                        psMfeedShow.setTlwlph(psMfeedShow.getSn());
                        psMfeedShow.setTlxlh(psMfeedShow.getSn());
                        psMfeedShow.setTlsl(new BigDecimal(result.getData()==null?0:result.getData()));
                    }
            );
        }

        return new Result<Page<UfcPsMfeedShow>>().toSuccess(snPage);
    }

    @Override
    public Result complete(Long id, User user) {
        if(EmptyUtil.isEmpty(id)){
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        UfcPsWbout byId = this.getById(id);
        if(EmptyUtil.isEmpty(byId)){
            return new Result().toFailure("当前已被删除，或有误!");
        }
        if(EmptyUtil.isEmpty(byId.getKgsj())){
            return new Result().toFailure("当前产出未开工，不能完工");
        }
        if(PsWboutEnums.COMPLETE.getValue().equals(byId.getZt())){
            return new Result().toFailure("当前产出已完工不能重复完工");
        }
        //1.判断当前工单产出物料是单件还是，批次
        UfcWbOutVo ufcWbOutVo = ufcPsWbMapper.getWbMaterialInfo(byId.getPsWbFk());
        Result<UfcWbOutVo> wb = new Result().setData(ufcWbOutVo);
        if(!wb.confirmSuccess()){
            return wb;
        }
        //2.如果为单件情况，开工时间-完工时间为单件工时
        Long time=System.currentTimeMillis();
        LocalDateTime now = LocalDateTime.now();
        if(wb.getData().getDjgl()){
            LocalDateTime kgsj = byId.getKgsj();
            Long dateTime = DateUtils.getTimestampOfDateTime(kgsj);
            dateTime=(time-dateTime)/1000;
            byId.setDjgs(dateTime.intValue());

        }
        //3.如果是批次情况,开工时间-完工时间/生产数量
        if(wb.getData().getPhkz()){
            LocalDateTime kgsj = wb.getData().getSjkgrq();
            Long dateTime = DateUtils.getTimestampOfDateTime(kgsj);
            dateTime=(time-dateTime)/1000;
            dateTime= BigDecimal.valueOf(dateTime).divide(wb.getData().getPcsl(),4,BigDecimal.ROUND_CEILING).longValue();
            byId.setDjgs(dateTime.intValue());
        }
        byId.setWgsj(now);
        byId.setSysLastUpdBy(user.getEmployeeOid());
        byId.setSysCreated(now);
        //设置状态为C|完工
        byId.setZt(PsWboutEnums.COMPLETE.getValue());
        int update = this.baseMapper.updateById(byId);
        if(0==update){
            return new Result().toFailure("完工失败！");
        }
        return new Result().toSuccess();
    }

    private Result<Integer> getThePreviousPsWbNumber(Long pswboid) {
        UfcPsWb pswb = ufcPsWbMapper.selectById(pswboid);
        if(EmptyUtil.isEmpty(pswb)){
            return new Result().toFailure("获取工单数据失败！");
        }
        //查询上一道工单
        Integer nextCount = null ;
        //查询上一道工单合格数量
        nextCount = ufcPsWbMapper.selectNextHgsl(pswboid);
        nextCount = nextCount == null ? 0:nextCount;
        return new Result<Integer>().setData(nextCount);
    }
}
