package com.jln.ufc.web.action.ufc.qc.entity;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableName;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonFormat;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.Size;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 
 * </p>
 *
 * @author 
 * @since 2020-02-19
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@TableName("qc_bill")
public class UfcQcBill extends Model<UfcQcBill> {

    private static final long serialVersionUID = 1L;
    @TableId("qc_billoid")
    private Long qcBilloid;

    /**
     * 检验单号

     */
    @ApiModelProperty(value = "检验单号", example = "00001")
    @NotEmpty(message = "检验单号不能为空")
    @Size(max = 18,message = "最大长度为18个字节")
    private String jydid;

    /**
     * 检验方式

     */
    @ApiModelProperty(value = "检验方式", example = "D")
    @NotEmpty(message = "检验方式不能为空")
    @Size(max = 1,message = "最大长度为1个字节")
    private String jyfs;

    /**
     * 检验部门编码

     */
    @ApiModelProperty(value = "检验方式", example = "2020-02-21")
    @Size(max = 8,message = "最大长度为8个字节")
    private String jybmid;

    /**
     * 取样日期

     */
    @ApiModelProperty(value = "取样日期",example = "2020-02-21")
    @DateTimeFormat(pattern ="yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate qyrq;

    /**
     * 检验日期

     */
    @ApiModelProperty(value = "检验日期",example = "2020-02-21")
    @DateTimeFormat(pattern ="yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate jyrq;

    /**
     * 送检母数

     */
    @ApiModelProperty(value = "送检母数",example = "0")
    private BigDecimal sjms;

    /**
     * 送检母数计量单位

     */
    @ApiModelProperty(value = "送检母数计量单位",example = "只")
    @Size(max = 8,message = "最大长度为8个字节")
    private String sjmsjldw;

    /**
     * 合格

     */
    @ApiModelProperty(value = "合格",example = "true")
    private Boolean hg;

    /**
     * 合格数量

     */
    @ApiModelProperty(value = "合格数量",example = "1")
    private BigDecimal hgsl;

    /**
     * 序列号

     */
    @ApiModelProperty(value = "序列号",example = "1")
    @Size(max = 200,message = "最大长度为200个字节")
    private String xlh;

    /**
     * 制令号

     */
    @ApiModelProperty(value = "制令号",example = "18")
    @Size(max = 18,message = "最大长度为18个字节")
    private String zlh;

    /**
     * 子批次

     */
    @ApiModelProperty(value = "子批次",example = "true")
    private Boolean zpc;

    /**
     * 子批次数量

     */
    @ApiModelProperty(value = "子批次数量",example = "20")
    private String zpcsl;

    /**
     * 派发人

     */
    @ApiModelProperty(value = "派发人",example = "1")
    @Size(max = 30,message = "最大长度为30个字节")
    private String pfr;

    /**
     * 派发日期

     */
    @ApiModelProperty(value = "派发日期",example = "2020-02-21")
    @DateTimeFormat(pattern ="yyyy-MM-dd")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate pfrq;

    /**
     * 取样人

     */
    @ApiModelProperty(value = "取样人",example = "1")
    @Size(max = 30,message = "最大长度为30个字节")
    private String qyr;

    /**
     * 制样人

     */
    @ApiModelProperty(value = "制样人",example = "1")
    @Size(max = 30,message = "最大长度为30个字节")
    private String zyr;

    /**
     * 温度

     */
    @ApiModelProperty(value = "温度",example = "1")
    @Size(max = 100,message = "最大长度为100个字节")
    private String wd;

    /**
     * 湿度
     */
    @ApiModelProperty(value = "湿度",example = "1")
    @Size(max = 100,message = "最大长度为100个字节")
    private String sd;

    /**
     * 气压

     */
    @ApiModelProperty(value = "气压",example = "1")
    @Size(max = 100,message = "最大长度为100个字节")
    private String qy;

    /**
     * 备注

     */
    @ApiModelProperty(value = "气压",example = "1")
    @Size(max = 255,message = "最大长度为255个字节")
    private String bz;


    /***
     * 状态
     */
    @ApiModelProperty(value = "状态",example = "1")
    @Size(max = 255,message = "最大长度为255个字节")
    private String zt;

    @ApiModelProperty(hidden = true)
    private Integer del;

    /**
     * 维护人外键
     */
    @ApiModelProperty(hidden = true)
    private Long sysLastUpdBy;

    /**
     * 维护时间
     */
    @ApiModelProperty(hidden = true)
    private LocalDateTime sysLastUpd;

    /**
     * 检验类型外键

     */
    @ApiModelProperty(example = "根据概要设计是不需要传入的。是通过检验标准关联的",hidden = true)
    private Long qcTypeFk;

    /**
     * 检验标准外键

     */
    @ApiModelProperty(example = "检验标准外键",hidden = true)
    private Long qcStdFk;

    /**
     * 检验对象外键

     */
    @ApiModelProperty(example = "检验对象外键",hidden = true)
    private Long qcObjFk;


    @ApiModelProperty(example = "抽样方案",value = "抽样方案")
    private String cyfa;

    /**
     * 检验人外键

     */
    @ApiModelProperty(example = "检验人外键",hidden = true)
    private Long jyrFk;
    /**
     * 不合格原因

     */
    @ApiModelProperty(example = "不合格原因",value = "不合格原因")
    private String bhgyy;

    @ApiModelProperty(value = "抽样数量",example = "0")
    private BigDecimal cysl;

    @Override
    protected Serializable pkVal() {
        return this.qcBilloid;
    }

}
