package com.jln.ufc.web.action.ufc.qc.entity.vo;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.jln.common.constant.LocalDateTimeConst;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;

import javax.validation.constraints.NotBlank;
import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

@Data
@ApiModel("检验项目数据层")
@JsonIgnoreProperties(ignoreUnknown = true)
public class UfcQcitemInfo {

    /**
     * 检验项目主键
     */
    @ApiModelProperty(example = "检验项目主键", required = true,dataType = "Long")
    private Long qcItemoid;

    /**
     * 检验项目编码
     */
    @NotBlank(message = "检验项目编码不能为空")
    @ApiModelProperty(example = "检验项目编码:1004", required = true,dataType = "string")
    @Size(max = 32,message = "检验类型编码最大长度为32个字节")
    private String jyxmid;

    /**
     * 检验项目名称
     */
    @NotBlank(message = "检验项目名称不能为空")
    @ApiModelProperty(example = "检验项目名称:测试项目", required = true,dataType = "string")
    @Size(max = 60,message = "检验项目名称最大长度为60个字节")
    private String jyxmmc;

    /**
     * 重要性等级
     */
    @ApiModelProperty(example = "重要性等级:重要", required = true,dataType = "string")
    private String dj;

    /**
     * 类型
     */
    @ApiModelProperty(example = "类型:普通", required = true,dataType = "string")
    private String lx;

    /**
     * 控制方式
     */
    @ApiModelProperty(example = "控制方式:普通", required = true,dataType = "string")
    private String kzfs;

    /**
     * 计量单位
     */
    @ApiModelProperty(example = "计量单位:克", required = true,dataType = "string")
    private String jldw;

    /**
     * 缺省值(数值型)
     */
    @ApiModelProperty(example = "缺省值(数值型):2", required = true,dataType = "decimal")
    private BigDecimal qszf;

    /**
     * 缺省值(字符型)
     */
    @ApiModelProperty(example = "缺省值(字符型):克", required = true,dataType = "string")
    private String qszs;

    /**
     * 缺省值(日期型)
     */


    @ApiModelProperty(example = "缺省值(日期型)：2019-12-12", required = true,dataType = "date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate qszd;

    /**
     * 枚举
     */
    @ApiModelProperty(example = "枚举:false", required = true,dataType = "bool")
    private Boolean mj;

    /**
     * 枚举列表
     */
    @ApiModelProperty(example = "枚举列表:枚举测试", required = true,dataType = "string")
    private String mjlb;

    /**
     * 缺省值(枚举型)
     */
    @ApiModelProperty(example = "缺省值(枚举型):枚举测试", required = true,dataType = "string")
    private String qszm;

    /**
     * 抽样方式
     */
    @ApiModelProperty(example = "抽样方式:枚举测试", required = true,dataType = "string")
    private String cyfs;

    /**
     * 抽样数量
     */
    @ApiModelProperty(example = "抽样数量:10", required = true,dataType = "decimal")
    private BigDecimal ybsl;

    /**
     * 抽样百分比(%)
     */
    @ApiModelProperty(example = "抽样百分比(%):10", required = true,dataType = "decimal")
    private BigDecimal bfb;

    /**
     * 抽样标准
     */
    @ApiModelProperty(example = "抽样标准:正常", required = true,dataType = "string")
    private String cybz;

    /**
     * 检查水平
     */
    @ApiModelProperty(example = "检查水平:正常", required = true,dataType = "string")
    private String jcsp;

    /**
     * aql值
     */
    @ApiModelProperty(example = "aql值:10", required = true,dataType = "decimal")
    private BigDecimal aql;

    /**
     * 判别水平
     */
    @ApiModelProperty(example = "判别水平:正常", required = true,dataType = "string")
    private String pbsp;

    /**
     * rql值
     */
    @ApiModelProperty(example = "rql值:10", required = true,dataType = "decimal")
    private BigDecimal rql;

    /**
     * 最小样本数量
     */
    @ApiModelProperty(example = "最小样本数量:10", required = true,dataType = "decimal")
    private BigDecimal zxybsl;

    /**
     * 小数位数
     */
    @ApiModelProperty(example = "小数位数:10", required = true,dataType = "decimal")
    private BigDecimal xsws;

    /**
     * 计算公式
     */
    @ApiModelProperty(example = "计算公式:a*b", required = true,dataType = "string")
    private String jsgs;

    /**
     * 检验方法
     */
    @ApiModelProperty(example = "检验方法:抽样", required = true,dataType = "string")
    private String jyff;

    /**
     * 检验内容及要求
     */
    @ApiModelProperty(example = "检验内容及要求:抽样", required = true,dataType = "string")
    private String jynr;

    /**
     * 启用日期
     */
    @ApiModelProperty(example = "启用日期：2019-12-12", required = true,dataType = "date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate qyrq;

    /**
     * 停用日期
     */
    @ApiModelProperty(example = "停用日期：2019-12-12", required = true,dataType = "date")
    @JsonFormat(pattern = "yyyy-MM-dd")
    private LocalDate tyrq;

    /**
     * 停用标志
     */
    @ApiModelProperty(example = "停用标志:默认false", required = true,dataType = "bool")
    private Boolean tybz;

    /**
     * 备注
     */
    @ApiModelProperty(example = "备注:测试", required = true,dataType = "string")
    private String bz;

    /**
     * 状态
     */
    @ApiModelProperty(example = "状态:默认I", required = true,dataType = "string")
    private String zt;


    @ApiModelProperty(example = "创建日期：2019-12-12 10:10:10", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    /**
     * 创建日期
     */
    private LocalDateTime sysCreated;

    @ApiModelProperty(example = "维护人姓名:不需添加", required = true,dataType = "string")
    private String   employeename ;

    @ApiModelProperty(value = "检验项目分类外键")
    private Long qcItemClassFk;

    @ApiModelProperty(value = "分类代码")
    private String qcItemClassBarcode;

    @ApiModelProperty(value = "检验项目分类编码")
    private String qcItemClassCode;

    @ApiModelProperty(value = "检验项目分类名称")
    private String qcItemClassName;
    @ApiModelProperty(value = "技术要求")
    private String jsyq;
}
