package com.jln.ufc.web.action.ufc.qc.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.core.conditions.update.UpdateWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.annotation.ValidationRulesRepetition;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.commonweb.parameterize.service.SysBusinessService;
import com.jln.system.web.action.commonweb.parameterize.validation.ValidationRules;
import com.jln.ufc.web.action.ufc.qc.entity.UfcQcItem;
import com.jln.ufc.web.action.ufc.qc.entity.UfcQcStdmx;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcQcitemInfo;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcUpBatchQcItemClass;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcItemMapper;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcStdmxMapper;
import com.jln.ufc.web.action.ufc.qc.service.UfcQcItemService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.sql.Timestamp;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.Date;
import java.util.List;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author
 * @since 2020-02-25
 */
@Service
public class UfcQcItemServiceImpl extends ServiceImpl<UfcQcItemMapper, UfcQcItem> implements UfcQcItemService, ValidationRules<UfcQcItem> {
    @Autowired
    private UfcQcItemMapper bQcItemMapper;    //工位业务逻辑

    @Autowired
    private UfcQcItemService bQcItemService;    //工位业务逻辑

    @Autowired
    private SysBusinessService sysBusinessService;

    @Autowired
    private UfcQcStdmxMapper qcStdmxMapper;

    @Override
    public Result<UfcQcitemInfo> getdetailbyoid(Long b_standardprocessoid) {
        if (EmptyUtil.isEmpty(b_standardprocessoid)) {
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        UfcQcitemInfo bStandardprocessInfoPage = bQcItemMapper.selectbyid(b_standardprocessoid);
        if (EmptyUtil.isEmpty(bStandardprocessInfoPage)) {
            return new Result().toFailure(ResultCodeEnum.LOOK_UP_TO);
        } else {
            return new Result<UfcQcitemInfo>().toSuccess(bStandardprocessInfoPage);
        }
    }

    @Override
    public Result<Page<UfcQcItem>> selectIsuse() {
        Page<UfcQcItem> bFactoryPage = new Page<>();
        LambdaQueryWrapper<UfcQcItem> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(UfcQcItem::getDel, 0);
        queryWrapper.le(UfcQcItem::getQyrq, LocalDateTime.now());
        queryWrapper.and(wrapper -> wrapper.gt(UfcQcItem::getTyrq, LocalDateTime.now()).or().eq(UfcQcItem::getTyrq, "").or().isNull(UfcQcItem::getTyrq));
        queryWrapper.eq(UfcQcItem::getTybz, false);
        Page<UfcQcItem> bFactorylist = bQcItemMapper.selectPage(bFactoryPage, queryWrapper);
        // 停用状态为未停用，启用时间小于等于当前时间并且没有设置停用时间或者停用数据大于等于当前时间
        return new Result<Page<UfcQcItem>>().toSuccess(bFactorylist);
    }

    @Override
    public Result selectQcItem(List<Long> list) {
        if (EmptyUtil.isEmpty(list)){
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        LambdaQueryWrapper<UfcQcStdmx> qcStdLambdaQueryWrapper = new LambdaQueryWrapper<>();
        qcStdLambdaQueryWrapper.in(UfcQcStdmx::getQcItemFk,list);
        List<UfcQcStdmx> qcStdmxes = qcStdmxMapper.selectList(qcStdLambdaQueryWrapper);
        if (qcStdmxes.size()>0){
            return new Result().toFailure(ResultCodeEnum.QCERROR14024);
        }
        return new Result().toSuccess();
    }

    @Override
    public Result<Page<UfcQcitemInfo>> selectPage(PageParameter<Long> page) {
        Page<UfcQcitemInfo> bStandardprocessInfoPage = bQcItemMapper.selectPages(new Page<>(page.getPageNum(), page.getPageSize()),page.getData());
        return new Result<Page<UfcQcitemInfo>>().toSuccess(bStandardprocessInfoPage);
    }

//    @ValidationRulesRepetition(value = "QCK002",isList=false ,idIndex = 0,isSuperclass = false)
    @Override
    public Result save(UfcQcitemInfo bQcitemInfo, User user) {
        //实体类入参判空
        if (EmptyUtil.isEmpty(bQcitemInfo)) {
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        QueryWrapper<UfcQcItem> QueryWrapper = new QueryWrapper<>();
        QueryWrapper.eq("qc_itemoid", bQcitemInfo.getQcItemoid());
        UfcQcItem tbPaperType = bQcItemMapper.selectOne(QueryWrapper);
        if (EmptyUtil.isEmpty(tbPaperType)) {
            //添加
            QueryWrapper<UfcQcItem> CheckID = new QueryWrapper<>();
            CheckID.eq("jyxmid", bQcitemInfo.getJyxmid());
            CheckID.eq("del", 0);
            int querycount = bQcItemMapper.selectCount(CheckID);
            if (querycount > 0) {
                return new Result().toFailure(ResultCodeEnum.SYSERROR17002);
            }
            UfcQcItem detail = new UfcQcItem();
            detail.setQcItemoid(SnowflakeIdUtils.generate());
            detail.setJyxmid(bQcitemInfo.getJyxmid());
            detail.setAql(bQcitemInfo.getAql());
            detail.setBfb(bQcitemInfo.getBfb());
            detail.setDel(0);
            detail.setBz(bQcitemInfo.getBz());
            detail.setCybz(bQcitemInfo.getCybz());
            detail.setCyfs(bQcitemInfo.getCyfs());
            detail.setDj(bQcitemInfo.getDj());
            detail.setJcsp(bQcitemInfo.getJcsp());
            detail.setJldw(bQcitemInfo.getJldw());
            detail.setJsgs(bQcitemInfo.getJsgs());
            detail.setJyff(bQcitemInfo.getJyff());
            detail.setJynr(bQcitemInfo.getJynr());
            detail.setJyxmmc(bQcitemInfo.getJyxmmc());
            detail.setKzfs(bQcitemInfo.getKzfs());
            detail.setSysCreated(LocalDateTime.now());
            detail.setLx(bQcitemInfo.getLx());
            detail.setTybz(bQcitemInfo.getTybz());
            detail.setMj(bQcitemInfo.getMj());
            detail.setQyrq(LocalDate.now());
            detail.setTyrq(bQcitemInfo.getTyrq());
            detail.setMjlb(bQcitemInfo.getMjlb());
            detail.setPbsp(bQcitemInfo.getPbsp());
            detail.setQszd(bQcitemInfo.getQszd());
            detail.setQszf(bQcitemInfo.getQszf());
            detail.setQszm(bQcitemInfo.getQszm());
            detail.setQszs(bQcitemInfo.getQszs());
            detail.setRql(bQcitemInfo.getRql());
            detail.setXsws(bQcitemInfo.getXsws());
            detail.setYbsl(bQcitemInfo.getYbsl());
            detail.setZxybsl(bQcitemInfo.getZxybsl());
            detail.setZt("I");
            detail.setYbsl(bQcitemInfo.getYbsl());
            detail.setSysPostn(user.getPostOid());
            detail.setSysDivision(user.getDivisionOid());
            detail.setSysOrg(user.getOrgOid());
            detail.setSysCreatedBy(user.getEmployeeOid());
            detail.setSysLastUpdBy(user.getEmployeeOid());
            detail.setQcItemClassFk(bQcitemInfo.getQcItemClassFk());
            detail.setQcItemClassBarcode(bQcitemInfo.getQcItemClassBarcode());
            detail.setJsyq(bQcitemInfo.getJsyq());
            verify("QCK004",detail);
            int insert = bQcItemMapper.insert(detail);
            if (0 == insert) {
                return new Result().toFailure(ResultCodeEnum.CREARE_FAILURE);
            }
        } else {
            //更新
            tbPaperType.setAql(bQcitemInfo.getAql());
            tbPaperType.setBfb(bQcitemInfo.getBfb());
            tbPaperType.setBz(bQcitemInfo.getBz());
            tbPaperType.setCybz(bQcitemInfo.getCybz());
            tbPaperType.setCyfs(bQcitemInfo.getCyfs());
            tbPaperType.setDj(bQcitemInfo.getDj());
            tbPaperType.setJcsp(bQcitemInfo.getJcsp());
            tbPaperType.setJldw(bQcitemInfo.getJldw());
            tbPaperType.setJsgs(bQcitemInfo.getJsgs());
            tbPaperType.setJyff(bQcitemInfo.getJyff());
            tbPaperType.setJynr(bQcitemInfo.getJynr());
            tbPaperType.setJyxmmc(bQcitemInfo.getJyxmmc());
            tbPaperType.setKzfs(bQcitemInfo.getKzfs());
            tbPaperType.setLx(bQcitemInfo.getLx());
            tbPaperType.setSysLastUpdBy(user.getEmployeeOid());
            tbPaperType.setTybz(bQcitemInfo.getTybz());
            tbPaperType.setMj(bQcitemInfo.getMj());
            tbPaperType.setQyrq(bQcitemInfo.getQyrq());
            tbPaperType.setTyrq(bQcitemInfo.getTyrq());
            tbPaperType.setMjlb(bQcitemInfo.getMjlb());
            tbPaperType.setPbsp(bQcitemInfo.getPbsp());
            tbPaperType.setQszd(bQcitemInfo.getQszd());
            tbPaperType.setQszf(bQcitemInfo.getQszf());
            tbPaperType.setQszm(bQcitemInfo.getQszm());
            tbPaperType.setQszs(bQcitemInfo.getQszs());
            tbPaperType.setRql(bQcitemInfo.getRql());
            tbPaperType.setXsws(bQcitemInfo.getXsws());
            tbPaperType.setYbsl(bQcitemInfo.getYbsl());
            tbPaperType.setZxybsl(bQcitemInfo.getZxybsl());
            tbPaperType.setQcItemClassFk(bQcitemInfo.getQcItemClassFk());
            tbPaperType.setJsyq(bQcitemInfo.getJsyq());

            tbPaperType.setYbsl(bQcitemInfo.getYbsl());
            int update = bQcItemMapper.update(tbPaperType, QueryWrapper);
            if (0 == update) {
                return new Result().toFailure(ResultCodeEnum.UPDATE_EXCEPTION);
            }
        }
        return new Result().toSuccess(ResultCodeEnum.SUCCESS);
    }

    @Override
    public Result deletes(List<Long> list) {
        if (EmptyUtil.isEmpty(list)) {//判断传入的值
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        UpdateWrapper<UfcQcItem> wrapper = new UpdateWrapper();
        wrapper.in("qc_itemoid", list);
        wrapper.set("del", 1);
        boolean update = bQcItemService.update(wrapper);
        if (update) {
            return new Result().toSuccess(ResultCodeEnum.SUCCESS);
        } else {
            return new Result().toFailure(ResultCodeEnum.UPDATE_EXCEPTION);
        }
    }

    @Override
    public Result blockups(List<Long> list) {
        if (EmptyUtil.isEmpty(list)) {//判断传入的值
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        Date time = new Date();
        Timestamp timestamp = new Timestamp(time.getTime());
        UpdateWrapper<UfcQcItem> wrapper = new UpdateWrapper();
        wrapper.in("qc_itemoid", list);
        wrapper.set("tybz", 1);
        wrapper.set("tyrq", timestamp);
        boolean update = bQcItemService.update(wrapper);
        if (update) {
            return new Result().toSuccess(ResultCodeEnum.SUCCESS);
        } else {
            return new Result().toFailure(ResultCodeEnum.UPDATE_EXCEPTION);
        }
    }


    @Override
    public void verify(String code, User user, UfcQcItem paramers) throws CustomException {

    }

    @Override
    public void verify(String code, UfcQcItem paramers) throws CustomException {
        //TODO  调用用户查询  当前编码值  查询出值是否什么内容
        Result<List<Object>> ruleValue = sysBusinessService.getdefaultValue(code);
        if(!ruleValue.confirmSuccess()){
            throw new CustomException(ruleValue.getCode(),ruleValue.getMsg());
        }
        if ("QCK004".equals(code)){
            String o = ruleValue.getData().get(0).toString();
            if ("N".equals(o)){
                if (EmptyUtil.isEmpty(paramers.getXsws())){
                    return;
                }
                throw new CustomException(ResultCodeEnum.QCERROR14020);
            }else {
                return;
            }
        }
    }

    @Override
    public Result upBatchQcItemClass(UfcUpBatchQcItemClass upBatchQcItemClass) {
        List<UfcQcItem> qcItems = this.baseMapper.selectBatchIds(upBatchQcItemClass.getList());
        for (UfcQcItem qcItem : qcItems) {
            qcItem.setQcItemClassFk(upBatchQcItemClass.getQcItemClassFk());
            qcItem.setQcItemClassBarcode(upBatchQcItemClass.getQcItemClassBarcode());
        }
        boolean update = this.updateBatchById(qcItems);
        if (update) {
            return new Result().toSuccess(ResultCodeEnum.SUCCESS);
        } else {
            return new Result().toFailure(ResultCodeEnum.UPDATE_EXCEPTION);
        }
    }

}
