package com.jln.ufc.web.action.ufc.qc.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialPropertyGroupService;
import com.jln.ufc.web.action.ufc.qc.entity.UfcQcRule;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcQcRuleSelectInfo;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcQcRuleView;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcRuleMapper;
import com.jln.ufc.web.action.ufc.qc.service.UfcQcRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;

/**
 * @author: Luca.Liu
 * @date: 2022/3/11
 */
@Service
public class UfcQcRuleServiceImpl extends ServiceImpl<UfcQcRuleMapper, UfcQcRule> implements UfcQcRuleService {

    @Autowired
    private UfcQcRuleMapper ufcQcRuleMapper;

    @Autowired
    private UfcBMaterialPropertyGroupService bMaterialPropertyGroupService;
    
    @Override
    public Result<Page<UfcQcRuleView>> getQcRuleList(Page<UfcQcRuleView> page, UfcQcRuleSelectInfo qcRuleSelectInfo) {
        Page<UfcQcRuleView> qcRuleView = page.setRecords(ufcQcRuleMapper.getQcRuleList(page, qcRuleSelectInfo));
        if (qcRuleView.getRecords().size() > 0) {
            bMaterialPropertyGroupService.packedAbsorber(qcRuleView);
        }
        return new Result<Page<UfcQcRuleView>>().toSuccess(qcRuleView);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveQcRule(UfcQcRule qcRule, User user) {
        if (EmptyUtil.isEmpty(qcRule) || EmptyUtil.isEmpty(user)) {
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        if (EmptyUtil.isEmpty(qcRule.getQcRuleoid())) {
            qcRule.setQcRuleoid(SnowflakeIdUtils.generate());
            qcRule.setSysCreatedBy(user.getEmployeeOid());//token获取
            qcRule.setSysCreated(LocalDateTime.now());
            qcRule.setDel(0);
        }
        Integer integer = this.baseMapper.selectCount(new LambdaQueryWrapper<UfcQcRule>()
                .ne(UfcQcRule::getQcRuleoid, qcRule.getQcRuleoid())
                .eq(UfcQcRule::getBMaterialFk, qcRule.getBMaterialFk())
                .eq(UfcQcRule::getBStandardprocessFk, qcRule.getBStandardprocessFk())
                .eq(UfcQcRule::getQcTypeFk, qcRule.getQcTypeFk())
        );
        if(integer > 0){
            return new Result().toFailure("该物料同一工序不允许添加相同类型的检验标准");
        }
        qcRule.setSysLastUpdBy(user.getEmployeeOid());//token获取
        qcRule.setSysLastUpd(LocalDateTime.now());
        this.saveOrUpdate(qcRule);
        return new Result().toSuccess(qcRule.getQcRuleoid());
    }
}
