package com.jln.ufc.web.action.ufc.qc.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.commonweb.parameterize.validation.ValidationRules;
import com.jln.ufc.web.action.ufc.bm.entity.UfcBFactory;
import com.jln.ufc.web.action.ufc.bm.entity.vo.UfcBMaterialView;
import com.jln.ufc.web.action.ufc.bm.mapper.UfcBFactoryMapper;
import com.jln.ufc.web.action.ufc.qc.entity.*;
import com.jln.ufc.web.action.ufc.qc.entity.vo.*;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcRuleMapper;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcStdMapper;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcStdmxMapper;
import com.jln.ufc.web.action.ufc.qc.service.UfcHmQcStdService;
import com.jln.ufc.web.action.ufc.qc.service.UfcQcItemService;
import com.jln.ufc.web.action.ufc.qc.service.UfcQcStdService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 * 服务实现类
 * </p>
 *
 * @author
 * @since 2020-02-25
 */
@Service
public class UfcQcStdServiceImpl extends ServiceImpl<UfcQcStdMapper, UfcQcStd> implements UfcQcStdService, ValidationRules<UfcQcStd> {

    @Autowired
    private UfcHmQcStdService ufcHmQcStdService;

    @Autowired
    private UfcQcStdmxMapper qcStdmxMapper;

    @Autowired
    private UfcQcItemService ufcQcItemService;

    @Autowired
    private UfcQcRuleMapper qcRuleMapper;

    @Autowired
    private UfcBFactoryMapper ufcBFactoryMapper;

    @Override
    public Result<UfcQcStdView> getQcStd(Page<UfcQcStdmxView> page, UfcQcStdDetailInfo qcStdSelectInfo) {
        if (EmptyUtil.isEmpty(qcStdSelectInfo.getQcStdoid())) {
            return new Result().toFailure(ResultCodeEnum.QCERROR14004);
        }
        UfcQcStdView qcStdView;
        Page<UfcQcStdmxView> qcStdmxView;
        if (qcStdSelectInfo.getIsDerive().equals("0")) {
            qcStdView = this.baseMapper.getQcStd(qcStdSelectInfo.getQcStdoid());
            qcStdmxView = page.setRecords(this.baseMapper.getQcStdmxList(page, qcStdSelectInfo));
        } else {
            qcStdView = this.baseMapper.getQcStdDerive(qcStdSelectInfo.getQcStdoid());
            qcStdmxView = page.setRecords(this.baseMapper.getQcStdmxDeriveList(page, qcStdSelectInfo));
        }
        if (qcStdmxView.getSize() > 0) {
            qcStdView.setQcStdmxViewPage(qcStdmxView);
        }
        return new Result<UfcQcStdView>().toSuccess(qcStdView);
    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result saveQcStd(UfcQcStd qcStd, User user) {
        if (EmptyUtil.isEmpty(qcStd)) {
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        UfcHmQcStd ufcHmQcStd = new UfcHmQcStd();
        if (EmptyUtil.isEmpty(qcStd.getQcStdoid())) {
            //编号是否重复
            if (qcStd.getJybzid() != null && !qcStd.getJybzid().isEmpty()) {
                UfcQcStd qcStd1 = this.baseMapper.selectOne(new QueryWrapper<UfcQcStd>().eq("jybzid", qcStd.getJybzid()).eq("version", qcStd.getVersion()));
                if (qcStd1 != null) {
                    return new Result<>().toFailure(ResultCodeEnum.QCERROR14002);
                }
            }
            qcStd.setQcStdoid(SnowflakeIdUtils.generate());
            qcStd.setSysCreatedBy(user.getEmployeeOid());//token获取
            qcStd.setSysLastUpdBy(user.getEmployeeOid());
            qcStd.setSysLastUpd(LocalDateTime.now());
            qcStd.setSysCreated(LocalDateTime.now());
            qcStd.setDel(0);
            this.baseMapper.insert(qcStd);
            ufcHmQcStd.setQcStdOid(qcStd.getQcStdoid());
        } else {
            //编号是否重复
            if (qcStd.getJybzid() != null && !qcStd.getJybzid().isEmpty()) {
                UfcQcStd qcStd1 = this.baseMapper.selectOne(new QueryWrapper<UfcQcStd>().eq("jybzid", qcStd.getJybzid()).eq("version", qcStd.getVersion()).ne("qc_stdoid", qcStd.getQcStdoid()));
                if (qcStd1 != null) {
                    return new Result<>().toFailure(ResultCodeEnum.QCERROR14003);
                }
            }
            List<String> qcStdmxoids = new ArrayList<>();
            qcStd.setSysLastUpdBy(user.getEmployeeOid());//token获取
            qcStd.setSysLastUpd(LocalDateTime.now());
            qcStd.setVersion(qcStd.getVersion());
            this.baseMapper.update(qcStd, new QueryWrapper<UfcQcStd>().eq("qc_stdoid", qcStd.getQcStdoid()));
            ufcHmQcStd.setQcStdOid(qcStd.getQcStdoid());
        }
        ufcHmQcStd.setZxbz(qcStd.getZxbz());
        ufcHmQcStdService.saveOrUpdate(ufcHmQcStd);
        return new Result().toSuccess(qcStd.getQcStdoid());
    }

    @Override
    public Result<Page<UfcQcStdView>> getQcStdList(Page<UfcQcStdView> page, UfcQcStdSelectInfo qcStdSelectInfo) {
        Page<UfcQcStdView> qcStdView = page.setRecords(this.baseMapper.getQcStdList(page, qcStdSelectInfo));
        return new Result<Page<UfcQcStdView>>().toSuccess(qcStdView);
    }

    @Override
    @Transactional
    public Result saveQcStdmx(UfcQcStdmx qcStdmx, User user) {
        UfcQcStd qcStd = new UfcQcStd();
        qcStd.setQcStdoid(qcStdmx.getQcStdFk());
        if (EmptyUtil.isEmpty(qcStdmx.getQcStdmxoid())) {
            qcStdmx.setQcStdmxoid(SnowflakeIdUtils.generate());
            qcStdmx.setSysCreatedBy(user.getEmployeeOid());//token获取
            qcStdmx.setSysLastUpdBy(user.getEmployeeOid());
            qcStdmx.setSysLastUpd(LocalDateTime.now());
            qcStdmx.setSysCreated(LocalDateTime.now());
            qcStdmx.setDel(0);
            int insert = qcStdmxMapper.insert(qcStdmx);
            if (0 == insert) {
                return new Result().toFailure(ResultCodeEnum.CREARE_FAILURE);
            }
        } else {
            qcStdmx.setSysLastUpdBy(user.getEmployeeOid());//token获取
            qcStdmx.setSysLastUpd(LocalDateTime.now());
            qcStdmx.setVersion(qcStdmx.getVersion());
            int qc_stdmxoid = qcStdmxMapper.update(qcStdmx, new QueryWrapper<UfcQcStdmx>().eq("qc_stdmxoid", qcStdmx.getQcStdmxoid()));
            if (0 == qc_stdmxoid) {
                return new Result().toFailure(ResultCodeEnum.UPDATE_EXCEPTION);
            }
        }
        if(!EmptyUtil.isEmpty(qcStdmx.getQcItemFk())){
            UfcQcItem ufcQcItem = new UfcQcItem();
            ufcQcItem.setQcItemoid(qcStdmx.getQcItemFk());
            ufcQcItem.setJsyq(qcStdmx.getJsyq());
            ufcQcItemService.updateById(ufcQcItem);
        }
        return new Result().toSuccess(ResultCodeEnum.SUCCESS);

    }

    @Override
    @Transactional(rollbackFor = Exception.class)
    public Result addQcRule(UfcQcRuleInfo qcRuleInfo, User user) {
        //不分页取出数据
        List<UfcBMaterialView> bMaterials = null;
        if(!EmptyUtil.isEmpty(qcRuleInfo.getFactoryOid())){
            bMaterials = this.baseMapper.getBMaterials(qcRuleInfo.getMaterial(),qcRuleInfo.getFactoryOid());
        }else{
            bMaterials = this.baseMapper.getBMaterials(qcRuleInfo.getMaterial(),null);
        }

        //提取物料外键oid
        List<Long> collect = bMaterials.stream().map(UfcBMaterialView::getBMaterialoid).collect(Collectors.toList());
        UfcQcRule qcRule = qcRuleInfo.getQcRule();
        if (collect.size() > 0) {
            qcRule.setDel(0);
            qcRule.setSysCreatedBy(user.getEmployeeOid());//token获取
            qcRule.setSysLastUpdBy(user.getEmployeeOid());
            qcRule.setSysLastUpd(LocalDateTime.now());
            qcRule.setSysCreated(LocalDateTime.now());
            for (Long item : collect) {
                //根据物料编码、工厂主键、检验类型、工序、检验标准 查询检验规程是否存在
                UfcQcRule check = null;
                try {
                    check = qcRuleMapper.checkSelect(item, qcRuleInfo.getFactoryOid(), qcRuleInfo.getQcRule().getQcTypeFk(), qcRuleInfo.getQcRule().getBStandardprocessFk(), qcRuleInfo.getQcRule().getQcStdFk());
                }catch (Exception e){
                    new Result().toFailure("数据有误，请先删除重复数据！");
                }
                if(!EmptyUtil.isEmpty(check)){
                    continue;
                }
                qcRule.setQcRuleoid(SnowflakeIdUtils.generate());
                qcRule.setBMaterialFk(item);
                qcRuleMapper.insert(qcRule);
            }
        } else {
            return new Result().toFailure(ResultCodeEnum.QCERROR14005);
        }
        return new Result().toSuccess(ResultCodeEnum.SUCCESS);
    }

    @Override
    public void verify(String code, User user, UfcQcStd paramers) throws CustomException {

    }

    @Override
    public void verify(String code, UfcQcStd paramers) throws CustomException {

    }
}
