package com.jln.ufc.web.action.ufc.qc.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.enums.ResultCodeEnum;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.ufc.web.action.ufc.bm.service.UfcBMaterialPropertyGroupService;
import com.jln.ufc.web.action.ufc.qc.entity.UfcQcTyRule;
import com.jln.ufc.web.action.ufc.qc.entity.UfcQcTyRuleBill;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcQcRuleSelectInfo;
import com.jln.ufc.web.action.ufc.qc.entity.vo.UfcQcRuleView;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcTyRuleBillMapper;
import com.jln.ufc.web.action.ufc.qc.mapper.UfcQcTyRuleMapper;
import com.jln.ufc.web.action.ufc.qc.service.UfcQcTyRuleService;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import java.time.LocalDateTime;
import java.util.List;

/**
 * <p>
 * 通用规程 服务实现类
 * </p>
 *
 * @author 
 * @since 2022-04-29
 */
@Service
public class UfcQcTyRuleServiceImpl extends ServiceImpl<UfcQcTyRuleMapper, UfcQcTyRule> implements UfcQcTyRuleService {

    @Autowired
    private UfcQcTyRuleBillMapper ufcQcTyRuleBillMapper;

    @Autowired
    private UfcBMaterialPropertyGroupService bMaterialPropertyGroupService;

    @Override
    public Result saveQcTyRule(UfcQcTyRule ufcQcTyRule, User user) {
        //查询工序是否已经存在
        LambdaQueryWrapper<UfcQcTyRule> checkGx = new LambdaQueryWrapper<>();
        checkGx.eq(UfcQcTyRule::getBStandardprocessFk,ufcQcTyRule.getBStandardprocessFk());
        checkGx.eq(UfcQcTyRule::getQcTypeFk,ufcQcTyRule.getQcTypeFk());
        checkGx.eq(UfcQcTyRule::getQcStdFk,ufcQcTyRule.getQcStdFk());

        if(!EmptyUtil.isEmpty(ufcQcTyRule) && !EmptyUtil.isEmpty(ufcQcTyRule.getUfcQcTyRuleoid())){
            checkGx.ne(UfcQcTyRule::getUfcQcTyRuleoid,ufcQcTyRule.getUfcQcTyRuleoid());
        }else {
            ufcQcTyRule.setUfcQcTyRuleoid(SnowflakeIdUtils.generate());
        }
        ufcQcTyRule.setSysCreated(LocalDateTime.now());
        ufcQcTyRule.setSysCreatedBy(user.getUserId());
        ufcQcTyRule.setSysLastUpd(LocalDateTime.now());
        ufcQcTyRule.setSysLastUpdBy(user.getUserId());
        ufcQcTyRule.setTyRuleBz(true);
        UfcQcTyRule checkUfcQcTyRule = this.baseMapper.selectOne(checkGx);
        if(!EmptyUtil.isEmpty(checkUfcQcTyRule)){
            return new Result().toFailure("规程已存在！");
        }
        boolean b = this.saveOrUpdate(ufcQcTyRule);
        if(b){
            return new Result().toSuccess();
        }
        return new Result().toFailure("新增失败！");
    }

    @Override
    @Transactional
    public Result delQcTyRule(List<Long> oids) {
        if(EmptyUtil.isEmpty(oids)){
            return new Result().toFailure("未选中数据！");
        }
        LambdaQueryWrapper<UfcQcTyRuleBill> wrapper = new LambdaQueryWrapper<>();
        wrapper.in(UfcQcTyRuleBill::getUfcQcTyRuleoid,oids);
        List<UfcQcTyRuleBill> list = ufcQcTyRuleBillMapper.selectList(wrapper);
        if(!EmptyUtil.isEmpty(list)){
            return new Result().toFailure("数据已被引用，不允许删除！");
        }
        int i = this.baseMapper.deleteBatchIds(oids);
        return new Result().toSuccess();
    }

    @Override
    public Result pageQcTyRule(PageParameter<UfcQcRuleSelectInfo> qcRuleSelectInfo) {
        Page page = new Page(qcRuleSelectInfo.getPageNum(),qcRuleSelectInfo.getPageSize());
        Page<UfcQcRuleView> qcRuleView = page.setRecords(this.baseMapper.getQcRuleList(page, qcRuleSelectInfo.getData()));
        if (qcRuleView.getRecords().size() > 0) {
            bMaterialPropertyGroupService.packedAbsorber(qcRuleView);
        }
        return new Result<Page<UfcQcRuleView>>().toSuccess(qcRuleView);
    }

    @Override
    public Result generalSettings(List<UfcQcTyRule> qcTyRules) {
        boolean b = this.updateBatchById(qcTyRules);
        if(b) {
            return new Result().toSuccess();
        }else {
            return new Result().toFailure("设置失败！");
        }
    }

    @Override
    public Result<UfcQcRuleView> getQcTyRule(Long qcTyRuleoid) {
        if (EmptyUtil.isEmpty(qcTyRuleoid)) {
            return new Result().toFailure(ResultCodeEnum.MISS_PARAM);
        }
        UfcQcRuleView qcRuleView = this.baseMapper.getQcTyRule(qcTyRuleoid);
        if (EmptyUtil.isEmpty(qcRuleView)) {
            return new Result().toFailure(ResultCodeEnum.LOOK_UP_TO);
        }
        //增加物料属性值
        bMaterialPropertyGroupService.packedAbsorber(qcRuleView);
        return new Result<UfcQcRuleView>().toSuccess(qcRuleView);
    }
}
