package com.jln.system.web.action.config;

import com.jln.common.config.DbEncryptionConfig;
import com.jln.common.utils.AESUtil;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.constant.CommonConfiguration;
import com.jln.common.constant.MesConfiguration;
import com.zaxxer.hikari.HikariDataSource;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.boot.context.properties.EnableConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.context.annotation.Primary;

import javax.sql.DataSource;

/**
 * @author 86180
 * @version : DataSourcesConfig, v 0.1 2020/5/9 11:43
 */
@Configuration
@EnableConfigurationProperties(DbEncryptionConfig.class)
public class DataSourcesConfig {

    @Autowired
    private DbEncryptionConfig dbEncryptionConfig;

    @Autowired
    private CommonConfiguration commonConfiguration;

    @Autowired
    private MesConfiguration mesConfiguration;

    @Bean(name="dbOne")
    @Primary
    @ConfigurationProperties(prefix = "spring.datasource.one")
    public DataSource dbOne(){
        return build(dbEncryptionConfig.getPrivateKey());
    }

    private DataSource build(String key){

        //数据库类型
        String host = mesConfiguration.getDbReleaseHost();
        //数据库类型
        String port = mesConfiguration.getDbReleasePort();
        //数据库类型
        String databaseName = mesConfiguration.getDbReleaseDatabaseName();
        //数据库类型
        String type = mesConfiguration.getDbReleaseType();
        //连接驱动,地址
        String driveClassName = "";
        String url = "";
        if(type.equals("mysql")){
            driveClassName = "com.mysql.jdbc.Driver";
            url = "jdbc:mysql://" + host + ":" + port + "/" + databaseName + "?useUnicode=true&characterEncoding=UTF-8&serverTimezone=Hongkong&allowMultiQueries=true";
        }else if(type.equals("sqlserver")){
            driveClassName = "com.microsoft.sqlserver.jdbc.SQLServerDriver";
            url = "jdbc:sqlserver://" + host + ":" + port + ";DatabaseName=" + databaseName;
        }else if(type.equals("oracle")){
            driveClassName = "oracle.jdbc.driver.OracleDriver";
            url = "jdbc:oracle:thin:@" + host + ":" + port + ":" + databaseName;
        }
        //用户名
        String username = mesConfiguration.getDbReleaseUsername();
        //密码
        String password = mesConfiguration.getDbReleasePassword();
        if(!EmptyUtil.isEmpty(key)){
            password = AESUtil.decrypt(password, key);
        }

        //配置连接池
        HikariDataSource dataSource = new HikariDataSource();
        dataSource.setDriverClassName(driveClassName);
        dataSource.setJdbcUrl(url);
        dataSource.setUsername(username);
        dataSource.setPassword(password);
        dataSource.setConnectionTimeout(commonConfiguration.getDatasourceConnectionTimeout());
        dataSource.setIdleTimeout(commonConfiguration.getDatasourceIdleTimeout());
        dataSource.setValidationTimeout(commonConfiguration.getDatasourceValidationTimeout());
        dataSource.setMaxLifetime(commonConfiguration.getDatasourceMaxLifetime());
        dataSource.setMaximumPoolSize(commonConfiguration.getDatasourceMaximumPoolSize());
        dataSource.setMinimumIdle(commonConfiguration.getDatasourceMinimumIdle());
        dataSource.setConnectionTestQuery(commonConfiguration.getDatasourceConnectionTestQuery());

        return dataSource;
    }

}
