package com.jln.system.web.action.interceptor;

import com.jln.common.constant.MesConfiguration;
import com.jln.system.web.action.utils.ApplicationContextHelper;
import lombok.extern.slf4j.Slf4j;
import org.apache.ibatis.executor.Executor;
import org.apache.ibatis.mapping.BoundSql;
import org.apache.ibatis.mapping.MappedStatement;
import org.apache.ibatis.mapping.SqlSource;
import org.apache.ibatis.plugin.*;
import org.apache.ibatis.session.ResultHandler;
import org.apache.ibatis.session.RowBounds;
import org.springframework.context.ApplicationContext;

import java.util.Properties;

/**
 * @author: Luca.Liu
 * @date: 2022/3/30
 * modified by wangjian 20220421
 */
@Slf4j
@Intercepts(
        @Signature(method = "query",
                type = Executor.class,
                args = {MappedStatement.class, Object.class, RowBounds.class, ResultHandler.class}
        )
)
public class LimitInterceptor implements Interceptor {

    private MesConfiguration mesConfiguration;
    private ApplicationContext beanFactory;

    @Override
    public Object intercept(Invocation invocation) throws Exception {
        this.loadService();
        Object[] args = invocation.getArgs();
        MappedStatement statement = (MappedStatement) args[0];
        //获取了sql执行所需的参数
        Object parameterObject = args[1];
        BoundSql boundSql = statement.getBoundSql(parameterObject);

        //从预编译中取出的sql
        String sql = boundSql.getSql();

        if (sql.toUpperCase().lastIndexOf("LIMIT") == -1) {
            return invocation.proceed();
        }
        String limit = getLimit(sql);

        // 改变sql语句
        BoundSql newBoundSql = new BoundSql(statement.getConfiguration(),limit,boundSql.getParameterMappings(), boundSql.getParameterObject());
        MappedStatement newMs = copyFromMappedStatement(statement, new BoundSqlSqlSource(newBoundSql));
        //将新的sql装入到执行器中  如果是批量查询将导致参数的重复循环
        invocation.getArgs()[0] = newMs;
        return invocation.proceed();
    }

    private MappedStatement copyFromMappedStatement(MappedStatement ms, SqlSource newSqlSource) {
        MappedStatement.Builder builder = new MappedStatement.Builder(ms.getConfiguration(), ms.getId(), newSqlSource, ms.getSqlCommandType());
        builder.resource(ms.getResource());
        builder.fetchSize(ms.getFetchSize());
        builder.statementType(ms.getStatementType());
        builder.keyGenerator(ms.getKeyGenerator());
        if (ms.getKeyProperties() != null && ms.getKeyProperties().length > 0) {
            builder.keyProperty(ms.getKeyProperties()[0]);
        }
        builder.timeout(ms.getTimeout());
        builder.parameterMap(ms.getParameterMap());
        builder.resultMaps(ms.getResultMaps());
        builder.resultSetType(ms.getResultSetType());
        builder.cache(ms.getCache());
        builder.flushCacheRequired(ms.isFlushCacheRequired());
        builder.useCache(ms.isUseCache());
        return builder.build();
    }

    public static class BoundSqlSqlSource implements SqlSource {
        private BoundSql boundSql;
        public BoundSqlSqlSource(BoundSql boundSql) {
            this.boundSql = boundSql;
        }
        @Override
        public BoundSql getBoundSql(Object parameterObject) {
            return boundSql;
        }
    }


    public String getLimit(String sql) {
        String result = "";

        String databaseProductName = mesConfiguration.getDbReleaseType();
        databaseProductName = databaseProductName.toLowerCase();
        log.error("databaseType:{}",databaseProductName);
        if ("mysql".equals(databaseProductName)) {
            return sql;
        }

        switch (databaseProductName) {
            case "mysql":
                result = "LIMIT ";
                break;
            case "oracle":
                result = "AND ROWNUM <= ";
                break;

        }

        String limit = sql.toUpperCase().replace("LIMIT", result);

        return limit;
    }

    @Override
    public Object plugin(Object target) {
        return Plugin.wrap(target, this);
    }

    @Override
    public void setProperties(Properties properties) {

    }

    private void loadService() {
        if (null == beanFactory) {
            beanFactory = ApplicationContextHelper.getApplicationContext();
            if(null == beanFactory){
                return;
            }
        }
        if(null==mesConfiguration){
            mesConfiguration = beanFactory.getBean(MesConfiguration.class);
        }
    }
}
