package com.jln.system.web.action.sm.user.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.system.web.action.sm.sm1001.pojo.vo.EmpListVo;
import com.jln.system.web.action.sm.user.entity.SysEmployee;
import com.jln.system.web.action.sm.user.mapper.SysEmployeeMapper;
import com.jln.system.web.action.sm.user.pojo.dto.EmployeeDTO;
import com.jln.system.web.action.sm.user.pojo.vo.EmployeeVo;
import com.jln.system.web.action.sm.user.service.SysEmployeeService;
import org.springframework.beans.BeanUtils;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.util.ArrayList;
import java.util.List;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author
 * @since 2020-02-15
 */
@Service
public class SysEmployeeServiceImpl extends ServiceImpl<SysEmployeeMapper, SysEmployee> implements SysEmployeeService {

    @Autowired
    private SysEmployeeMapper sysEmployeeMapper;
    
    @Override
    public String getEmpNameByoid(Long oid) {
        if(EmptyUtil.isEmpty(oid)){
            return null;
        }
        LambdaQueryWrapper<SysEmployee> wrapper=new LambdaQueryWrapper<>();
        wrapper.select(SysEmployee::getEmployeeName);
        wrapper.eq(SysEmployee::getEmployeeOid,oid);
        SysEmployee employee = getOne(wrapper);
        if(EmptyUtil.isEmpty(employee)){
            return null;
        }
        return employee.getEmployeeName();
    }

    @Override
    public Result<Page<EmpListVo>> getlist(PageParameter<EmployeeDTO> parameter) {
        LambdaQueryWrapper<SysEmployee> wrapper=new LambdaQueryWrapper<>();
        wrapper.select(SysEmployee::getJobNumber, SysEmployee::getEmployeeOid, SysEmployee::getEmployeeName, SysEmployee::getCodeing);
        if(!EmptyUtil.isEmpty(parameter.getData())){
            if(!EmptyUtil.isEmpty(parameter.getData().getEmployeeName())){
                wrapper.like(SysEmployee::getEmployeeName,parameter.getData().getEmployeeName());
            }
            if(!EmptyUtil.isEmpty(parameter.getData().getJobNumber())){
                wrapper.like(SysEmployee::getJobNumber,parameter.getData().getJobNumber());
            }
            if(!EmptyUtil.isEmpty(parameter.getData().getCodeing())){
                wrapper.like(SysEmployee::getCodeing,parameter.getData().getCodeing());
            }
        }
        Page<SysEmployee> employeePage = page(new Page<>(parameter.getPageNum(), parameter.getPageSize()), wrapper);
        if(0==employeePage.getTotal()){
            return new Result().toSuccess(new Page<EmpListVo>());
        }
        List<EmpListVo> employees=new ArrayList<>();
        Page<EmpListVo> empListVoPage=new Page<>();
        BeanUtils.copyProperties(employeePage,empListVoPage);
        for (SysEmployee record : employeePage.getRecords()) {
            Long oid = record.getEmployeeOid();
            EmpListVo listVo = new EmpListVo();
            BeanUtils.copyProperties(record,listVo);
            listVo.setEmployeeOid(oid.toString());
            employees.add(listVo);
        }
        empListVoPage.setRecords(employees);
        return new Result<Page<EmpListVo>>().toSuccess().setData(empListVoPage);
    }

    @Override
    public Result<Page<EmpListVo>> getListGwj(PageParameter<String> parameter) {
        LambdaQueryWrapper<SysEmployee> wrapper=new LambdaQueryWrapper<>();
        wrapper.select(SysEmployee::getJobNumber, SysEmployee::getEmployeeOid, SysEmployee::getEmployeeName, SysEmployee::getCodeing);
        if (!EmptyUtil.isEmpty(parameter.getData())){
            wrapper.likeRight(SysEmployee::getEmployeeName,parameter.getData());
        }
        Page<SysEmployee> employeePage = page(new Page<>(parameter.getPageNum(), parameter.getPageSize()), wrapper);
        if(0==employeePage.getTotal()){
            return new Result().toSuccess(new Page<EmpListVo>());
        }
        List<EmpListVo> employees=new ArrayList<>();
        Page<EmpListVo> empListVoPage=new Page<>();
        BeanUtils.copyProperties(employeePage,empListVoPage);
        for (SysEmployee record : employeePage.getRecords()) {
            EmpListVo listVo = new EmpListVo();
            BeanUtils.copyProperties(record,listVo);
            listVo.setEmployeeOid(record.getEmployeeOid() + "");
            employees.add(listVo);
        }
        empListVoPage.setRecords(employees);
        return new Result<Page<EmpListVo>>().toSuccess().setData(empListVoPage);
    }

    @Override
    public Result<Page<EmployeeVo>> getEmployeeList(PageParameter<EmployeeDTO> parameter) {
        Page page = new Page<>(parameter.getPageNum(), parameter.getPageSize());
        Page<EmployeeVo> employeeVoPage = sysEmployeeMapper.selectEmployeePostList(page, parameter.getData());
        List<EmployeeVo> records = employeeVoPage.getRecords();
        records.stream().forEach(vo -> {
            String post = vo.getPostList().stream().collect(Collectors.joining(","));
            vo.setPostName(post);
        });
        return new Result<Page<EmployeeVo>>().toSuccess().setData(employeeVoPage);
    }


}
