package com.jln.system.web.action.erp.gxbg.controller;

import com.jln.common.annotation.LoginUser;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.system.web.action.erp.gxbg.entity.dto.UfcWbRptJobAddDto;
import com.jln.system.web.action.erp.gxbg.service.GxBgService;
import com.jln.system.web.action.erp.gxbg.service.UfcErpPsWbrptService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.*;


@RestController
@RequestMapping("/erp/gxbg")
@Api(tags = "erp工序报工")
public class GxBgController {

    @Autowired
    private GxBgService gxBgService;

    @Autowired
    private UfcErpPsWbrptService ufcErpPsWbrptService;

    @ApiOperation(value = "erp工序报工", notes = "erp工序报工")
    @PostMapping("addReportRecord")
    public Result addReportRecord(@RequestBody List<UfcWbRptJobAddDto> dtos, @LoginUser User user) {
        try {
            return gxBgService.addReportReccord(dtos, user);
        } catch (Exception e) {
            return new Result().toFailure(e.getMessage());
        }
    }

    @ApiOperation(value = "作业反馈添加", notes = "作业反馈添加")
    @PostMapping("saveGxbg")
    public Result saveGxbg(@RequestParam Long pswboid,@RequestParam Long pswboutoid) {
        return gxBgService.saveGxbg(pswboid,pswboutoid);
    }

    @ApiOperation(value = "作业反馈--确认按钮", notes = "作业反馈--确认按钮")
    @PostMapping("erpGxbg")
    public Result erpGxbg(@RequestParam String pswbrptoid, @LoginUser User user) {
        return gxBgService.erpGxbg(pswbrptoid, user);
    }

    /**
     * erp工序汇报查询接口
     * @param fbillNo
     * @return
     */
    @ApiOperation(value = "erp工序汇报查询接口", notes = "erp工序汇报查询接口")
    @PostMapping("gxbgSelect")
    public Result gxbgSelect(@RequestParam String fbillNo) {
        return gxBgService.gxbgSelect(fbillNo);
    }


    /**
     * 工序汇报删除接口
     * @param psWbrptoids 工序反馈表主键
     * @return
     */
    @ApiOperation(value = "工序汇报删除接口", notes = "工序汇报删除接口")
    @PostMapping("del")
    public Result del(@RequestBody List<Long> psWbrptoids,@LoginUser User user) {
        return gxBgService.del(psWbrptoids,user);
    }

    /**
     *工序汇报撤销
     * @param psWbrptoid
     * @param user
     * @return
     */
    @ApiOperation(value = "工序汇报撤销", notes = "工序汇报撤销")
    @PostMapping("/countermand")
    public Result countermand(@RequestBody List<Long> psWbrptoid, @LoginUser User user){
        return gxBgService.countermand(psWbrptoid, user);
    }

    /**
     *查询工单 温度系数、质量等级、精度 字段 默认返回订单数据
     * @param pswborptoid 工序汇报主键
     * @return
     */
    @ApiOperation(value = "查询工单 温度系数、质量等级、精度 字段 默认返回订单数据", notes = "查询工单 温度系数、质量等级、精度 字段 默认返回订单数据")
    @GetMapping("/getPsWbMxInfo")
    public Result getPsWbMxInfo(@RequestParam Long pswborptoid,@RequestParam Long pswboid){
        return gxBgService.getPsWbMxInfo(pswborptoid,pswboid);
    }

    @ApiOperation(value = "查询erp精度", notes = "查询erp精度")
    @GetMapping("/getErpJd")
    public Result getErpJd() {
        return gxBgService.getErpJd();
    }

    @ApiOperation(value = "查询erp质量等级", notes = "查询erp质量等级")
    @GetMapping("/getErpZldj")
    public Result getErpZldj() {
        return gxBgService.getErpZldj();
    }

    @ApiOperation(value = "查询erp温度系数组别", notes = "查询erp温度系数组别")
    @GetMapping("/getErpWdxszb")
    public Result getErpWdxszb() {
        return gxBgService.getErpWdxszb();
    }

    @ApiOperation(value = "委外工序自动生成报工数据", notes = "委外工序自动生成报工数据")
    @PostMapping("/mesGxbg")
    public Result mesGxbg(@RequestBody List<UfcWbRptJobAddDto> dtos, @LoginUser User user) {
        return ufcErpPsWbrptService.addReportRecord(dtos,user);
    }
    @ApiOperation(value = "生成专检记录数据", notes = "生成专检记录数据")
    @PostMapping("/saveZjjl")
    public Result saveZjjl(@RequestParam Long pswbrptoid, @LoginUser User user) {
        return gxBgService.saveZjjl(pswbrptoid,user);
    }
    @ApiOperation(value = "查询上一道工序批号日期", notes = "查询上一道工序批号日期")
    @GetMapping("/getNextPhrq")
    public Result getNextPhrq(@RequestParam Long pswboid) {
        return gxBgService.getNextPhrq(pswboid);
    }

    @ApiOperation(value = "统计作业反馈专检次数", notes = "统计作业反馈专检次数")
    @GetMapping("getCountZj")
    public Result getCountZj(@RequestParam Long pswbrptoid) {
        return gxBgService.getCountZj(pswbrptoid);
    }

    @ApiOperation(value = "查询工单合格数量与不合格数量", notes = "查询工单合格数量与不合格数量")
    @GetMapping("getCountSl")
    public Result getCountSl(@RequestParam Long pswboid) {
        return gxBgService.getCountSl(pswboid);
    }
}
