package com.jln.system.web.action.erp.gxbg.dto;

import com.fasterxml.jackson.annotation.JsonFormat;
import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.fasterxml.jackson.annotation.JsonProperty;
import com.jln.common.constant.LocalDateTimeConst;
import io.swagger.annotations.ApiModel;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;
import org.springframework.format.annotation.DateTimeFormat;

import javax.validation.constraints.Size;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * @ClassName:
 * @Description:
 * @Author:三刀 Date:2021/6/18 15:05
 * Version:1.0
 **/
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
@JsonIgnoreProperties(ignoreUnknown = true)
@ApiModel(value = "gxZyListAdd",description = "工序转移查询详情和添加数据")
public class ErpGxZyListAdd {


    @ApiModelProperty(value = "排产数量")
    private BigDecimal pcsl;

    @ApiModelProperty(value = "完工数量")
    private BigDecimal hgsl;


    @ApiModelProperty(value = "当前状态:I|初始，F|确认，R|下达，C|完成，S|暂停")
    private String thisZt;


    @ApiModelProperty(value = "当前工序编码")
    private String gxid;

    @ApiModelProperty(value = "当前工序名称")
    private String gxmc;

    /**
     * 添加查询的时候后端给当前日期值
     */
    @ApiModelProperty(example = "2019-10-10 10:10:10", value = "业务日期", required = true,dataType = "date")
    @DateTimeFormat(pattern = "yyyy-MM-dd")
    @JsonFormat(shape = JsonFormat.Shape.STRING,pattern = "yyyy-MM-dd")
    private LocalDate ywrq;

    /**
     * 业务单号-后端给值
     */
    @ApiModelProperty(example = "20190230", value = "工序转移单号", required = true,dataType = "string")
    @Size(max = 20,message = "最大长度为20个字节")
    private String ywid;

    /**
     * 添加的时候-后端给值
     */
    @ApiModelProperty(value = "状态: I|移除,F|转出,C|接收")
    private String zt;

    /**
     * 添加的时候-前端给值
     */
    @ApiModelProperty(example = "A|正常移出，B|返工移出，C|报废移出", value = "转移类型", required = true,dataType = "string")
    @Size(max = 1,message = "最大长度为1个字节")
    private String ywlx;

    /**
     * 添加的时候-后端给值
     */
    @ApiModelProperty(value = "转出人编码")
    private String toProcessUserCode;

    /**
     * 添加的时候-后端给值
     */
    @ApiModelProperty(value = "转出人名称")
    private String toProcessUserName;

    @ApiModelProperty(value = "转出人外键")
    private Long toProcessUserFk;

    /**
     * 当前工单的数量
     */
    @ApiModelProperty(value = "转出数量")
    private BigDecimal toProcessNumber;

    /**
     * 条码扫描录入
     */
    @ApiModelProperty(value = "转移物料批号")
    private String wlph;


    @ApiModelProperty(value = "转出时间")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime yjrTime;

    @ApiModelProperty(value = "转出说明")
    private String turnsOutThat;


    @ApiModelProperty(value = "接收工序编码")
    private String transferProcessCode;

    @ApiModelProperty(value = "接收工序名称")
    private String transferProcessName;


    @ApiModelProperty(value = "接收人编码")
    private String transferProcessUserCode;

    @ApiModelProperty(value = "接收人名称")
    private String transferProcessUserName;

    @ApiModelProperty(value = "接收人外键")
    private Long transferProcessUserFk;

    @ApiModelProperty(value = "接收数量")
    private BigDecimal numberReceiving;

    @ApiModelProperty(value = "接收物料批次号")
    private String receiveThe;

    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    @ApiModelProperty(value = "接收时间",example = "2021-06-18 00:00:00")
    private LocalDateTime jsrTime;

    @ApiModelProperty(value = "接收说明")
    private String proofOfReceipt;


    @ApiModelProperty(example = "2000", value = "移出工单外键-2021-6-18新增", required = true,dataType = "double")
    private Long jgPsWbFk;


    @ApiModelProperty(example = "2000", value = "接收工单外键-2021-6-18新增", required = true,dataType = "double")
    private Long wgPsWbFk;

    @ApiModelProperty(example = "物料外键", required = true,dataType = "string")
    private Long bMaterialFk;

    @ApiModelProperty(example = "0", value = "工艺路线外键", required = true,dataType = "string")
    private Long wpgylxFk;

    @ApiModelProperty(value = "工序转移外键")
    private Long gxzydFk;

    @ApiModelProperty(value = "工序转移明细主键")
    private Long gxzydmxoid;

    @ApiModelProperty(value = "生产订单排程外键")
    private Long psWsFk;

    @ApiModelProperty(value = "工序流程图外键")
    private Long psTechnologicalProcessFk;

    //20210917新增参数
    @ApiModelProperty(value = "接收数量（汇总）")
    private BigDecimal jsslhz;

    @ApiModelProperty(value = "转出数量（汇总）")
    private BigDecimal zcslhz;

    @ApiModelProperty(value = "订单属性")
    private String ddsx;

    @ApiModelProperty(value = "生产批号")
    private String productionBatch;

    @ApiModelProperty(value = "转入供应商编码")
    private String inGysid;

    /**
     * 转出供应商编码
     */
    private String outGysid;

    @ApiModelProperty(value = "转包供应商外键")
    @JsonProperty(value = "bSupplierFk")
    private Long bSupplierFk;
}
