package com.jln.system.web.action.erp.organization.service.impl;


import com.alibaba.fastjson.JSONObject;
import com.jln.common.entity.Result;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.bm.factory.entity.BFactory;
import com.jln.system.web.action.bm.factory.service.BFactoryService;
import com.jln.system.web.action.bm.workshop.entity.BWorkshop;
import com.jln.system.web.action.bm.workshop.service.BWorkshopService;
import com.jln.system.web.action.erp.organization.jopo.dto.ERPOrganizationQueryDTO;
import com.jln.system.web.action.erp.organization.jopo.dto.OrganizeErpWorkshop;
import com.jln.system.web.action.erp.organization.jopo.vo.ERPDepartmentVO;
import com.jln.system.web.action.erp.organization.jopo.vo.ERPOrganizationVO;
import com.jln.system.web.action.erp.organization.service.OrganizationService;
import com.jln.system.web.action.mes.organize.entity.SysOrganize;
import com.jln.system.web.action.mes.organize.entity.SysOrganizeErp;
import com.jln.system.web.action.mes.organize.mapper.SysOrganizeErpMapper;
import com.jln.system.web.action.mes.organize.service.SysOrganizeErpService;
import com.jln.system.web.action.mes.organize.service.SysOrganizeService;
import com.jln.system.web.action.mes.user.entity.SysPost;
import com.jln.system.web.action.mes.user.service.SysPostService;
import com.jln.system.web.action.sm.common.service.CodeTableService;
import com.jln.system.web.action.util.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDate;
import java.util.*;
import java.util.stream.Collectors;

/**
 * @ClassName: 组织机构及部门
 * @Description:
 * @Author:wangxinxin Date:2021/10/124 11:51
 * Version:1.0
 **/
@Service
public class OrganizationServiceImpl implements OrganizationService {
    @Autowired
    private CodeTableService codeTableService;
    @Autowired
    private SysOrganizeService organizeService;
    @Autowired
    private SysOrganizeErpService organizeErpService;
    @Autowired
    private BFactoryService factoryService;
    @Autowired
    private BWorkshopService workshopService;
    @Resource
    private SysOrganizeErpMapper organizeErpMapper;
    //    @Value("${orgCodeType}")
    private String orgCodeType = "sys_org";

    @Autowired
    private SysPostService sysPostService;

    @Value("${topPid}")
    private Long topPid;
    @Autowired
    private BFactoryService bFactoryService;

    @Value("${erp.MAINTAINER}")
    private Long MAINTAINER;

    @Override
    public Result<List<ERPOrganizationVO>> queryOrganizations(ERPOrganizationQueryDTO query) {
        ERPParam params = new ERPParam();
        //后台限制
        params.setFieldKeys("FFORBIDSTATUS,FDocumentStatus,FNUMBER,FNAME,FTEL,FOrgID,FORGFORMID,FModifyDate");
        params.setFormId("ORG_Organizations");
        params.setTopRowCount(0);
        params.setLimit(query.getLimit());
        //List<ERPFilterString> filterStrings = new ArrayList<>();
        String erpParam = null;
        if (!EmptyUtil.isEmpty(query.getStartTime())) {
            erpParam="FModifyDate>'"+query.getStartTime().toString()+"' and "+"(FNUMBER=101 or FNUMBER=102 or FNUMBER=103 or FNUMBER=104)";
            /*ERPFilterString filterString = new ERPFilterString();
            filterString.setLeft("(");
            filterString.setFieldName("FModifyDate");
            filterString.setCompare(">");
            filterString.setValue(query.getStartTime().toString());
            filterString.setRight(")");
            filterString.setLogic("");
            filterStrings.add(filterString);*/
        }else{
            erpParam="FNUMBER=101 or FNUMBER=102 or FNUMBER=103 or FNUMBER=104";
        }
        params.setStartRow(query.getLimit() * (query.getPage() - 1));
        params.setFilterString(erpParam);
        System.out.println(JSONObject.toJSONString(params));
        return ERPHttpUtils.others(params, ERPOrganizationVO.class);
    }

    @Override
    public Result<String> syncOrganizations(ERPOrganizationQueryDTO query) {
        int page = 1;
        while (true) {
            query.setLimit(50);
            query.setPage(page);
            Result<List<ERPOrganizationVO>> organizationResult = queryOrganizations(query);
            if (!organizationResult.confirmSuccess()) {
                return new Result<>().toFailure(organizationResult.getMsg());
            }
            List<ERPOrganizationVO> data = organizationResult.getData();
            if (data.size() == 0) {
                break;
            }
            page++;
            Result<String> result = saveOrganizations(data);
            if (!result.confirmSuccess()) {
                return new Result<>().toFailure(result.getMsg());
            }
        }
        return new Result<String>().toSuccess();
    }

    @Override
    @Transactional
    public Result<String> saveOrganizations(List<ERPOrganizationVO> organizations) {
        if (EmptyUtil.isEmpty(organizations)) {
            return new Result<String>().toFailure("不能传空过来！");
        }
        List<Long> bms = organizations.stream().filter(e -> !EmptyUtil.isEmpty(e.getFOrgID())).map(ERPOrganizationVO::getFOrgID).collect(Collectors.toList());
        List<SysOrganizeErp> organizeErps = organizeErpMapper.queryOrganizationsByCodes(bms);
        Map<String, SysOrganizeErp> erpMap = organizeErps.stream().filter(e -> !EmptyUtil.isEmpty(e.getOrganizeCode())).collect(Collectors.toMap(SysOrganizeErp::getOrganizeCode, e -> e));
        List<SysOrganize> organizeList = new ArrayList<>();
        List<SysOrganizeErp> organizeErpList = new ArrayList<>();
        List<BFactory> factoryList = new ArrayList<>();
        Map<Long, ERPOrganizationVO> departmentVOMap = organizations.stream().filter(e -> !EmptyUtil.isEmpty(e.getFOrgID())).collect(Collectors.toMap(ERPOrganizationVO::getFOrgID, o -> o, (b, c) -> c));
        //生成关联信息
        for (Long key : departmentVOMap.keySet()) {
            ERPOrganizationVO organization = departmentVOMap.get(key);
//        for (ERPOrganizationVO organization : organizations) {
            SysOrganizeErp organizeErp = erpMap.get(organization.getFOrgID().toString());
            SysOrganize organize = new SysOrganize();
            //未保存过ERP数据
            if (EmptyUtil.isEmpty(organizeErp)) {
                organizeErp = new SysOrganizeErp();
                organizeErp.setOid(SnowflakeIdUtils.generate());
                organizeErp.setSysOrganizeId(SnowflakeIdUtils.generate());
                organizeErp.setBFactoryoid(SnowflakeIdUtils.generate());
            }
            //组织信息
            organize.setSysOrganizeId(organizeErp.getSysOrganizeId());
            if ("C".equals(organization.getFDocumentStatus()) && "A".equals(organization.getFFORBIDSTATUS())) {
                organize.setActiveFlag(1);
            } else {
                organize.setActiveFlag(0);
            }
            organize.setSfzz("ZZ");
            organize.setOrganizeCode(String.valueOf(organization.getFOrgID()));
            organize.setOrganizeName(organization.getFNAME());
            organize.setOrgnizeIphone(organization.getFTEL());
            organize.setOrgnizePid(100000000000000000L);
            //从编码表中取值
            Result<String> codeingResult = codeTableService.getCodeing(orgCodeType, false);
            String code = codeingResult.getData();
            if (EmptyUtil.isEmpty(code)) {
                return new Result().toFailure("组织机构编码未维护，请管理员进行维护");
            }
            organize.setClassCode(codeingResult.getData());
            organize.setUnit(1);
            organizeList.add(organize);
            //MES主表存在记录，但是关联数据不存在
            if (EmptyUtil.isEmpty(organizeErp.getOid())) {
                organizeErp = new SysOrganizeErp();
                organizeErp.setOid(SnowflakeIdUtils.generate());
                organizeErp.setBFactoryoid(SnowflakeIdUtils.generate());
            }
            //关联信息
            organizeErp.setSysOrganizeId(organize.getSysOrganizeId());
            organizeErp.setFOrgId(organization.getFOrgID());
            organizeErp.setOrganizeCode(organization.getFNUMBER());
            organizeErp.setOrganizeType(organization.getFORGFORMID());
            organizeErp.setSysUpd(organization.getFModifyDate());
            organizeErpList.add(organizeErp);
            //工厂信息
            BFactory factory = new BFactory();
            if (EmptyUtil.isEmpty(organizeErp.getBFactoryoid())) {
                organizeErp.setBFactoryoid(SnowflakeIdUtils.generate());
            }
            factory.setBFactoryoid(organizeErp.getBFactoryoid());
            factory.setGcid(String.valueOf(organization.getFOrgID()));
            factory.setGcmc(organization.getFNAME());
            factory.setSysLastUpd(organization.getFModifyDate());
            factory.setSysLastUpdBy(MAINTAINER);
            factory.setQyrq(LocalDate.now());
            if ("C".equals(organization.getFDocumentStatus()) && "A".equals(organization.getFFORBIDSTATUS())) {
                factory.setTybz(false);
            } else {
                factory.setTyrq(LocalDate.now());
                factory.setTybz(true);
            }
            factoryList.add(factory);
        }
        boolean b = organizeService.saveOrUpdateBatch(organizeList);
        if (!b) {
            throw new CustomException(-1, "保存组织机构信息主表信息失败！");
        }
        boolean b1 = organizeErpService.saveOrUpdateBatch(organizeErpList);
        if (!b1) {
            throw new CustomException(-1, "保存组织机构信息关联表信息失败！");
        }
        boolean b3 = factoryService.saveOrUpdateBatch(factoryList);
        if (!b3) {
            throw new CustomException(-1, "保存工厂信息失败！");
        }
        return new Result<String>().toSuccess();
    }

    @Override
    public Result<List<ERPDepartmentVO>> queryDepartments(ERPOrganizationQueryDTO query) {
        ERPParam params = new ERPParam();
        //后台限制
        params.setFieldKeys("FDEPTID,FFORBIDSTATUS,FDocumentStatus,FDESCRIPTION,FNUMBER,FNAME,FPARENTID,FUSEORGID,FMODIFYDATE,FDEPTPROPERTY,FIsWorkshop");
        params.setFormId("BD_Department");
        params.setTopRowCount(0);
        params.setLimit(query.getLimit());
        //List<ERPFilterString> filterStrings = new ArrayList<>();
        String erpParam=null;
        if (!EmptyUtil.isEmpty(query.getStartTime())) {
            erpParam="FMODIFYDATE>'"+query.getStartTime().toString()+"' and "+"(FUSEORGID=100013 or FUSEORGID=100016 or FUSEORGID=100017 or FUSEORGID=100018) and F_101_CheckBoxSFTBMES=1";
            /*ERPFilterString filterString = new ERPFilterString();
            filterString.setLeft("(");
            filterString.setFieldName("FModifyDate");
            filterString.setCompare(">");
            filterString.setValue(query.getStartTime().toString());
            filterString.setRight(")");
            filterString.setLogic("");
            filterStrings.add(filterString);*/
        }else{
            erpParam="(FUSEORGID=100013 or FUSEORGID=100016 or FUSEORGID=100017 or FUSEORGID=100018) and F_101_CheckBoxSFTBMES=1";
        }
        params.setFilterString(erpParam);
        params.setStartRow(query.getLimit() * (query.getPage() - 1));
        System.out.println(JSONObject.toJSONString(params));
        return ERPHttpUtils.others(params, ERPDepartmentVO.class);
    }


    @Override
    @Transactional
    public Result<String> saveDepartments(List<ERPDepartmentVO> departments) {
        if (EmptyUtil.isEmpty(departments)) {
            return new Result<String>().toFailure("不能传空过来！");
        }
        //将erp部门主键放到集合中
        List<Long> bms = departments.stream().filter(e -> !EmptyUtil.isEmpty(e.getFDEPTID())).map(ERPDepartmentVO::getFDEPTID).collect(Collectors.toList());
        //根据erp部门主键查询mes 组织部门/车间主键
        List<OrganizeErpWorkshop> checked = organizeErpMapper.selectOrganizeErpWorkshop();

        List<SysOrganize> organizeList = new ArrayList<>();
        List<SysOrganizeErp> organizeErpList = new ArrayList<>();
        List<BWorkshop> workshopList = new ArrayList<>();
        List<SysPost> posts = new ArrayList<>();

        //查询工厂
        List<BFactory> bFactorieList = bFactoryService.getBaseMapper().selectList(null);

        for (ERPDepartmentVO department : departments) {
            //生成部门信息
            SysOrganize organize = new SysOrganize();
            //判断部门是否已经存在
            List<OrganizeErpWorkshop> boys = checked.stream().filter(s->s.getErpOid().toString().equals(department.getFDEPTID().toString())).collect(Collectors.toList());
            if(!EmptyUtil.isEmpty(boys) && !EmptyUtil.isEmpty(boys.get(0).getSysOrganizeId())){
                organize.setSysOrganizeId(boys.get(0).getSysOrganizeId());
            }else{
                organize.setSysOrganizeId(SnowflakeIdUtils.generate());
            }

            organize.setSfzz("BM");
            if ("C".equals(department.getFDocumentStatus()) && "A".equals(department.getFFORBIDSTATUS())) {
                organize.setActiveFlag(1);
            } else {
                organize.setActiveFlag(0);
            }
            organize.setOrganizeName(department.getFNAME());
            organize.setOrganizeCode(String.valueOf(department.getFDEPTID()));
            organize.setDescribes(department.getFDESCRIPTION());
            //从编码表中取值
            Result<String> codeingResult = codeTableService.getCodeing(orgCodeType, false);
            String code = codeingResult.getData();
            if (EmptyUtil.isEmpty(code)) {
                return new Result().toFailure("组织机构编码未维护，请管理员进行维护");
            }
            organize.setClassCode(codeingResult.getData());
            organize.setUnit(0);

            //父级部门为0,父级部门字段存组织主键
            if(department.getFPARENTID().toString().equals("0")){
                List<OrganizeErpWorkshop> zuzhi = checked.stream().filter(s->s.getErpOid().toString().equals(department.getFUSEORGID().toString())).collect(Collectors.toList());
                if(!EmptyUtil.isEmpty(zuzhi) && !EmptyUtil.isEmpty(zuzhi.get(0).getSysOrganizeId())){
                    organize.setOrgnizePid(zuzhi.get(0).getSysOrganizeId());
                }
            }

            //获取父级部门主键
            List<OrganizeErpWorkshop> savepid = checked.stream().filter(s->s.getErpOid().toString().equals(department.getFPARENTID().toString())).collect(Collectors.toList());
            if(!EmptyUtil.isEmpty(savepid) && !EmptyUtil.isEmpty(savepid.get(0).getSysOrganizeId())){
                organize.setOrgnizePid(savepid.get(0).getSysOrganizeId());
            }
            List<SysOrganize> newpid = organizeList.stream().filter(n -> n.getOrganizeCode().equals(department.getFPARENTID().toString())).collect(Collectors.toList());
            if(!EmptyUtil.isEmpty(newpid) && !EmptyUtil.isEmpty(newpid.get(0).getSysOrganizeId())){
                organize.setOrgnizePid(newpid.get(0).getSysOrganizeId());
            }
            //没有父级部门
            if(EmptyUtil.isEmpty(organize.getOrgnizePid())){
                List<OrganizeErpWorkshop> zuzhi = checked.stream().filter(s->s.getErpOid().toString().equals(department.getFUSEORGID().toString())).collect(Collectors.toList());
                if(!EmptyUtil.isEmpty(zuzhi) && !EmptyUtil.isEmpty(zuzhi.get(0).getSysOrganizeId())){
                    organize.setOrgnizePid(zuzhi.get(0).getSysOrganizeId());
                }
            }
            organizeList.add(organize);

            SysPost sysPost = new SysPost();
            sysPost.setSysPostId(SnowflakeIdUtils.generate());
            sysPost.setOrganizeFk(organize.getSysOrganizeId());
            sysPost.setPostName(organize.getOrganizeName());
            sysPost.setPostCode(organize.getClassCode());
            posts.add(sysPost);

            SysOrganizeErp organizeErp = new SysOrganizeErp();
            //判断sys_organize_erp 是否已存在数据
            if(!EmptyUtil.isEmpty(boys) && !EmptyUtil.isEmpty(boys.get(0).getOId())){
                organizeErp.setOid(boys.get(0).getOId());
                organizeErp.setSysOrganizeId(boys.get(0).getSysOrganizeId());
            }else{
                organizeErp.setOid(SnowflakeIdUtils.generate());
                organizeErp.setSysOrganizeId(organize.getSysOrganizeId());
            }
            organizeErp.setFOrgId(department.getFDEPTID());
            organizeErp.setOrganizeCode(department.getFNUMBER());
            organizeErp.setSysUpd(department.getFMODIFYDATE());
            organizeErpList.add(organizeErp);

            //生成车间信息
            if("4866f13a3a3940b9b2fe47895a6e7cbe".equals(department.getFDEPTPROPERTY()) && department.getFIsWorkshop()){
                BWorkshop workshop = new BWorkshop();
                //判断车间是否存在
                if(!EmptyUtil.isEmpty(boys) && !EmptyUtil.isEmpty(boys.get(0).getBWorkshopoid())){
                    workshop.setBWorkshopoid(boys.get(0).getBWorkshopoid());
                }else{
                    workshop.setBWorkshopoid(SnowflakeIdUtils.generate());
                }
                workshop.setCjid(String.valueOf(department.getFDEPTID()));
                workshop.setCjmc(department.getFNAME());
                workshop.setQyrq(LocalDate.now());
                if ("C".equals(department.getFDocumentStatus()) && "A".equals(department.getFFORBIDSTATUS())) {
                    workshop.setTybz(false);
                } else {
                    workshop.setTyrq(LocalDate.now());
                    workshop.setTybz(true);
                }
                workshop.setBz(department.getFDESCRIPTION());
                workshop.setSysLastUpd(department.getFMODIFYDATE());
                workshop.setSysLastUpdBy(MAINTAINER);

                //判断工厂是否存在
                List<BFactory> bFactories = bFactorieList.stream().filter(s->s.getGcid().toString().equals(department.getFUSEORGID().toString())).collect(Collectors.toList());
                if (EmptyUtil.isEmpty(bFactories)) {
                    throw new CustomException(-1, "【" + department.getFNAME() + "，" + department.getFNUMBER() + "】工厂信息不存在");
                }
                workshop.setFactoryFk(bFactories.get(0).getBFactoryoid());
                workshopList.add(workshop);
            }

        }





        /*List<SysOrganizeErp> organizeErps = organizeErpMapper.queryOrganizationsByCodes(bms);
        Map<String, SysOrganizeErp> erpMap = organizeErps.stream().filter(e -> !EmptyUtil.isEmpty(e.getOrganizeCode())).collect(Collectors.toMap(SysOrganizeErp::getOrganizeCode, e -> e));
        //List<SysOrganize> organizeList = new ArrayList<>();
        //List<SysOrganizeErp> organizeErpList = new ArrayList<>();
        //List<BWorkshop> workshopList = new ArrayList<>();
        Set<Long> pids = departments.stream().filter(o -> !EmptyUtil.isEmpty(o.getFPARENTID())).map(ERPDepartmentVO::getFPARENTID).collect(Collectors.toSet());
        Set<Long> orgs = departments.stream().filter(o -> !EmptyUtil.isEmpty(o.getFUSEORGID())).map(ERPDepartmentVO::getFUSEORGID).collect(Collectors.toSet());
        pids.addAll(orgs);
        Map<Long, SysOrganizeErp> parent = new HashMap<>();
        if (pids.size() > 0) {
            List<SysOrganizeErp> erps = organizeErpMapper.queryOrganizationsByOrgIds(pids);
            if (erps.size() > 0) {
                parent = erps.stream().collect(Collectors.toMap(SysOrganizeErp::getFOrgId, o -> o, (c, b) -> b));
            }
        }
        Map<Long, ERPDepartmentVO> departmentVOMap = departments.stream().filter(e -> !EmptyUtil.isEmpty(e.getFDEPTID())).collect(Collectors.toMap(ERPDepartmentVO::getFDEPTID, o -> o, (b, c) -> c));
        //生成关联信息
        for (Long key : departmentVOMap.keySet()) {
            ERPDepartmentVO department = departmentVOMap.get(key);
            SysOrganizeErp organizeErp = erpMap.get(department.getFDEPTID().toString());
            //未保存过ERP数据
            if (EmptyUtil.isEmpty(organizeErp)) {
                organizeErp = new SysOrganizeErp();
                organizeErp.setOid(SnowflakeIdUtils.generate());
                organizeErp.setSysOrganizeId(SnowflakeIdUtils.generate());
                organizeErp.setBWorkshopoid(SnowflakeIdUtils.generate());
            }
            //MES主表存在记录，但是关联数据不存在
            if (EmptyUtil.isEmpty(organizeErp.getOid())) {
                organizeErp.setOid(SnowflakeIdUtils.generate());
                //判断是否有车间信息
                if (EmptyUtil.isEmpty(organizeErp.getBWorkshopoid())) {
                    organizeErp.setBWorkshopoid(SnowflakeIdUtils.generate());
                }
            }
            //关联信息
            organizeErp.setFOrgId(department.getFDEPTID());
            organizeErp.setOrganizeCode(department.getFNUMBER());
            organizeErp.setSysUpd(department.getFMODIFYDATE());
            organizeErpList.add(organizeErp);
            //生成部门信息
            SysOrganize organize = new SysOrganize();
            organize.setSfzz("BM");
            organize.setSysOrganizeId(organizeErp.getSysOrganizeId());
            if ("C".equals(department.getFDocumentStatus()) && "A".equals(department.getFFORBIDSTATUS())) {
                organize.setActiveFlag(1);
            } else {
                organize.setActiveFlag(0);
            }
            organize.setOrganizeName(department.getFNAME());
            organize.setOrganizeCode(String.valueOf(department.getFDEPTID()));
            organize.setDescribes(department.getFDESCRIPTION());
            //从编码表中取值
            Result<String> codeingResult = codeTableService.getCodeing(orgCodeType, false);
            String code = codeingResult.getData();
            if (EmptyUtil.isEmpty(code)) {
                return new Result().toFailure("组织机构编码未维护，请管理员进行维护");
            }
            organize.setClassCode(codeingResult.getData());
            organize.setUnit(0);
            //父级信息
            SysOrganizeErp erp = parent.get(department.getFPARENTID());
            if (EmptyUtil.isEmpty(erp)) {
                erp = parent.get(department.getFUSEORGID());
            }
            if (EmptyUtil.isEmpty(erp)) {
                throw new CustomException(-1, "【" + department.getFNAME() + "，" + department.getFNUMBER() + "】父级信息不存在");
            }
            organize.setOrgnizePid(erp.getSysOrganizeId());
            organizeList.add(organize);
            //生成车间信息
            //System.out.println("FDEPTPROPERTY【"+department.getFDEPTPROPERTY()+"】");
            if("4866f13a3a3940b9b2fe47895a6e7cbe".equals(department.getFDEPTPROPERTY())*//* && department.getFIsWorkshop()*//*){
                //System.out.println("FDEPTPROPERTY【true】");
                BWorkshop workshop = new BWorkshop();
                workshop.setBWorkshopoid(organizeErp.getBWorkshopoid());
                workshop.setCjid(String.valueOf(department.getFDEPTID()));
                workshop.setCjmc(department.getFNAME());
                workshop.setQyrq(LocalDate.now());
                if ("C".equals(department.getFDocumentStatus()) && "A".equals(department.getFFORBIDSTATUS())) {
                    workshop.setTybz(false);
                } else {
                    workshop.setTyrq(LocalDate.now());
                    workshop.setTybz(true);
                }
                workshop.setBz(department.getFDESCRIPTION());
                workshop.setSysLastUpd(department.getFMODIFYDATE());
                workshop.setSysLastUpdBy(ERPConstant.MAINTAINER);
                SysOrganizeErp erp1 = parent.get(department.getFUSEORGID());
                if (EmptyUtil.isEmpty(erp1)) {
                    throw new CustomException(-1, "【" + department.getFNAME() + "，" + department.getFNUMBER() + "】工厂信息不存在");
                }
                workshop.setFactoryFk(erp1.getBFactoryoid());
                workshopList.add(workshop);
            }

        }*/
        boolean b = organizeService.saveOrUpdateBatch(organizeList);
        if (!b) {
            throw new CustomException(-1, "保存组织机构信息主表信息失败！");
        }
        boolean b1 = organizeErpService.saveOrUpdateBatch(organizeErpList);
        if (!b1) {
            throw new CustomException(-1, "保存组织机构信息关联表信息失败！");
        }
        if(!EmptyUtil.isEmpty(workshopList)){
            boolean b3 = workshopService.saveOrUpdateBatch(workshopList);
            if (!b3) {
                throw new CustomException(-1, "保存车间信息失败！");
            }
        }
        //boolean b4 = sysPostService.saveorup
        return new Result<String>().toSuccess();
    }

    @Override
    public Result<String> syncDepartments(ERPOrganizationQueryDTO query) {
        int page = 1;
        while (true) {
            query.setLimit(500);
            query.setPage(page);
            Result<List<ERPDepartmentVO>> departments = queryDepartments(query);
            if (!departments.confirmSuccess()) {
                return new Result<>().toFailure(departments.getMsg());
            }
            List<ERPDepartmentVO> data = departments.getData();
            if (data.size() == 0) {
                break;
            }
            page++;
            Result<String> result = saveDepartments(data);
            if (!result.confirmSuccess()) {
                return new Result<>().toFailure(result.getMsg());
            }
        }
        return new Result<String>().toSuccess();
    }
}
