package com.jln.system.web.action.erp.organization.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.bm.factory.entity.BFactory;
import com.jln.system.web.action.bm.factory.mapper.BFactoryMapper;
import com.jln.system.web.action.erp.organization.jopo.UfcSysEmployeeOrganize;
import com.jln.system.web.action.erp.organization.service.UfcSysEmployeeOrganizeService;
import com.jln.ufc.web.action.enums.UfcResultCodeEnum;
import com.jln.system.web.action.erp.organization.jopo.dto.ERPUserQueryDTO;
import com.jln.system.web.action.erp.organization.jopo.vo.ERPUserVO;
import com.jln.system.web.action.erp.organization.service.UserService;
import com.jln.ufc.web.action.exception.UfcCustomException;
import com.jln.system.web.action.mes.organize.entity.SysOrganize;
import com.jln.system.web.action.mes.organize.service.SysOrganizeService;
import com.jln.system.web.action.mes.user.entity.*;
import com.jln.system.web.action.mes.user.service.*;
import com.jln.system.web.action.util.*;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;
import org.springframework.transaction.annotation.Transactional;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;

@Service
public class UserServiceImpl implements UserService {

    @Resource
    private SysEmployeeService employeeService;
    @Resource
    private SystemEmployeeService systemEmployeeService;
    @Resource
    private SysUserService userService;
    @Resource
    private SysOrganizeService sysorganizeser;
    @Resource
    private UfcSysEmployeeOrganizeService ufcSysEmployeeOrganizeService;
    @Resource
    private BFactoryMapper bFactoryMapper;

    @Override
    public Result<List<ERPUserVO>> queryUsers(ERPUserQueryDTO query) {
        ERPParam params = new ERPParam();
        //后台限制
        params.setFieldKeys("FUseOrgId,FUseOrgId.FNumber,FUseOrgId.FName,FEmpInfoId,FEmpInfoId.FNUMBER," +
                "FEmpInfoId.FNAME,FDept,FDept.FNUMBER,FDept.FNAME,FDocumentStatus,FFORBIDSTATUS");
        params.setFormId("BD_NEWSTAFF");
        params.setTopRowCount(0);
        params.setLimit(query.getLimit());
        String erpParam = null;
        List<ERPFilterString> filterStrings = new ArrayList<>();
        if (!EmptyUtil.isEmpty(query.getStartTime())) {
            ERPFilterString filterString = new ERPFilterString();
            filterString.setLeft("(");
            filterString.setFieldName("FModifyDate");
            filterString.setCompare(">");
            filterString.setValue(query.getStartTime().toString());
            filterString.setRight(")");
            filterString.setLogic("");
            filterStrings.add(filterString);
            erpParam = "FModifyDate>'" + query.getStartTime().toString() + "' and " + "(FUseOrgId.FNumber=101) and FIsFirstPost=1";
        } else {
            erpParam = "FUseOrgId.FNumber=101 and FIsFirstPost=1";
        }
        params.setFilterString(erpParam);
        params.setStartRow(query.getLimit() * (query.getPage() - 1));
        return ERPHttpUtils.other(params, ERPUserVO.class);
    }

    @Transactional
    public Result<String> saveUsers(List<ERPUserVO> users, List<SysEmployee> oldUser, List<SysOrganize> organizes) {
        //List<SystemEmployee> oldUser = systemEmployeeService.getBaseMapper().selectList(null);
        //List<Long> oid = list.stream().map(p -> p.getSysEmployeeOid()).collect(Collectors.toList());
        if (EmptyUtil.isEmpty(users)) {
            return new Result<String>().toFailure("不能传空过来！");
        }

        //员工信息操作
        List<SysEmployee> sysEmployees = new ArrayList<>();
        List<SystemEmployee> systemEmployees = new ArrayList<>();
        List<SysUser> sysUsers = new ArrayList<>();
        List<UfcSysEmployeeOrganize> zuzhirenyuan = new ArrayList<>();

        List<UfcSysEmployeeOrganize> zuzhirenyuanUpdate = new ArrayList<>();
        List<SysEmployee> sysEmployeesUpdate = new ArrayList<>();
        List<SystemEmployee> systemEmployeesUpdate = new ArrayList<>();
        List<SysUser> sysUsersUpdate = new ArrayList<>();

        for (ERPUserVO user : users) {

            if(user.getFEmpInfoIdFNAME().equals("胡建芳")){
                System.out.println(user);
            }
            //判断用户是否是同步的部门的用户
            List<SysOrganize> zuzhi = organizes.stream().filter(s -> s.getOrganizeCode().toString().equals(user.getFDept().toString())).collect(Collectors.toList());

            if (!EmptyUtil.isEmpty(zuzhi)) {

                //判断人员是否存在
                boolean b = oldUser.stream().anyMatch(m -> m.getEmployeeOid().toString().equals(user.getFEmpInfoId().toString()));
                if (b) {
                    SysEmployee employee = new SysEmployee();
                    employee.setEmployeeOid(user.getFEmpInfoId());
                    employee.setCodeing(user.getFEmpInfoIdFNUMBER());
                    employee.setJobNumber(user.getFEmpInfoIdFNUMBER());
                    employee.setEmployeeName(user.getFEmpInfoIdFNAME());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        employee.setBlockUp("0");
                        employee.setDel(false);
                    } else {
                        employee.setBlockUp("1");
                        employee.setDel(true);
                    }
                    sysEmployeesUpdate.add(employee);

                    SystemEmployee systemEmployee = new SystemEmployee();
                    systemEmployee.setSysEmployeeOid(user.getFEmpInfoId());
                    systemEmployee.setEmployeeCode(user.getFEmpInfoIdFNUMBER());
                    systemEmployee.setEmployeeName(user.getFEmpInfoIdFNAME());
                    systemEmployee.setUserFk(user.getFEmpInfoId());
                    systemEmployee.setOrganiceFk(zuzhi.get(0).getSysOrganizeId());
                    systemEmployee.setDivisionFk(zuzhi.get(0).getSysOrganizeId());
                    systemEmployee.setMianPostFk(user.getFDept());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        systemEmployee.setBlockUp(false);
                        systemEmployee.setDel(0);
                    } else {
                        systemEmployee.setBlockUp(true);
                        systemEmployee.setDel(1);
                    }
                    systemEmployeesUpdate.add(systemEmployee);

                    SysUser sysUser = new SysUser();
                    sysUser.setUserId(user.getFEmpInfoId());
                    sysUser.setUserName(user.getFEmpInfoIdFNUMBER());
                    sysUser.setUserEmployeeName(user.getFEmpInfoIdFNAME());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        sysUser.setDel(0);
                    } else {
                        sysUser.setDel(1);
                    }
                    //处理密码加密
                    try {
                        String encryption = encryption(sysUser.getSalt(), "123456");
                        sysUser.setPassword(encryption);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }

                    sysUsersUpdate.add(sysUser);

                    UfcSysEmployeeOrganize ufcSysEmployeeOrganize = new UfcSysEmployeeOrganize();
                    ufcSysEmployeeOrganize.setSysEmployeeoid(user.getFEmpInfoId());
                    ufcSysEmployeeOrganize.setSysOrganizeoid(zuzhi.get(0).getSysOrganizeId());
                    zuzhirenyuanUpdate.add(ufcSysEmployeeOrganize);

                } else {
                    SysEmployee employee = new SysEmployee();
                    employee.setEmployeeOid(user.getFEmpInfoId());
                    employee.setCodeing(user.getFEmpInfoIdFNUMBER());
                    employee.setJobNumber(user.getFEmpInfoIdFNUMBER());
                    employee.setEmployeeName(user.getFEmpInfoIdFNAME());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        employee.setBlockUp("0");
                        employee.setDel(false);
                    } else {
                        employee.setBlockUp("1");
                        employee.setDel(true);
                    }
                    sysEmployees.add(employee);

                    SystemEmployee systemEmployee = new SystemEmployee();
                    systemEmployee.setSysEmployeeOid(user.getFEmpInfoId());
                    systemEmployee.setEmployeeCode(user.getFEmpInfoIdFNUMBER());
                    systemEmployee.setEmployeeName(user.getFEmpInfoIdFNAME());
                    systemEmployee.setUserFk(user.getFEmpInfoId());
                    systemEmployee.setOrganiceFk(zuzhi.get(0).getSysOrganizeId());
                    systemEmployee.setDivisionFk(zuzhi.get(0).getSysOrganizeId());
                    systemEmployee.setMianPostFk(user.getFDept());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        systemEmployee.setBlockUp(false);
                        systemEmployee.setDel(0);
                    } else {
                        systemEmployee.setBlockUp(true);
                        systemEmployee.setDel(1);
                    }
                    systemEmployees.add(systemEmployee);

                    SysUser sysUser = new SysUser();
                    sysUser.setUserId(user.getFEmpInfoId());
                    sysUser.setUserName(user.getFEmpInfoIdFNUMBER());
                    sysUser.setUserEmployeeName(user.getFEmpInfoIdFNAME());
                    if ("A".equals(user.getFFORBIDSTATUS())) {
                        sysUser.setDel(0);
                    } else {
                        sysUser.setDel(1);
                    }
                    //处理密码加密
                    try {
                        String encryption = encryption(sysUser.getSalt(), "123456");
                        sysUser.setPassword(encryption);
                    } catch (Exception e) {
                        e.printStackTrace();
                    }

                    sysUsers.add(sysUser);

                    UfcSysEmployeeOrganize ufcSysEmployeeOrganize = new UfcSysEmployeeOrganize();
                    ufcSysEmployeeOrganize.setSysEmployeeoid(user.getFEmpInfoId());
                    ufcSysEmployeeOrganize.setSysOrganizeoid(zuzhi.get(0).getSysOrganizeId());
                    zuzhirenyuan.add(ufcSysEmployeeOrganize);
                }
            }
        }

        try {
            if (!EmptyUtil.isEmpty(sysEmployees)) {
                boolean b1 = employeeService.saveOrUpdateBatch(sysEmployees);
            }
            if (!EmptyUtil.isEmpty(sysEmployeesUpdate)) {
                employeeService.updateBatch(sysEmployeesUpdate);
            }

            if (!EmptyUtil.isEmpty(systemEmployees)) {
                boolean b2 = systemEmployeeService.saveOrUpdateBatch(systemEmployees);
            }
            if (!EmptyUtil.isEmpty(systemEmployeesUpdate)) {
                employeeService.updateBatchSystemEmployees(systemEmployeesUpdate);
            }

            if (!EmptyUtil.isEmpty(sysUsers)) {
                boolean b3 = userService.saveOrUpdateBatch(sysUsers);
            }
            if (!EmptyUtil.isEmpty(sysUsersUpdate)) {
                employeeService.updateBatchSysUser(sysUsersUpdate);
            }

            if (!EmptyUtil.isEmpty(zuzhirenyuan)) {
                ufcSysEmployeeOrganizeService.saveOrUpdateBatch(zuzhirenyuan);
            }
            if (!EmptyUtil.isEmpty(zuzhirenyuanUpdate)) {
                ufcSysEmployeeOrganizeService.updateBatchById(zuzhirenyuanUpdate);
            }


        } catch (Exception e) {
            System.out.println("-------------------" + e);
        }


        return new Result().toSuccess();
    }

    @Override
    public Result<String> syncUsers(ERPUserQueryDTO query) {
        int page = 1;
        //查询已同步人员
        List<SysEmployee> oldUser = employeeService.selectAll();

        //查询所有部门
        List<SysOrganize> organizes = sysorganizeser.getBaseMapper().selectList(null);
        while (true) {
            query.setLimit(50);
            query.setPage(page);
            Result<List<ERPUserVO>> users = queryUsers(query);
            if (!users.confirmSuccess()) {
                return new Result<>().toFailure(users.getMsg());
            }
            List<ERPUserVO> data = users.getData();
            if (data.size() == 0) {
                break;
            }
            page++;
            Result<String> result = saveUsers(data, oldUser, organizes);
            if (!result.confirmSuccess()) {
                return new Result<>().toFailure(result.getMsg());
            }
        }
        return new Result<String>().toSuccess();
    }

    @Override
    public Result selectIsuse(User user) {
        Result result = new Result();
        LambdaQueryWrapper<BFactory> queryWrapper = new LambdaQueryWrapper<>();
        queryWrapper.eq(BFactory::getDel, 0);
        queryWrapper.le(BFactory::getQyrq, LocalDateTime.now());
        queryWrapper.eq(BFactory::getTybz, false);
        if (!user.getUserId().toString().equals("758337585624907776")) {
            SysOrganize sysorganizeser = this.sysorganizeser.getById(user.getOrgOid());
            sysorganizeser = recursive(sysorganizeser);
            queryWrapper.eq(BFactory::getGcid, sysorganizeser.getOrganizeCode());
        }
        queryWrapper.orderByAsc(BFactory::getGcid);
        List<BFactory> bFactorylist = bFactoryMapper.selectList(queryWrapper);
        // 停用状态为未停用，启用时间小于等于当前时间并且没有设置停用时间或者停用数据大于等于当前时间
        return result.toSuccess(bFactorylist);
    }

    @Override
    @Transactional
    public Result delUser(Long userId) {
        employeeService.delSysUser(userId);
        employeeService.delSystemEmployees(userId);
        employeeService.delSysEmployees(userId);
        employeeService.delEmployeesOrganize(userId);
        return new Result().toSuccess();
    }

    //查询最上级组织机构
    private SysOrganize recursive(SysOrganize sysorganizeser) {
        SysOrganize sysOrganize = this.sysorganizeser.getBaseMapper().selectById(sysorganizeser.getOrgnizePid());
        if (!sysOrganize.getOrgnizePid().toString().equals("100000000000000000")) {
            sysOrganize = recursive(sysOrganize);
        }
        return sysOrganize;
    }

    public String encryption(String salt, String password) throws Exception {
        if (!EmptyUtil.isEmpty(salt)) {
            //盐值存在
            password += salt;
        }
        return MD5Utils.MD5(password);
    }


}
