package com.jln.system.web.action.erp.supplier.service.impl;


import com.baomidou.mybatisplus.core.conditions.query.LambdaQueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.system.web.action.bm.supplier.entity.BSuppliertype;
import com.jln.system.web.action.bm.supplier.service.BSuppliertypeService;
import com.jln.system.web.action.erp.supplier.entity.Supplier;
import com.jln.system.web.action.erp.supplier.jopo.vo.ERPSupplierVO;
import com.jln.system.web.action.erp.supplier.jopo.vo.ERPSuppliertypeVO;
import com.jln.system.web.action.erp.supplier.mapper.SupplierMapper;
import com.jln.system.web.action.erp.supplier.service.SupplierService;
import com.jln.system.web.action.util.ERPHttpUtils;
import com.jln.system.web.action.util.ERPParam;
import com.jln.system.web.action.util.ERPParams;
import com.jln.system.web.action.util.ERPQueryDTO;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Service;

import java.time.LocalDateTime;
import java.util.ArrayList;
import java.util.List;
import java.util.Map;
import java.util.stream.Collectors;

/**
 * <p>
 *  服务实现类
 * </p>
 *
 * @author 
 * @since 2021-11-02
 */
@Service
public class SupplierServiceImpl  extends ServiceImpl<SupplierMapper, Supplier> implements SupplierService {

    @Autowired
    private BSuppliertypeService bSuppliertypeService;

    @Override
    public Result<String> syncSupplierClass() {
        List<BSuppliertype> bSuppliertypeList = new ArrayList<>();
        ERPParam params = new ERPParam();
        //后台限制
        params.setFieldKeys("FID,FNUMBER,FNAME,FPARENTID");
        params.setFormId("BD_SupplierGRoup");
        params.setFilterString("FNUMBER in ('001','101')");
        int page = 1;
        while (true) {
            params.setLimit(50);
            params.setStartRow(params.getLimit() * (page - 1));
            Result<List<ERPSuppliertypeVO>> other = null;
            try {
                other = ERPHttpUtils.other(params,  ERPSuppliertypeVO.class);
            } catch (Exception e) {
                if (e instanceof NullPointerException) {
                    return new Result<>().toFailure("ERP未连接!");
                }
            }
            if (!other.confirmSuccess()) {
                return new Result<>().toFailure(other.getMsg());
            }
            if (other.getData().size() == 0) {
                break;
            }else {
                for (ERPSuppliertypeVO item:other.getData()) {
                    BSuppliertype bSuppliertype = new BSuppliertype();
                    bSuppliertype.setBSuppliertypeoid(item.getFID());
                    bSuppliertype.setFlid(item.getFNUMBER());
                    bSuppliertype.setFlmc(item.getFNAME());
                    bSuppliertype.setParentoid(item.getFPARENTID());
                    bSuppliertype.setSysLastUpd(LocalDateTime.now());
                    bSuppliertype.setSysLastUpdBy(0L);
                    bSuppliertypeList.add(bSuppliertype);
                }
            }
            page++;
        }
        boolean b = bSuppliertypeService.saveOrUpdateBatch(bSuppliertypeList);
        if (!b) {
            return new Result<String>().toFailure("保存供应商分类信息失败！");
        }
        return new Result().toSuccess();
    }

    @Override
    public Result<String> syncSupplier(ERPQueryDTO query) {
        List<Supplier> bSupplierList = new ArrayList<>();
        ERPParam params = new ERPParam();
        //后台限制
        params.setFieldKeys("FSupplierId,FNumber,FName,FShortName,FGroup,FUseOrgId");
        params.setFormId("BD_Supplier");
        params.setTopRowCount(0);
        params.setLimit(200);
        String erpParam = null;
        if (!EmptyUtil.isEmpty(query.getStartTime())) {
            erpParam="FModifyDate>'"+query.getStartTime().toString()+"' and "+"(FUseOrgId=100013 or FUseOrgId=100016 or FUseOrgId=100017 or FUseOrgId=100018) and FGroup.FNUMBER in ('001','101')";
        }else{
            erpParam="FUseOrgId=100013 or FUseOrgId=100016 or FUseOrgId=100017 or FUseOrgId=100018 and FGroup.FNUMBER in ('001','101')";
        }
        params.setFilterString(erpParam);
        int page = 1;
        while (true) {
            params.setStartRow(params.getLimit() * (page - 1));
            Result<List<ERPSupplierVO>> other = ERPHttpUtils.others(params,  ERPSupplierVO.class);
            if (!other.confirmSuccess()) {
                return new Result<>().toFailure(other.getMsg());
            }
            if (other.getData().size() == 0) {
                break;
            }else {
                List<ERPSupplierVO> data = other.getData();
                //获取erp分类主键对应的编码
                List<Long> collect = data.stream().map(ERPSupplierVO::getFGroup).distinct().collect(Collectors.toList());
                List<BSuppliertype> bSuppliertypeList = bSuppliertypeService.getBaseMapper().selectList(new LambdaQueryWrapper<BSuppliertype>().in(BSuppliertype::getBSuppliertypeoid, collect));
                //key:主键 val:编码
                Map<Long, String> longMap = bSuppliertypeList.stream().collect(Collectors.toMap(BSuppliertype::getBSuppliertypeoid, BSuppliertype::getFlid));
                for (ERPSupplierVO item:other.getData()) {
                    Supplier bSupplier = new Supplier();
                    bSupplier.setBSupplieroid(item.getFSupplierId());
                    bSupplier.setGysid(item.getFNumber());
                    bSupplier.setMc(item.getFName());
                    bSupplier.setJc(item.getFShortName());
                    bSupplier.setFl(longMap.get(item.getFGroup()));
                    bSupplier.setErpOrgId(item.getFUseOrgId());
                    bSupplier.setSysLastUpd(LocalDateTime.now());
                    bSupplier.setSysLastUpdBy(0L);
                    bSupplierList.add(bSupplier);
                }
            }
            page++;
            this.saveOrUpdateBatch(bSupplierList);
        }
        return new Result<String>().toSuccess();
    }

    @Override
    public Result getGyxList(PageParameter<Supplier> param) {
        Page<Supplier> page = new Page<>(param.getPageNum(),param.getPageSize());
        LambdaQueryWrapper<Supplier> wrapper = new LambdaQueryWrapper<>();
        if(!EmptyUtil.isEmpty(param.getData()) && !EmptyUtil.isEmpty(param.getData().getGysid())){
            wrapper.like(Supplier::getGysid,param.getData().getGysid());
        }
        if(!EmptyUtil.isEmpty(param.getData()) && !EmptyUtil.isEmpty(param.getData().getMc())){
            wrapper.like(Supplier::getMc,param.getData().getMc());
        }
        return new Result().setData(this.baseMapper.selectPageList(page,param.getData()));
    }
}
