package com.jln.system.web.action.erp.wo.controller;

import com.fasterxml.jackson.annotation.JsonIgnoreProperties;
import com.jln.common.annotation.ApplyForPermission;
import com.jln.common.annotation.LoginUser;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.system.web.action.erp.wo.pojo.*;
import com.jln.system.web.action.erp.wo.service.WoErpService;
import com.jln.system.web.action.pp.planImport.pojo.dto.WoDto;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

/**
 * @ClassName:
 * @Description:
 * @Author:三刀 Date:2021/10/28 15:36
 * Version:1.0
 **/
@RestController
@RequestMapping("/erp/wo")
@Api(tags = "订单部分-同步接口", description = "订单部分-同步接口")
public class WoErpController {

    @Autowired
    private WoErpService woErpService;

    @ApiOperation(value = "订单初始化接口", notes = "订单初始化接口")
    @PostMapping("/woInit")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result woInit(@RequestBody List<WoInitDto> woInitDtoList, @LoginUser User user){
        return woErpService.woInit(woInitDtoList,user);
    }

    @ApiOperation(value = "订单修改接口", notes = "订单修改接口")
    @PostMapping("/orderModify")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result orderModify(@RequestBody List<WoInitDto> woInitDtoList, @LoginUser User user){
        return woErpService.orderModify(woInitDtoList,user);
    }

    @ApiOperation(value = "订单删除接口", notes = "订单删除接口")
    @PostMapping("/removeOrder")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result removeOrder(@RequestBody List<String> codeList){
        return woErpService.removeOrder(codeList);
    }

    @ApiOperation(value = "订单物料清单-修改接口", notes = "订单物料清单-修改接口")
    @PostMapping("/materialsModify")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result materialsModify(@RequestBody WoBomErp woBomErp, @LoginUser User user){
        return woErpService.materialsModify(woBomErp,user);
    }

    @ApiOperation(value = "订单工艺路线-修改接口", notes = "订单工艺路线-修改接口")
    @PostMapping("/processRouteModify")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result processRouteModify(@RequestBody WogylxErp wogylxErp, @LoginUser User user){
        return woErpService.processRouteModify(wogylxErp,user);
    }

    @ApiOperation(value = "订单工艺路线删除接口", notes = "订单工艺路线删除接口")
    @PostMapping("/processRouteRemove")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result processRouteRemove(@RequestBody List<WogylxRemove> wogylxRemoves){
        return woErpService.processRouteRemove(wogylxRemoves);
    }

    @ApiOperation(value = "订单物料清单删除接口", notes = "订单物料清单删除接口")
    @PostMapping("/materialsRemove")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result materialsRemove(@RequestBody List<WobomRemove> wogylxRemoves){
        return woErpService.materialsRemove(wogylxRemoves);
    }

    @ApiOperation(value = "获取辅助属性：精度、质量等级", notes = "获取辅助属性：精度、质量等级")
    @GetMapping("/getFzsx")
    @JsonIgnoreProperties(ignoreUnknown = true)
    public Result getFzsx(@RequestParam String type){
        return woErpService.getFzsx(type);
    }

    @ApiOperation(value = "生产订单维护接口——生产订单保存", notes = "生产订单维护接口——生产订单保存")
    @PostMapping("/saveWoUfc")
    public Result saveWoUfc(@RequestBody WoDto wo, @LoginUser User user) {
        return woErpService.saveWo(wo, user);
    }

    /**
     * erp负责调用接口 ，如果没有订单数据，erp可以修改订单，否则更具订单状态判断是否为初始状态再确定是否可以修改
     * @param woid 订单编号
     * @return
     */
    @ApiOperation(value = "erp订单是否允许反审核", notes = "erp订单是否允许反审核")
    @PostMapping("/getErpWoInfo")
    public Boolean getErpWoInfo(@RequestBody List<String> woid){
        return woErpService.getErpWoInfo(woid);
    }

    /**
     * erp反审核删除mes订单接口
     *
     * @param woid
     * @return
     */
    @ApplyForPermission
    @ApiOperation(value = "erp反审核删除mes订单接口 ", notes = "erp反审核删除mes订单接口")
    @PostMapping("/erpDelWo")
    public Result erpDelWo(@RequestBody List<String> woid) {
        return woErpService.erpDelWo(woid);
    }
}
