package com.jln.system.web.action.erp.wo.pojo;

import com.baomidou.mybatisplus.annotation.TableId;
import com.baomidou.mybatisplus.annotation.TableLogic;
import com.baomidou.mybatisplus.extension.activerecord.Model;
import com.fasterxml.jackson.annotation.JsonFormat;
import com.jln.common.constant.LocalDateTimeConst;
import io.swagger.annotations.ApiModelProperty;
import lombok.Data;
import lombok.EqualsAndHashCode;
import lombok.experimental.Accessors;

import javax.validation.constraints.NotEmpty;
import javax.validation.constraints.NotNull;
import java.io.Serializable;
import java.math.BigDecimal;
import java.time.LocalDate;
import java.time.LocalDateTime;

/**
 * <p>
 * 生产订单
 * </p>
 *
 * @author 
 * @since 2020-02-08
 */
@Data
@EqualsAndHashCode(callSuper = false)
@Accessors(chain = true)
public class ErpWo extends Model<ErpWo> {

    private static final long serialVersionUID = 1L;

    @TableId
    @ApiModelProperty(example = "生产订单主键", required = true,dataType = "string")
    private Long wooid;

    @NotEmpty(message = "生产订单号不能为空")
    @ApiModelProperty(example = "生产订单号（生产订单号接口获取）:2020020001", required = true,dataType = "string")
    private String woid;

    @NotEmpty(message = "订单类型不能为空")
    @ApiModelProperty(example = "订单类型:VP|量产、SM|试产、PP|小批量、RM|改型、RW|返工、RP|返修", required = true,dataType = "string")
    private String lx;

    @ApiModelProperty(example = "计划开工日期:2020-02-20", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate jhkgrq;

    @ApiModelProperty(example = "计划完工日期:2020-02-20", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate jhwgrq;

    @ApiModelProperty(example = "实际开工日期:2020-02-20", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate sjkgrq;

    @ApiModelProperty(example = "实际完工日期:2020-02-20", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate sjwgrq;

    @NotEmpty(message = "排产方式不能为空")
    @ApiModelProperty(example = "排产方式:S|顺排、D|倒排、N|排产时指定", required = true,dataType = "string")
    private String pcfs;

    @ApiModelProperty(example = "排产优先级:0、1、2、3", required = true)
    private BigDecimal pcyxj;

    @NotEmpty(message = "生成方式不能为空")
    @ApiModelProperty(example = "生成方式:EX|手工维护、JH|生产计划、IM|接口导入", required = true,dataType = "string")
    private String scfs;

    @ApiModelProperty(example = "制令号:990323", required = true,dataType = "string")
    private String zlh;

    @NotNull(message = "需求数量不能为空")
    @ApiModelProperty(example = "需求数量:10000", required = true)
    private BigDecimal xqsl;

    @ApiModelProperty(example = "完成数量:1000", required = true)
    private BigDecimal wcsl;

    @ApiModelProperty(example = "料费数量:1000", required = true)
    private BigDecimal lfsl;

    @ApiModelProperty(example = "工废数量:1000", required = true)
    private BigDecimal fpsl;

    @ApiModelProperty(example = "回用数量:1000", required = true)
    private BigDecimal hysl;

    @ApiModelProperty(example = "入库单数量:1000", required = true)
    private BigDecimal rkdsl;

    @ApiModelProperty(example = "入库数量:1000", required = true)
    private BigDecimal rksl;

    @ApiModelProperty(example = "已排产数量:1000", required = true)
    private BigDecimal ypcsl;

    @ApiModelProperty(example = "退料数量:1000", required = true)
    private BigDecimal tlsl;

    @ApiModelProperty(example = "拆分数量:1000", required = true)
    private BigDecimal cfsl;

    @ApiModelProperty(example = "拆分前总数量:1000", required = true)
    private BigDecimal cfqsl;

    @ApiModelProperty(example = "废品扣减计划数:0|未选择，1|已选择", required = true,dataType = "int")
    private Integer fp;

    @ApiModelProperty(example = "变更标志:0|未变更，1|已变更", required = true,dataType = "int")
    private Integer bg;

    @ApiModelProperty(example = "父生产订单号:2020020001", required = true,dataType = "string")
    private String fwoid;

    @ApiModelProperty(example = "父工序号:0、1、2", required = true,dataType = "int")
    private Integer fgxid;

    @ApiModelProperty(example = "完工备注", required = true,dataType = "string")
    private String wgbz;

    @ApiModelProperty(example = "原生产订单号:2020020001", required = true,dataType = "string")
    private String ywoid;


    @ApiModelProperty(example = "原状态:I|初始、F|确认、R|下达、S|暂停；C|完成", required = true,dataType = "string")
    private String yzt;

    @ApiModelProperty(example = "确认人:token获取", required = true,dataType = "string")
    private Long qrr;


    @ApiModelProperty(example = "确认日期:自动生成", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate qrrq;

    @ApiModelProperty(example = "下达人:token获取", required = true,dataType = "string")
    private Long xdr;

    @ApiModelProperty(example = "下达日期:自动生成", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate xdrq;

    @ApiModelProperty(example = "关闭人:token获取", required = true,dataType = "string")
    private Long gbr;

    @ApiModelProperty(example = "关闭日期:自动生成", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_PATTERN)
    private LocalDate gbrq;

    @ApiModelProperty(example = "备注", required = true,dataType = "string")
    private String bz;

    @NotEmpty(message = "订单状态不能为空")
    @ApiModelProperty(example = "订单状态:I|初始、F|确认、R|下达、S|暂停；C|完成", required = true,dataType = "string")
    private String zt;

    @ApiModelProperty(example = "创建人:token获取", required = true,dataType = "string")
    private Long sysCreatedBy;

    @ApiModelProperty(example = "创建日期:自动生成", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysCreated;

    @ApiModelProperty(example = "最后修改日期:自动生成", required = true,dataType = "date")
    @JsonFormat(pattern = LocalDateTimeConst.DATE_TIME_PATTERN)
    private LocalDateTime sysLastUpd;

    @NotNull(message = "物料外键不能为空")
    @ApiModelProperty(example = "物料外键", required = true,dataType = "string")
    private Long bMaterialFk;

    @NotNull(message = "工厂外键不能为空")
    @ApiModelProperty(example = "工厂外键", required = true,dataType = "string")
    private Long bFactoryFk;

    @NotNull(message = "车间外键不能为空")
    @ApiModelProperty(example = "车间外键", required = true,dataType = "string")
    private Long bWorkshopFk;

    @ApiModelProperty(example = "产品工艺流程外键", required = true,dataType = "string")
    private Long bProductprocessFk;

    @ApiModelProperty(example = "产品结构号", required = true,dataType = "string")
    private String bomid;

    @ApiModelProperty(example = "最后修改人:token获取", required = true,dataType = "string")
    private Long sysLastUpdBy;

    @TableLogic
    @ApiModelProperty(example = "删除标记:自动生成", required = true,dataType = "int")
    private Integer del;

    @ApiModelProperty(example = "产品结构外键", required = true,dataType = "string")
    private Long bBomFk;


    @ApiModelProperty(example = "技术参数", value = "技术参数", required = true, dataType = "string",position = 101)
    private String jscs;
    @ApiModelProperty(example = "物料属性值", value = "物料属性值", required = true, dataType = "string",position = 102)
    private String wlsxz;
    @ApiModelProperty(example = "批次属性值", value = "批次属性值", required = true, dataType = "string",position = 103)
    private String pcsxz;

    @ApiModelProperty(example = "投料的时候使用的已投料数量", hidden = true)
    private BigDecimal ywcsl;

    @ApiModelProperty(example = "紧急程度等级编码", hidden = true)
    private String udid;

    @ApiModelProperty(example = "紧急程度等级外键")
    private Long budFk;
    @ApiModelProperty(value = "投料控制规则：1|生产订单投料控制、2|作业计划投料控制、3|作业工序投料控制、4|投料不控制")
    private String releaseControlType;
    @ApiModelProperty(value = "投料控制方式:1|直接投料、2|扫码投料、3|线边仓投料")
    private String feedingControlMode;

    @Override
    protected Serializable pkVal() {
        return this.wooid;
    }

}
