package com.jln.system.web.action.mes.qc.controller;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.jln.common.annotation.ApplyForPermission;
import com.jln.common.annotation.IgnoreUserLoginToken;
import com.jln.common.annotation.LoginUser;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.system.web.action.mes.qc.entity.SelectPages;
import com.jln.system.web.action.mes.qc.entity.StorageDetail;
import com.jln.system.web.action.mes.qc.entity.vo.DetailVo;
import com.jln.system.web.action.mes.qc.entity.vo.StorageDetailVO;
import com.jln.system.web.action.mes.qc.entity.vo.TimeGapVO;
import com.jln.system.web.action.mes.qc.service.StorageNoticeDetailsService;
import com.jln.ufc.web.action.ufc.pp.pojo.vo.UfcGdpcQueryVo;
import com.jln.ufc.web.action.ufc.ps.pojo.vo.UfcPsWsList;
import com.jln.ufc.web.action.ufc.ps.service.UfcPsWsService;
import io.swagger.annotations.Api;
import io.swagger.annotations.ApiOperation;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.web.bind.annotation.*;

import java.util.List;

@RestController
@RequestMapping(value = "/erp.qc/ufcStorageNotice/Detial")
@Api(value = "入库通知详情数据操作",tags = "入库通知详情数据操作API")
public class NoticesDetailController {

    @Autowired
    private StorageNoticeDetailsService detailsService;

    @Autowired
    private UfcPsWsService psWsService;

    @PostMapping(value = "/addDetail")
    @ApiOperation(value = "新增/修改 入库详情", notes = "批量操作")
    public Result addDetail(@RequestBody List<StorageDetail> detail, @LoginUser User user){
        return detailsService.saveDetail(detail,user);
    }

    @PostMapping(value = "/delDetail")
    @ApiOperation(value = "删除入库详情", notes = "0 未删除/1 已删除")
    public Result delDetail(@RequestBody List<Long> ids,@LoginUser User user){
        return detailsService.delDetail(ids,user);
    }

    @PostMapping(value = "/findProcessCard")
    @ApiOperation(value = "流程卡查询", notes = "生产订单号，源单号，流程卡号，维护时间，合同号，规格型号")
    public Result findProcessCard(@RequestBody StorageDetailVO detailVO){
        return detailsService.findProcessCard(detailVO);
    }

    @PostMapping(value = "/findDetail")
    @ApiOperation(value = "详情查询", notes = "流程卡查询")
    public Result findDetail(@RequestBody DetailVo detailVo){
        return detailsService.findDetail(detailVo);
    }

    /**
     * 生产订单排程接口——生产订单排程列表
     * @param page
     * @return
     */
    @ApplyForPermission
    @ApiOperation(value = "生产订单排程接口——生产关闭--定制接口", notes = "生产订单排程接口——生产关闭--定制接口")
    @PostMapping("/getPsWsCloseLists")
    public Result<Page<UfcPsWsList>> getPsWsCloseLists(@RequestBody PageParameter<UfcGdpcQueryVo> page) {
        if(EmptyUtil.isEmpty(page.getData())){
            page.setData(new UfcGdpcQueryVo());
        }
        page.getData().setParamType(3);
        return psWsService.getPsWsLists(page);
    }

}
