package com.jln.system.web.action.mes.qc.service.impl;

import com.baomidou.mybatisplus.core.conditions.query.QueryWrapper;
import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.User;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.mes.qc.commom.Contains;
import com.jln.system.web.action.mes.qc.entity.StorageDetail;
import com.jln.system.web.action.mes.qc.entity.vo.DetailVo;
import com.jln.system.web.action.mes.qc.entity.vo.StorageDetailVO;
import com.jln.system.web.action.mes.qc.entity.vo.TimeGapVO;
import com.jln.system.web.action.mes.qc.mapper.StorageNoticesDetailMapper;
import com.jln.system.web.action.mes.qc.service.StorageNoticeDetailsService;
import org.springframework.stereotype.Service;
import com.jln.common.entity.Result;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.util.List;

@Service
public class StorageNoticeDetailsServiceImpl extends ServiceImpl<StorageNoticesDetailMapper, StorageDetail> implements StorageNoticeDetailsService {

    @Resource
    private StorageNoticesDetailMapper storageNoticesDetailMapper;

    @Override
    public Result saveDetail(List<StorageDetail> details, User user) {
        if (details.size() == 0){
            return new Result().toFailure(Contains.EmptyDatas);
        }else {
            for (StorageDetail item: details ) {
                if (EmptyUtil.isEmpty(item.getId())){
                    //自动填充主键
                    item.setId(SnowflakeIdUtils.generate());
                }
                //操作人
                item.setSysLastUpd(LocalDateTime.now());
                item.setSysLastUpdBy(user.getEmployeeOid());
            }

            boolean flag = this.saveOrUpdateBatch(details);
            if (flag){
                return new Result().toSuccess();
            }else {
                return new Result().toFailure(Contains.BatchUDPError);
            }
        }
    }

    @Override
    public Result delDetail(List<Long> ids,User user) {
        if (ids.size() > 0){
            for (Long item: ids) {
                StorageDetail detail = storageNoticesDetailMapper.selectById(item);
                if (detail != null ){
                    if (detail.getDel() == 0){
                        detail.setDel(1);
                        detail.setSysLastUpd(LocalDateTime.now());
                        detail.setSysLastUpdBy(user.getEmployeeOid());
                        storageNoticesDetailMapper.updateById(detail);
                    }else {
                        return new Result<>().toFailure(Contains.DELError);
                    }
                }else {
                    return new Result<>().toFailure(Contains.DataNotFind);
                }
            }
            return new Result().toSuccess();
        }else {
            return new Result<>().toFailure(Contains.EmptyDatas);
        }
    }

    @Override
    public Result findProcessCard(StorageDetailVO detailVO) {
        if (detailVO != null){
            //构造查询条件
            QueryWrapper<StorageDetail> wrapper = new QueryWrapper<StorageDetail>()
                    .like(!EmptyUtil.isEmpty(detailVO.getOrderId()),"order_id", detailVO.getOrderId())
                    .like(!EmptyUtil.isEmpty(detailVO.getContractId()),"contract_id", detailVO.getContractId())
                    .like(!EmptyUtil.isEmpty(detailVO.getSourceId()),"source_id", detailVO.getSourceId())
                    .like(!EmptyUtil.isEmpty(detailVO.getProcessCard()),"process_card", detailVO.getProcessCard())
                    .eq(!EmptyUtil.isEmpty(detailVO.getSysLastUpd()),"sys_last_upd", detailVO.getSysLastUpd())
                    .eq(!EmptyUtil.isEmpty(detailVO.getIdFk()),"storage_notice_fk",detailVO.getIdFk())
                    //未删除 0 /已删除 1
                    .eq("del",0)
                    .between(!EmptyUtil.isEmpty(detailVO.getStart()) && !EmptyUtil.isEmpty(detailVO.getEnd()),"qyrq",detailVO.getStart(),detailVO.getEnd());
            Page<StorageDetail> page = new Page<>(detailVO.getCurrent(),detailVO.getPageSize());
            Page<StorageDetail> data = storageNoticesDetailMapper.selectPage(page,wrapper);
            return new Result().toSuccess(data);
        }else {
            return new Result().toFailure(Contains.ParametersError);
        }
    }

    @Override
    public Result findDetail(DetailVo detailVo) {
        if (detailVo == null){
            return new Result().toFailure(Contains.ParametersError);
        }
        Page<StorageDetail> page = new Page<>(detailVo.getCurrent(),detailVo.getPageSize());
        Page<StorageDetail> datas = storageNoticesDetailMapper.selectPage(page, new QueryWrapper<StorageDetail>()
                .eq("storage_notice_fk", detailVo.getId())
                .eq("del", 0));
        if (datas.getTotal() > 0){
            return new Result().toSuccess(datas);
        }else {
            return new Result().toFailure(Contains.EmptyDatas);
        }
    }
}
