package com.jln.system.web.action.mes.qc.service.impl;

import com.baomidou.mybatisplus.extension.plugins.pagination.Page;
import com.baomidou.mybatisplus.extension.service.impl.ServiceImpl;
import com.jln.common.entity.Result;
import com.jln.common.entity.User;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.PageParameter;
import com.jln.common.utils.SnowflakeIdUtils;
import com.jln.system.web.action.mes.qc.commom.Contains;
import com.jln.system.web.action.mes.qc.entity.StorageNotice;
import com.jln.system.web.action.mes.qc.entity.dto.FactoryWorkDTO;
import com.jln.system.web.action.mes.qc.entity.dto.NoticeListDTO;
import com.jln.system.web.action.mes.qc.entity.dto.StorageNoticeDTO;
import com.jln.system.web.action.mes.qc.entity.vo.StorageNoticeVO;
import com.jln.system.web.action.mes.qc.mapper.StorageNoticesMapper;
import com.jln.system.web.action.mes.qc.service.StorageNoticesService;
import org.springframework.stereotype.Service;

import javax.annotation.Resource;
import java.time.LocalDateTime;
import java.time.format.DateTimeFormatter;
import java.util.List;

@Service(value = "storageNoticesService")
public class StorageNoticesServiceImpl extends ServiceImpl<StorageNoticesMapper,StorageNotice> implements StorageNoticesService {

    @Resource
    private StorageNoticesMapper storageNoticesMapper;

    @Override
    public Result saveNotice(StorageNotice storageNotice,User user) {
        if (storageNotice != null){
            if(EmptyUtil.isEmpty(storageNotice.getCode())){
                //生成主键id
                Long id = SnowflakeIdUtils.generate();
                //生成流水号 8(年月日) + 5  --> 00005
                String format = DateTimeFormatter.ofPattern("yyyyMMdd").format(LocalDateTime.now());
                int serialNumber = storageNoticesMapper.getSerialNumber(format);
                String suffix = String.format("%05d", serialNumber);

                //信息填充
                storageNotice.setId(id);
                storageNotice.setCreateBy(user.getEmployeeOid());
                storageNotice.setSysLastUpdBy(user.getEmployeeOid());
                storageNotice.setSysLastUpd(LocalDateTime.now());
                storageNotice.setCode(format + suffix);
                storageNotice.setQyrq(LocalDateTime.now());
                int count = storageNoticesMapper.insert(storageNotice);
                if (count != 0){
                    return new Result<>().toSuccess(id);
                }else {
                    return new Result().toFailure(Contains.InsertError);
                }
            }else {
                storageNotice.setSysLastUpdBy(user.getEmployeeOid());
                storageNotice.setSysLastUpd(LocalDateTime.now());
                int count = storageNoticesMapper.updateById(storageNotice);
                if (count != 0){
                    return new Result<>().toSuccess();
                }else {
                    return new Result().toFailure(Contains.UpdateError);
                }
            }
        }
        return new Result().toFailure(Contains.ParametersError);
    }

    @Override
    public Result delNotice(List<Long> ids,User user) {
        if (ids.size() > 0) {
            for (Long id : ids) {
                StorageNotice storageNotice = storageNoticesMapper.selectById(id);
                if (storageNotice != null) {
                    if (storageNotice.getDel() == 0) {
                        storageNotice.setDel(1);
                        storageNotice.setSysLastUpd(LocalDateTime.now());
                        storageNotice.setSysLastUpdBy(user.getEmployeeOid());
                        storageNoticesMapper.updateById(storageNotice);
                    }
                } else {
                    return new Result<>().toFailure(Contains.DataNotFind);
                }
            }
        } else {
            return new Result<>().toFailure(Contains.ParametersError);
        }
        return new Result().toSuccess(ids);
    }

    @Override
    public Result modifyNotice(List<Long> ids,User user) {
        //成功处理修改的数量
        int count = 0;
        for (Long item: ids ) {
            StorageNotice storageNotice = storageNoticesMapper.selectById(item);
            if (storageNotice.getStatus() == 0){
                storageNotice.setSysLastUpd(LocalDateTime.now());
                storageNotice.setSysLastUpdBy(user.getEmployeeOid());
                storageNotice.setStatus(1);
                storageNoticesMapper.updateById(storageNotice);
                count++;
            }else {
                return new Result<>().toFailure("第"+ (++count) +"状态非未处理,批处理中断");
            }
        }
        return new Result<>().toSuccess();
    }

    @Override
    public Result reNotice(Long id,User user) {
        if (EmptyUtil.isEmpty(id)){
            return new Result().toFailure(Contains.ParametersError);
        }
        StorageNotice storageNotice = storageNoticesMapper.selectById(id);
        if (storageNotice == null){
            return new Result().toFailure(Contains.DataNotFind);
        }else if (storageNotice.getStatus() != 1){
            return new Result<>().toFailure(Contains.StatusDealError);

        }else {
            storageNotice.setStatus(0);
            storageNotice.setSysLastUpd(LocalDateTime.now());
            storageNotice.setSysLastUpdBy(user.getEmployeeOid());
            int count = storageNoticesMapper.updateById(storageNotice);
            if (count != 0){
                return new Result<>().toSuccess();
            }else {
                return new Result().toFailure(Contains.UpdateError);
            }
        }
    }

    @Override
    public Result getNotices(PageParameter<StorageNoticeVO> parameter, User user) {
        Page<NoticeListDTO> psListPage = storageNoticesMapper.getRecords(new Page(parameter.getPageNum(), parameter.getPageSize()), parameter.getData());
        return new Result().toSuccess(psListPage);
    }

    @Override
    public Result getFactoryWork(User user) {
        Long employeeOid = user.getEmployeeOid();
        FactoryWorkDTO data = new FactoryWorkDTO();
        data.setFactoryId(storageNoticesMapper.getFactoryIds(employeeOid));
        data.setWorkShopId(storageNoticesMapper.getWorkShopIds(employeeOid));
        if (data == null){
            return new Result().toFailure(Contains.NoAnyDatas);
        }else {
            return new Result().toSuccess(data);
        }
    }

}
