package com.jln.system.web.action.util;

import com.alibaba.fastjson.JSON;
import com.alibaba.fastjson.JSONArray;
import com.alibaba.fastjson.JSONObject;
import com.jln.common.constant.ApiConst;
import com.jln.common.entity.Result;
import com.jln.common.exception.CustomException;
import com.jln.common.utils.EmptyUtil;
import com.jln.common.utils.HttpDeleteWithBody;
import com.jln.system.web.action.mes.user.entity.SysEmployee;
import org.apache.http.NameValuePair;
import org.apache.http.client.entity.UrlEncodedFormEntity;
import org.apache.http.client.methods.CloseableHttpResponse;
import org.apache.http.client.methods.HttpPost;
import org.apache.http.entity.ContentType;
import org.apache.http.entity.StringEntity;
import org.apache.http.impl.client.CloseableHttpClient;
import org.apache.http.impl.client.HttpClients;
import org.apache.http.message.BasicNameValuePair;
import org.apache.http.util.EntityUtils;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.stereotype.Component;
import java.io.IOException;
import java.lang.reflect.Field;
import java.time.LocalDate;
import java.time.LocalDateTime;
import java.util.*;
import java.util.stream.Collectors;
@Component
public class ERPHttpUtils {

    private static String ERP_ACCT_ID;

    private static String ERP_USERNAME;

    private static String ERP_PASSWORD;

    private static String ERP_LOGIN_URL;

    private static String ERP_LCID_CN;

    private static String ERP_OTHER_URL;

    private static String COOKIE;

    private static String DEFAULT_CHARSET;

    @Value("${erp.ERP_ACCT_ID}")
    public void setErpAcctId(String erpAcctId) {
        ERPHttpUtils.ERP_ACCT_ID = erpAcctId;
    }

    @Value("${erp.ERP_USERNAME}")
    public void setErpUsername(String erpUsername) {
        ERPHttpUtils.ERP_USERNAME = erpUsername;
    }

    @Value("${erp.ERP_PASSWORD}")
    public void setErpPassword(String erpPassword) {
        ERP_PASSWORD = erpPassword;
    }

    @Value("${erp.ERP_LOGIN_URL}")
    public void setErpLoginUrl(String erpLoginUrl) {
        ERP_LOGIN_URL = erpLoginUrl;
    }

    @Value("${erp.ERP_LCID_CN}")
    public void setErpLcidCn(String erpLcidCn) {
        ERP_LCID_CN = erpLcidCn;
    }

    @Value("${erp.ERP_OTHER_URL}")
    public void setErpOtherUrl(String erpOtherUrl) {
        ERP_OTHER_URL = erpOtherUrl;
    }

    @Value("${erp.COOKIE}")
    public void setCOOKIE(String COOKIE) {
        ERPHttpUtils.COOKIE = COOKIE;
    }

    @Value("${erp.DEFAULT_CHARSET}")
    public void setDefaultCharset(String defaultCharset) {
        DEFAULT_CHARSET = defaultCharset;
    }

    public static Result<CookieData> login() {
        Map<String, String> loginInfo = new HashMap();
        loginInfo.put("acctID",ERP_ACCT_ID);
        loginInfo.put("username",ERP_USERNAME);
        loginInfo.put("password",ERP_PASSWORD);
        loginInfo.put("lcid", ERP_LCID_CN);
        String r = doPost1(ERP_LOGIN_URL, loginInfo,null);
        JSONObject result = JSONObject.parseObject(r);
        Integer resultType = result.getInteger("LoginResultType");
        System.out.println(result);
        if (resultType.equals(1)) {
            CookieData cookie = new CookieData();
            JSONObject context = result.getJSONObject("Context");
            String sessionId = context.getString("SessionId");
            String kdsvcSessionId = result.getString("KDSVCSessionId");
            cookie.setLoginResultType(1);
            cookie.setSessionId(sessionId);
            cookie.setKdsvcSessionId(kdsvcSessionId);
            return new Result<CookieData>().toSuccess(cookie);
        }
        String message = result.getString("Message");
        return new Result<String>().toFailure(message);
    }

    /**
     * @param <T>
     * @return
     */

    public static <T> Result<List<T>> other(ERPParams params, Class<T> clazz) {
        Result<CookieData> login = login();
        if (!login.confirmSuccess()) {
            return new Result<>().toFailure(login.getMsg());
        }
        String paraStr = JSONObject.toJSONString(params);
        Map<String, String> map = new HashMap<>();
        map.put("data", paraStr);
        String r = doPost(ERP_OTHER_URL, map, "kdservice-sessionid=" + login.getData().getKdsvcSessionId() + ";ASP.NET_SessionId=" + login.getData().getSessionId());
        List<JSONArray> arrays = JSONObject.parseArray(r, JSONArray.class);
        if (clazz == null) {
            return new Result().toSuccess(arrays);
        }
        List<T> list = new ArrayList<>();
        for (JSONArray array : arrays) {
            try {
                //new 一个数据对象
                T t1 = clazz.newInstance();
                //拆分属性字段
                String[] fieldKeys = params.getFieldKeys().split(",");
                for (int i = 0; i < fieldKeys.length; i++) {
                    String fieldKey = fieldKeys[i].replace(".","");
                    try {
                        //是否是属性对象
                        String[] split = fieldKey.split("\\.");
                        //建立一个临时对象指向需要存储的属性
                        Object t2 = t1;
                        //建立一个临时Class指向需要存储的属性的Class
                        Class tc = clazz;
                        for (int j = 0; j < split.length; j++) {
                            Field field = tc.getDeclaredField(split[j]);
                            field.setAccessible(true);
                            //没有子属性对象了，将数
                            if (j == split.length - 1) {
//                                field.set(t2, array.get(i));
                                setAccessible(t2, field, array.get(i));
                                continue;
                            }
                            //获取子对象
                            Object o1 = field.get(t1);
                            //如果子对象为null则新建一个
                            if (o1 == null) {
                                Object o2 = field.getType().newInstance();
                                tc = o2.getClass();
                                t2 = o2;
//                                field.set(t1, o2);
                                setAccessible(t1, field, o2);
                            } else {
                                tc = o1.getClass();
                                t2 = o1;
                            }
                        }
                    } catch (NoSuchFieldException e) {
                        throw new CustomException(-1, clazz.getTypeName() + "没有【" + fieldKey + "】字段");
                    }
                }
                list.add(t1);
            } catch (InstantiationException e) {
                e.printStackTrace();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return new Result().toSuccess(list);
    }

    private static void setAccessible(Object o, Field field, Object value) {
        field.setAccessible(true);
        try {
            if (value == null) {
                field.set(o, null);
                return;
            }
            switch (field.getGenericType().getTypeName()) {
                case "java.lang.String":
                    field.set(o, value.toString());
                    break;
                case "double":
                case "java.lang.Double":
                    field.set(o, Double.parseDouble(value.toString()));
                    break;
                case "java.time.LocalDate":
                    field.set(o, LocalDate.parse(value.toString()));
                    break;
                case "java.time.LocalDateTime":
                    field.set(o, LocalDateTime.parse(value.toString()));
                    break;
                case "int":
                case "java.lang.Integer":
                    field.set(o, Integer.parseInt(value.toString()));
                    break;
                case "boolean":
                case "java.lang.Boolean":
                    field.set(o, Boolean.parseBoolean(value.toString()));
                    break;
                case "float":
                case "java.lang.Float":
                    field.set(o, Float.parseFloat(value.toString()));
                    break;
                case "long":
                case "java.lang.Long":
                    field.set(o, Long.parseLong(value.toString()));
                    break;
                default:
                    field.set(o, value);
            }
        } catch (IllegalAccessException e) {
            e.printStackTrace();
        }
    }


    public static void main(String[] args) {
      List<SysEmployee>  employees = new ArrayList<>();
        Map<String, SysEmployee> employeeMap = employees.stream().collect(Collectors.toMap(SysEmployee::getCodeing, o -> o));
        System.out.println();
        System.out.println();
        System.out.println();

    }



    public static <T> Result<List<T>> others(ERPParam params, Class<T> clazz) {
        Result<CookieData> login = login();
        if (!login.confirmSuccess()) {
            return new Result<>().toFailure(login.getMsg());
        }
        String paraStr = JSONObject.toJSONString(params);
        Map<String, String> map = new HashMap<>();
        map.put("data", paraStr);
        String r = doPost(ERP_OTHER_URL, map, "kdservice-sessionid=" + login.getData().getKdsvcSessionId() + ";ASP.NET_SessionId=" + login.getData().getSessionId());
        List<JSONArray> arrays = JSONObject.parseArray(r, JSONArray.class);
        System.out.println("ERP : " + arrays.toString());
        if (clazz == null) {
            return new Result().toSuccess(arrays);
        }
        List<T> list = new ArrayList<>();
        for (JSONArray array : arrays) {
            try {
                //new 一个数据对象
                T t1 = clazz.newInstance();
                //拆分属性字段
                String[] fieldKeys = params.getFieldKeys().split(",");
                for (int i = 0; i < fieldKeys.length; i++) {
                    String fieldKey = fieldKeys[i];
                    try {
                        //是否是属性对象
                        String[] split = fieldKey.split("\\.");
                        //建立一个临时对象指向需要存储的属性
                        Object t2 = t1;
                        //建立一个临时Class指向需要存储的属性的Class
                        Class tc = clazz;
                        for (int j = 0; j < split.length; j++) {
                            Field field = tc.getDeclaredField(split[j]);
                            field.setAccessible(true);
                            //没有子属性对象了，将数
                            if (j == split.length - 1) {
//                                field.set(t2, array.get(i));
                                setAccessible(t2, field, array.get(i));
                                continue;
                            }
                            //获取子对象
                            Object o1 = field.get(t1);
                            //如果子对象为null则新建一个
                            if (o1 == null) {
                                Object o2 = field.getType().newInstance();
                                tc = o2.getClass();
                                t2 = o2;
//                                field.set(t1, o2);
                                setAccessible(t1, field, o2);
                            } else {
                                tc = o1.getClass();
                                t2 = o1;
                            }
                        }
                    } catch (NoSuchFieldException e) {
                        throw new CustomException(-1, clazz.getTypeName() + "没有【" + fieldKey + "】字段");
                    }
                }
                list.add(t1);
            } catch (InstantiationException e) {
                e.printStackTrace();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return new Result().toSuccess(list);
    }

    public static <T> Result<List<T>> other(ERPParam params, Class<T> clazz) {
        Result<CookieData> login = login();
        if (!login.confirmSuccess()) {
            return new Result<>().toFailure(login.getMsg());
        }
        String paraStr = JSONObject.toJSONString(params);
        Map<String, String> map = new HashMap<>();
        map.put("data", paraStr);
        String r = doPost(ERP_OTHER_URL, map, "kdservice-sessionid=" + login.getData().getKdsvcSessionId() + ";ASP.NET_SessionId=" + login.getData().getSessionId());
        List<JSONArray> arrays = JSONObject.parseArray(r, JSONArray.class);
        if (clazz == null) {
            return new Result().toSuccess(arrays);
        }
        List<T> list = new ArrayList<>();
        for (JSONArray array : arrays) {
            try {
                //new 一个数据对象
                T t1 = clazz.newInstance();
                //拆分属性字段

                String[] fieldKeys = params.getFieldKeys().split(",");
                for (int i = 0; i < fieldKeys.length; i++) {
                    String fieldKey = fieldKeys[i].replace(".","");
                    try {
                        //是否是属性对象
                        String[] split = fieldKey.split("\\.");
                        //建立一个临时对象指向需要存储的属性
                        Object t2 = t1;
                        //建立一个临时Class指向需要存储的属性的Class
                        Class tc = clazz;
                        for (int j = 0; j < split.length; j++) {
                            Field field = tc.getDeclaredField(split[j]);
                            field.setAccessible(true);
                            //没有子属性对象了，将数
                            if (j == split.length - 1) {
//                                field.set(t2, array.get(i));
                                setAccessible(t2, field, array.get(i));
                                continue;
                            }
                            //获取子对象
                            Object o1 = field.get(t1);
                            //如果子对象为null则新建一个
                            if (o1 == null) {
                                Object o2 = field.getType().newInstance();
                                tc = o2.getClass();
                                t2 = o2;
//                                field.set(t1, o2);
                                setAccessible(t1, field, o2);
                            } else {
                                tc = o1.getClass();
                                t2 = o1;
                            }
                        }
                    } catch (NoSuchFieldException e) {
                        throw new CustomException(-1, clazz.getTypeName() + "没有【" + fieldKey + "】字段");
                    }
                }
                list.add(t1);
            } catch (InstantiationException e) {
                e.printStackTrace();
            } catch (IllegalAccessException e) {
                e.printStackTrace();
            }
        }
        return new Result().toSuccess(list);
    }

    public static String doPostSave(String url,String param,String authorization) {
        // 创建Httpclient对象
        CloseableHttpClient httpClient = HttpClients.createDefault();
        CloseableHttpResponse response = null;
        String resultString = "";
        try {
            HttpPost httpPost = new HttpPost(url);
            if(!EmptyUtil.isEmpty(authorization)){
                httpPost.setHeader(COOKIE, ApiConst.TOKEN_VAL +authorization);
            }
            // 创建请求内容
            StringEntity entity = new StringEntity(param, ContentType.APPLICATION_JSON);
            httpPost.setEntity(entity);
            // 执行http请求
            response = httpClient.execute(httpPost);
            resultString = EntityUtils.toString(response.getEntity(), DEFAULT_CHARSET);
        } catch (Exception e) {
            System.out.println("post异常" + e.getMessage());
            e.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                System.out.println("post异常" + e.getMessage());
                e.printStackTrace();
            }
        }
        resultString=String.valueOf(JSON.parse(resultString));
        return resultString;
    }

    public static String doPost(String url, Map<String, String> param,String authorization) {
        // 创建Httpclient对象
        CloseableHttpClient httpClient = HttpClients.createDefault();

        CloseableHttpResponse response = null;
        String resultString = "";
        try {
            // 创建Http Post请求
            HttpPost httpPost = new HttpPost(url);
            if(!EmptyUtil.isEmpty(authorization)){
                httpPost.setHeader("Cookie", ApiConst.TOKEN_VAL +authorization);
            }
            // 创建参数列表
            if (param != null) {
                List<NameValuePair> paramList = new ArrayList<>();
                for (String key : param.keySet()) {
                    String va1 = param.get(key);
                    paramList.add(new BasicNameValuePair(key, va1));
                }
                UrlEncodedFormEntity entity = new UrlEncodedFormEntity(paramList,"UTF-8");
                httpPost.setEntity(entity);
            }
            // 执行http请求
            response = httpClient.execute(httpPost);
            resultString = EntityUtils.toString(response.getEntity(),"utf-8");
        } catch (Exception e) {
            e.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException e) {
                e.printStackTrace();
            }
        }
        resultString=String.valueOf(JSON.parse(resultString));
        return resultString;
    }

    public static String doPost1(String url, Map<String, String> param, String authorization) {
        CloseableHttpClient httpClient = HttpClients.createDefault();
        CloseableHttpResponse response = null;
        String resultString = "";

        try {
            HttpPost httpPost = new HttpPost(url);
            if (!EmptyUtil.isEmpty(authorization)) {
                httpPost.setHeader("api_key", "" + authorization);
            }

            if (param != null) {
                List<NameValuePair> paramList = new ArrayList();
                Iterator var8 = param.keySet().iterator();

                while(var8.hasNext()) {
                    String key = (String)var8.next();
                    String va1 = (String)param.get(key);
                    paramList.add(new BasicNameValuePair(key, va1));
                }

                UrlEncodedFormEntity entity = new UrlEncodedFormEntity(paramList, "UTF-8");
                httpPost.setEntity(entity);
            }

            response = httpClient.execute(httpPost);
            resultString = EntityUtils.toString(response.getEntity(), "utf-8");
        } catch (Exception var19) {
            var19.printStackTrace();
        } finally {
            try {
                response.close();
            } catch (IOException var18) {
                var18.printStackTrace();
            }

        }

        resultString = String.valueOf(JSON.parse(resultString));
        return resultString;
    }

}
